library(foreign)
library(survival)
library(norm)


LeaderI.data <- read.dta("C:/Hgoemans/Leaders/Fate/CRISK/JCR/Ifail.dta", convert.dates=FALSE)

attach(LeaderI.data)

summary(LeaderI.data)
sum(is.na(tmixed))
sum(is.na(tdemparl))
sum(is.na(tdempres))
sum(is.na(trans))
sum(is.na(civwar))
sum(is.na(lngdpcapL))
sum(is.na(growth))
sum(is.na(tropen2L))
sum(is.na(dopen2))
sum(is.na(lnpop))
sum(is.na(age)) #age is age in this observation
sum(is.na(age0)) #age0 is age at entry
sum(is.na(entry1))
sum(is.na(powtimes))
sum(is.na(initiator))
sum(is.na(defender))
sum(is.na(dwinsh))
sum(is.na(dlosesh))
sum(is.na(ddrawsh))
sum(is.na(initiator2))
sum(is.na(defender2))
sum(is.na(dwinwar))
sum(is.na(dlosewar))
sum(is.na(ddrawwar))
sum(is.na(ccode))

#LeaderP.2.data <- subset(LeaderI.data, tmixed!="NA")
#detach(LeaderI.data)
#attach(LeaderP.2.data)
#sum(is.na(tmixed))

median(t)
median(t)/365.25
(median(t)/365.25-as.integer(median(t)/365.25))*12
median(t[tmixed==1])
median(t[tmixed==1])/365.25
median(t[tdemparl==1])
median(t[tdemparl==1])/365.25
median(t[tdempres==1])
median(t[tdempres==1])/365.25
median(t[autoc==1])
median(t[autoc==1])/365.25
median(t[trans==1])/365.25

#Leader.data$t <- round(t,6)
#Leader.data$t0 <- round(t0,6)

LeaderI.data$txtmixed <- log(t)*tmixed
LeaderI.data$txtdemparl <- log(t)*tdemparl
LeaderI.data$txtdempres <- log(t)*tdempres
LeaderI.data$txtrans <- log(t)*trans
LeaderI.data$txentry1 <- log(t)*entry1
LeaderI.data$txcivwar <- log(t)*civwar
LeaderI.data$txlngcapL <- log(t)*lngdpcapL
LeaderI.data$txgrowth <- log(t)*growth
LeaderI.data$txtropen2L <- log(t)*tropen2L
LeaderI.data$txdopen2 <- log(t)*dopen2
LeaderI.data$txlnpop <- log(t)*lnpop
LeaderI.data$txage0 <- log(t)*age0
LeaderI.data$txinitiator <- log(t)*initiator
LeaderI.data$txinitiator2 <- log(t)*initiator2
LeaderI.data$txdefender <- log(t)*defender
LeaderI.data$txdefender2 <- log(t)*defender2
LeaderI.data$txinherit <- log(t)*inherit
LeaderI.data$txdwinsh <- log(t)*dwinsh
LeaderI.data$txdwinwar <- log(t)*dwinwar
LeaderI.data$txdlosesh <- log(t)*dlosesh
LeaderI.data$txdlose <- log(t)*dlose
LeaderI.data$txdlosesh <- log(t)*dlosesh
LeaderI.data$txdwin <- log(t)*dwin
LeaderI.data$txlnpoldays <- log(t)*lnpoldays


attach(LeaderI.data)

#
#modelI1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
#                               + civwar + txcivwar
#                               + lngdpcapL + growth
#                               + tropen2L + txtropen2L + dopen2
#                               + lnpop 
#                               + age0 + txage0 + entry1 + txentry1 + powtimes
#                               + initiator2 + defender2 + inherit
#                               + dwinsh + dlosesh + txdlosesh + ddrawsh
#                               + dwinwar + dlosewar + ddrawwar
#                               + frailty(ccode), na.action=na.exclude, data=LeaderI.data,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#print(modelI1)
#also ran with frailty(leadid)
#modelP1.L <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
#                               + civwar + txcivwar
#                               + lngdpcapL + growth
#                               + tropen2L + txtropen2L + growth
#                               + lnpop 
#                               + age0 + txage0 + entry1 + txentry1 + powtimes
#                               + initiator2 + defender2 + inherit
#                               + dwinsh + dlosesh + txdlosesh + ddrawsh
#                               + dwinwar + dlosewar + ddrawwar
#                               + frailty(leadid), na.action=na.exclude, data=LeaderI.data,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#print(modelR1.L)


detach(LeaderI.data)
attach(LeaderI.data)

## Get the data as matrix
I.L <- as.matrix(LeaderI.data[,c('t','t0','d',
                     'tmixed','tdemparl','tdempres','trans','lnpoldays',
                     'civwar','txcivwar','lngdpcapL','growth',
                     'tropen2L','dopen2','lnpop','energy',
                     'age0','entry1','txentry1','powtimes',
                     'initiator2', 'defender2','inherit',
                     'dwin','dlose','ddraw','dwinsh','dlosesh', 'ddrawsh',
                     'dwinwar','dlosewar','ddrawwar')])

detach(LeaderI.data)


## missing value imputation
## prelim.norm does preliminary computations
## em.norm gives the EM estimates
## getparam gives the parameters back on original scale

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)


## bootstrap procedure to get EM estimates on a sample a quarter of the size of the whole sample
## this gives different starting values for the imputation, see Allison, 2002
set.seed(1510)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

## missing value imputation
s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)


## replace the mean mu and variances sigma computed on the entire dataset L
## with the mean mu and variances sigma computed on the smaller sample
## then, convert the values with the makeparam command
thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.1 is the first imputed data set
rngseed(4510)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.1 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.1$ccode <- LeaderI.data$ccode
attach(I.L.1)


## model with imputed data set I.L.1 without correction for ph violation

model1.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.I.L1)
## proportional hazard tests
fit.model1.I.L1 <- cox.zph(model1.I.L1, transform='identity')
print(fit.model1.I.L1)
#ph violations: growth, age0, entry1 and dlosesh fail. 

## more models, now collapsing conflict into one category


model0.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
print(model0.I.L1)
fit.model0.I.L1 <- cox.zph(model0.I.L1, transform='identity')
print(fit.model0.I.L1)
plot(fit.model0.I.L1[18])
#ph violations: 


model2.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.I.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L1 <- list(coef(model2.I.L1))
I.m2.se.L1 <- list(sqrt(diag(vcov(model2.I.L1))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L1 <- basehaz(model2.I.L1,centered=FALSE)

# model1.tx <- update(model1, .~. + txtmixed + txtdemparl + txtdempres + txtrans)

model3.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m3.coef.L1 <- list(coef(model3.I.L1))
I.m3.se.L1 <- list(sqrt(diag(vcov(model3.I.L1))))

detach(I.L.1)

## the following sections repeat the same operations; extracting a new sample from the
## main data set to get new starting values for the multiple imputation procedure

## Creating the second imputed data set

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6796)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.2 is the second imputed data set

rngseed(4894)

theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.2 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.2$ccode <- LeaderI.data$ccode
attach(I.L.2)


## model with imputed data set I.L.2 without correction for ph violation

model1.I.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.I.L2)
## proportional hazard tests
fit.model1.I.L2 <- cox.zph(model1.I.L2, transform='identity')
print(fit.model1.I.L2)


## more models, now collapsing conflict into one category

model0.I.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.I.L2 <- cox.zph(model0.I.L2, transform='identity')
print(fit.model0.I.L2)
print(model0.I.L2)

model2.I.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.I.L2)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L2 <- list(coef(model2.I.L2))
I.m2.se.L2 <- list(sqrt(diag(vcov(model2.I.L2))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L2 <- basehaz(model2.I.L2,centered=FALSE)


model3.I.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L2)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m3.coef.L2 <- list(coef(model3.I.L2))
I.m3.se.L2 <- list(sqrt(diag(vcov(model3.I.L2))))

detach(I.L.2)

##Now creating the third imputed data set

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6975)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.3 is the third imputed data set
rngseed(9329)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.3 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.3$ccode <- LeaderI.data$ccode
attach(I.L.3)


## model with imputed data set I.L.3 without correction for ph violation

model1.I.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.I.L3)
## proportional hazard tests
fit.model1.I.L3 <- cox.zph(model1.I.L3, transform='identity')
print(fit.model1.I.L3)


## more models, now collapsing conflict into one category

model0.I.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.I.L3 <- cox.zph(model0.I.L3, transform='identity')
print(fit.model0.I.L3)
print(model0.I.L3)

model2.I.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.I.L3)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L3 <- list(coef(model2.I.L3))
I.m2.se.L3 <- list(sqrt(diag(vcov(model2.I.L3))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L3 <- basehaz(model2.I.L3,centered=FALSE)

model3.I.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L3)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m3.coef.L3 <- list(coef(model3.I.L3))
I.m3.se.L3 <- list(sqrt(diag(vcov(model3.I.L3))))

detach(I.L.3)

# Now creating the fourth imputed data set

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(3038)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.4 is the fourth imputed data set
rngseed(5152)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.4 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.4$ccode <- LeaderI.data$ccode
attach(I.L.4)


## model with imputed data set I.L.4 without correction for ph violation

model1.I.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.I.L4)
## proportional hazard tests
fit.model1.I.L4 <- cox.zph(model1.I.L4, transform='identity')
print(fit.model1.I.L4)


## more models, now collapsing conflict into one category

model0.I.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.I.L4 <- cox.zph(model0.I.L4, transform='identity')
print(fit.model0.I.L4)
print(model0.I.L4)

model2.I.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.I.L4)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L4 <- list(coef(model2.I.L4))
I.m2.se.L4 <- list(sqrt(diag(vcov(model2.I.L4))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L4 <- basehaz(model2.I.L4,centered=FALSE)


model3.I.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L4)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m3.coef.L4 <- list(coef(model3.I.L4))
I.m3.se.L4 <- list(sqrt(diag(vcov(model3.I.L4))))

detach(I.L.4)

# Now the fifth and final imputed data set

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(2632)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.5 is the fifth imputed data set
rngseed(1138)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.5 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.5$ccode <- LeaderI.data$ccode
attach(I.L.5)


## model with imputed data set I.L.5 without correction for ph violation

model1.I.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.I.L5)
## proportional hazard tests
fit.model1.I.L5 <- cox.zph(model1.I.L5, transform='identity')
print(fit.model1.I.L5)


## more models, now collapsing conflict into one category

model0.I.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + lnpoldays + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.I.L5 <- cox.zph(model0.I.L5, transform='identity')
print(fit.model0.I.L5)
print(model0.I.L5)

model2.I.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
print(model2.I.L5)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L5 <- list(coef(model2.I.L5))
I.m2.se.L5 <- list(sqrt(diag(vcov(model2.I.L5))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L5 <- basehaz(model2.I.L5,centered=FALSE)


model3.I.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + lnpoldays + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L5)

## get coefficients and standard errors from the models; used later below
I.m3.coef.L5 <- list(coef(model3.I.L5))
I.m3.se.L5 <- list(sqrt(diag(vcov(model3.I.L5))))

detach(I.L.5)



##################################################################################################
##################################################################################################

# model 0 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m0.I.rho <- cbind(fit.model0.I.L1$table[,1],fit.model0.I.L2$table[,1],fit.model0.I.L3$table[,1],fit.model0.I.L4$table[,1],
                fit.model0.I.L5$table[,1])  ## get the rhos

m0.I.rho.chi <- cbind(fit.model0.I.L1$table[,2],fit.model0.I.L2$table[,2],fit.model0.I.L3$table[,2],fit.model0.I.L4$table[,2],
                fit.model0.I.L5$table[,2])  ## get the chi-squares

m0.I.rho.bar <- apply(m0.I.rho,1,mean)   ## take the means of the rhos

m0.I.d.bar <- apply(m0.I.rho.chi,1,mean)  ## take the means of the chi-squares

m0.I.s2.rho <- apply(sqrt(m0.I.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m0.I.D.tilde <- (m0.I.d.bar-(1-1/M)*m0.I.s2.rho)/(1+(1+1/M)*m0.I.s2.rho)  ## D-tilde expression on p.590 of Rubin-Shenker
                                                                  ## k is equal to 1

m0.I.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m0.I.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                  ## of p.590 of Rubin-Shenker

m0.I.rho.imp <- round(cbind('rho'=m0.I.rho.bar,'D.tilde'=m0.I.D.tilde,'p-value'=pf(m0.I.D.tilde,1,m0.I.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m0.I.rho.imp)


plot(fit.model0.I.L1[1])
plot(fit.model0.I.L2[2])
plot(fit.model0.I.L3[3])
plot(fit.model0.I.L4[4])
plot(fit.model0.I.L5[5])

##################################################################################################
##################################################################################################

# model 1 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m1.I.rho <- cbind(fit.model1.I.L1$table[,1],fit.model1.I.L2$table[,1],fit.model1.I.L3$table[,1],fit.model1.I.L4$table[,1],
                fit.model1.I.L5$table[,1])  ## get the rhos

m1.I.rho.chi <- cbind(fit.model1.I.L1$table[,2],fit.model1.I.L2$table[,2],fit.model1.I.L3$table[,2],fit.model1.I.L4$table[,2],
                fit.model1.I.L5$table[,2])  ## get the chi-squares

m1.I.rho.bar <- apply(m1.I.rho,1,mean)   ## take the means of the rhos

m1.I.d.bar <- apply(m1.I.rho.chi,1,mean)  ## take the means of the chi-squares

m1.I.s2.rho <- apply(sqrt(m1.I.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m1.I.D.tilde <- (m1.I.d.bar-(1-1/M)*m1.I.s2.rho)/(1+(1+1/M)*m1.I.s2.rho)  ## D-tilde expression on p.590 of Rubin-Shenker
                                                                  ## k is equal to 1

m1.I.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m1.I.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                  ## of p.590 of Rubin-Shenker

m1.I.rho.imp <- round(cbind('rho'=m1.I.rho.bar,'D.tilde'=m1.I.D.tilde,'p-value'=pf(m1.I.D.tilde,1,m1.I.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m1.I.rho.imp)

plot(fit.model1.I.L1[5])
plot(fit.model1.I.L2[11])
plot(fit.model1.I.L3[12])
plot(fit.model1.I.L4[11])
plot(fit.model1.I.L5[20]) #Two outliers drive the violation.


##################################################################################################
##################################################################################################

# model 2 -- coefficients

m2.I.b <- c(I.m2.coef.L1,I.m2.coef.L2,I.m2.coef.L3,I.m2.coef.L4,I.m2.coef.L5)
m2.I.s <- c(I.m2.se.L1,I.m2.se.L2,I.m2.se.L3,I.m2.se.L4,I.m2.se.L5)

model2.I.imp <- mi.inference(m2.I.b,m2.I.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model2.I.imp$est,'std.err'=model2.I.imp$std.err,'p-value'=model2.I.imp$signif),3)

# model 2 -- log likelihood
m2.I.llk <- mean(c(model2.I.L1$loglik[2],model2.I.L2$loglik[2],model2.I.L3$loglik[2],model2.I.L4$loglik[2],
               model2.I.L5$loglik[2]))

# model 2 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.I <- nrow(vcov(model2.I.L1))

m2.I.U <- (vcov(model2.I.L1)+vcov(model2.I.L2)+vcov(model2.I.L3)+vcov(model2.I.L4)+vcov(model2.I.L5))/M
                ## mean of var-cov matrixes

m2.I.A <- diag(1,k.I,k.I)

m2.I.zz1 <- (model2.I.L1$coef - model2.I.imp$est)%*%t(model2.I.L1$coef - model2.I.imp$est) ## (Theta-0 - Theta-bar) squared
m2.I.zz2 <- (model2.I.L2$coef - model2.I.imp$est)%*%t(model2.I.L2$coef - model2.I.imp$est)
m2.I.zz3 <- (model2.I.L3$coef - model2.I.imp$est)%*%t(model2.I.L3$coef - model2.I.imp$est)
m2.I.zz4 <- (model2.I.L4$coef - model2.I.imp$est)%*%t(model2.I.L4$coef - model2.I.imp$est)
m2.I.zz5 <- (model2.I.L5$coef - model2.I.imp$est)%*%t(model2.I.L5$coef - model2.I.imp$est)

m2.I.B <- (m2.I.zz1+m2.I.zz2+m2.I.zz3+m2.I.zz4+m2.I.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m2.I.rm <- (1+1/M)*sum(diag(m2.I.B%*%solve(m2.I.U)))/k.I   ## see r at top of p.590 of Rubin-Shenker

#m2.I.V <- (1+m2.I.rm)*m2.I.U

m2.I.Dm <- t(m2.I.A%*%model2.I.imp$est)%*%solve(m2.I.A%*%m2.I.U%*%t(m2.I.A))%*%(m2.I.A%*%model2.I.imp$est)/((1+m2.I.rm)*k.I) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m2.I.Dm) # This is the Wald test statistic

m2.I.a <- 1-2/(k.I*(M-1))                   ## a p.590 of Rubin-Shenker
m2.I.v <- 4+(k.I*(M-1)-4)*(1+m2.I.a/m2.I.rm)^2  ## w p.590 of Rubin-Shenker

m2.I.pval.Wald <- pf(m2.I.Dm,k.I,m2.I.v,lower.tail=FALSE)  ## F-test
print(m2.I.pval.Wald)

##################################################################################################
##################################################################################################


# model 3 -- coefficients

m3.I.b <- c(I.m3.coef.L1,I.m3.coef.L2,I.m3.coef.L3,I.m3.coef.L4,I.m3.coef.L5)
m3.I.s <- c(I.m3.se.L1,I.m3.se.L2,I.m3.se.L3,I.m3.se.L4,I.m3.se.L5)

model3.I.imp <- mi.inference(m3.I.b,m3.I.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model3.I.imp$est,'std.err'=model3.I.imp$std.err,'p-value'=model3.I.imp$signif),3)

# model 3 -- log likelihood
m3.I.llk <- mean(c(model3.I.L1$loglik[2],model3.I.L2$loglik[2],model3.I.L3$loglik[2],model3.I.L4$loglik[2],
               model3.I.L5$loglik[2]))

# model 3 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.I <- nrow(vcov(model3.I.L1))

m3.I.U <- (vcov(model3.I.L1)+vcov(model3.I.L2)+vcov(model3.I.L3)+vcov(model3.I.L4)+vcov(model3.I.L5))/M
                ## mean of var-cov matrixes

m3.I.A <- diag(1,k.I,k.I)

m3.I.zz1 <- (model3.I.L1$coef - model3.I.imp$est)%*%t(model3.I.L1$coef - model3.I.imp$est) ## (Theta-0 - Theta-bar) squared
m3.I.zz2 <- (model3.I.L2$coef - model3.I.imp$est)%*%t(model3.I.L2$coef - model3.I.imp$est)
m3.I.zz3 <- (model3.I.L3$coef - model3.I.imp$est)%*%t(model3.I.L3$coef - model3.I.imp$est)
m3.I.zz4 <- (model3.I.L4$coef - model3.I.imp$est)%*%t(model3.I.L4$coef - model3.I.imp$est)
m3.I.zz5 <- (model3.I.L5$coef - model3.I.imp$est)%*%t(model3.I.L5$coef - model3.I.imp$est)

m3.I.B <- (m3.I.zz1+m3.I.zz2+m3.I.zz3+m3.I.zz4+m3.I.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k.I   ## see r at top of p.590 of Rubin-Shenker

#m3.I.V <- (1+m3.I.rm)*m3.I.U

m3.I.Dm <- t(m3.I.A%*%model3.I.imp$est)%*%solve(m3.I.A%*%m3.I.U%*%t(m3.I.A))%*%(m3.I.A%*%model3.I.imp$est)/((1+m3.I.rm)*k.I) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m3.I.Dm) # This is the Wald test statistic

m3.I.a <- 1-2/(k.I*(M-1))                   ## a p.590 of Rubin-Shenker
m3.I.v <- 4+(k.I*(M-1)-4)*(1+m3.I.a/m3.I.rm)^2  ## w p.590 of Rubin-Shenker

m3.I.pval.Wald <- pf(m3.I.Dm,k.I,m3.I.v,lower.tail=FALSE)  ## F-test
print(m3.I.pval.Wald)

##################################################################################################
##################################################################################################

# frailty terms Model0

print(model2.I.L1)
print(model2.I.L2)
print(model2.I.L3)
print(model2.I.L4)
print(model2.I.L5)

m2.I.frailty <- mean(c(model2.I.L1$history$"frailty(ccode)"$history[5,1], #number of outer iterations
                     model2.I.L2$history$"frailty(ccode)"$history[5,1],
                     model2.I.L3$history$"frailty(ccode)"$history[5,1],
                     model2.I.L4$history$"frailty(ccode)"$history[5,1],
                     model2.I.L5$history$"frailty(ccode)"$history[5,1]))


round(pgamma(1,1/m2.I.frailty,1/m2.I.frailty),3)
round(qgamma(.025,1/m2.I.frailty,1/m2.I.frailty),3)
round(qgamma(.975,1/m2.I.frailty,1/m2.I.frailty),3)

m2.I.frail.terms <- exp((model2.I.L1$frail+model2.I.L2$frail+model2.I.L3$frail+model2.I.L4$frail+model2.I.L5$frail)/5)

quantile(m2.I.frail.terms,probs=seq(0,1,.005))

table(ccode)

cbind(m2.I.frail.terms,rep(NA,164)) #164 is the number of countries.

max(m2.I.frail.terms)
min(m2.I.frail.terms)

summary(m2.I.frail.terms)

country <- LeaderI.data$ccode
country <- unique(country)
country.frailty <- cbind(m2.I.frail.terms,country)
print(country.frailty)

round(100*(1-0.5498),2)     # ccode 760, Bhutan
round(100*(1-0.9705),2)     # ccode 2, USA
round(100*(1-0.8038),2)     # ccode 200, UK


m2.I.k.theta <- 62 # see df from model2.I.L1 from the frailty term
m2.I.d.bar.theta <- mean(c(126.38,129.2,117.31,129.3,125.78)) # Chi-square of the models
m2.I.s2.theta <- var(c(126.38,129.2,117.31,129.3,125.78)^.5)  # Chi-square of the models

m2.I.D.tilde.theta <- (m2.I.d.bar.theta/m2.I.k.theta - (1-1/M)*m2.I.s2.theta)/(1+(1+1/M)*m2.I.s2.theta)

m2.I.b.theta <- (m2.I.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m2.I.s2.theta)^(-1))^2

m2.I.frail.pval <- pf(m2.I.D.tilde.theta,m2.I.k.theta,m2.I.b.theta,lower.tail=FALSE)
print(m2.I.frail.pval)

##################################################################################################
##################################################################################################

# frailty terms Model 3

print(model3.I.L1)
print(model3.I.L2)
print(model3.I.L3)
print(model3.I.L4)
print(model3.I.L5)

m3.I.frailty <- mean(c(model3.I.L1$history$"frailty(ccode)"$history[5,1], #number of outer iterations
                     model3.I.L2$history$"frailty(ccode)"$history[5,1],
                     model3.I.L3$history$"frailty(ccode)"$history[5,1],
                     model3.I.L4$history$"frailty(ccode)"$history[5,1],
                     model3.I.L5$history$"frailty(ccode)"$history[5,1]))


round(pgamma(1,1/m3.I.frailty,1/m3.I.frailty),3)
round(qgamma(.025,1/m3.I.frailty,1/m3.I.frailty),3)
round(qgamma(.975,1/m3.I.frailty,1/m3.I.frailty),3)

m3.I.frail.terms <- exp((model3.I.L1$frail+model3.I.L2$frail+model3.I.L3$frail+model3.I.L4$frail+model3.I.L5$frail)/5)

quantile(m3.I.frail.terms,probs=seq(0,1,.01))

table(ccode)

cbind(m3.I.frail.terms,rep(NA,164)) #164 is the number of countries.

max(m3.I.frail.terms)
min(m3.I.frail.terms)
country.frailty <- cbind(m3.I.frail.terms,country)
print(country.frailty)

m3.I.k.theta <- 60 # see df from model3.I.L1 from the frailty term
m3.I.d.bar.theta <- mean(c(120.82,123.71,111.62,122.98,117.39)) # Chi-square of the models
m3.I.s2.theta <- var(c(120.82,123.71,111.62,122.98,117.39)^.5)  # Chi-square of the models

m3.I.D.tilde.theta <- (m3.I.d.bar.theta/m3.I.k.theta - (1-1/M)*m3.I.s2.theta)/(1+(1+1/M)*m3.I.s2.theta)

m3.I.b.theta <- (m3.I.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m3.I.s2.theta)^(-1))^2

m3.I.frail.pval <- pf(m3.I.D.tilde.theta,m3.I.k.theta,m3.I.b.theta,lower.tail=FALSE)
print(m3.I.frail.pval)

##################################################################################################
##################################################################################################

m2.I.part1 <- round(cbind('b'=model2.I.imp$est,'std.err'=model2.I.imp$std.err,'p-value'=model2.I.imp$signif),3)[1:22,] # first 22 coefficients
m2.I.part1 <- rbind(m2.I.part1,
                  'No. of obs.'=c(as.integer(model2.I.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(477,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m2.I.llk,NA,NA), # log-llk
                  'Wald-test'=c(m2.I.Dm,m2.I.pval.Wald,NA), # wald test
                  'Theta'=c(m2.I.frailty,m2.I.D.tilde.theta,m2.I.frail.pval)) # frailty

m2.I.part1 <- round((m2.I.part1),3)
print(m2.I.part1)


m3.I.part1 <- round(cbind('b'=model3.I.imp$est,'std.err'=model3.I.imp$std.err,'p-value'=model3.I.imp$signif),3)[1:25,] # first 25 coefficients
m3.I.part1 <- rbind(m3.I.part1,
                  'No. of obs.'=c(as.integer(model3.I.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(477,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m3.I.llk,NA,NA), # log-llk
                  'Wald-test'=c(m3.I.Dm,m3.I.pval.Wald,NA), # wald test
                  'Theta'=c(m3.I.frailty,m3.I.D.tilde.theta,m3.I.frail.pval)) # frailty

m3.I.part1 <- round((m3.I.part1),3)
print(m3.I.part1)
