library(foreign)
library(survival)
library(norm)

########################################################################################################
########################################Multiple Imputation#############################################
########################################################################################################
LeaderP.data <- read.dta("C:/Hgoemans/Leaders/Fate/CRISK/JCR/Poolfail.dta", convert.dates=FALSE)

attach(LeaderP.data)

summary(LeaderP.data)
sum(is.na(tmixed))
sum(is.na(tdemparl))
sum(is.na(tdempres))
sum(is.na(trans))
sum(is.na(civwar))
sum(is.na(lngdpcapL))
sum(is.na(growth))
sum(is.na(tropen2L))
sum(is.na(dopen2))
sum(is.na(lnpop))
sum(is.na(age)) #age is age in this observation
sum(is.na(age0)) #age0 is age at entry
sum(is.na(entry1))
sum(is.na(powtimes))
sum(is.na(initiator))
sum(is.na(defender))
sum(is.na(dwinsh))
sum(is.na(dlosesh))
sum(is.na(ddrawsh))
sum(is.na(initiator2))
sum(is.na(defender2))
sum(is.na(dwinwar))
sum(is.na(dlosewar))
sum(is.na(ddrawwar))
sum(is.na(ccode))

#LeaderP.2.data <- subset(LeaderP.data, tmixed!="NA")
#detach(LeaderP.data)
#attach(LeaderP.2.data)
#sum(is.na(tmixed))

median(t)
median(t)/365.25
(median(t)/365.25-as.integer(median(t)/365.25))*12
median(t[tmixed==1])
median(t[tmixed==1])/365.25
median(t[tdemparl==1])
median(t[tdemparl==1])/365.25
median(t[tdempres==1])
median(t[tdempres==1])/365.25
median(t[autoc==1])
median(t[autoc==1])/365.25
median(t[trans==1])/365.25

#Leader.data$t <- round(t,6)
#Leader.data$t0 <- round(t0,6)

LeaderP.data$txtmixed <- log(t)*tmixed
LeaderP.data$txtdemparl <- log(t)*tdemparl
LeaderP.data$txtdempres <- log(t)*tdempres
LeaderP.data$txtrans <- log(t)*trans
LeaderP.data$txentry1 <- log(t)*entry1
LeaderP.data$txcivwar <- log(t)*civwar
LeaderP.data$txlngcapL <- log(t)*lngdpcapL
LeaderP.data$txgrowth <- log(t)*growth
LeaderP.data$txtropen2L <- log(t)*tropen2L
LeaderP.data$txdopen2 <- log(t)*dopen2
LeaderP.data$txlnpop <- log(t)*lnpop
LeaderP.data$txage0 <- log(t)*age0
LeaderP.data$txinitiator <- log(t)*initiator
LeaderP.data$txinitiator2 <- log(t)*initiator2
LeaderP.data$txdefender <- log(t)*defender
LeaderP.data$txdefender2 <- log(t)*defender2
LeaderP.data$txinherit <- log(t)*inherit
LeaderP.data$txdwinsh <- log(t)*dwinsh
LeaderP.data$txdwinwar <- log(t)*dwinwar
LeaderP.data$txdlosesh <- log(t)*dlosesh
LeaderP.data$txdlose <- log(t)*dlose
LeaderP.data$txdlosesh <- log(t)*dlosesh
LeaderP.data$txdwin <- log(t)*dwin

attach(LeaderP.data)


modelP1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + txtropen2L + dopen2
                               + lnpop 
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + txdlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=LeaderP.data,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(modelP1)
#also ran with frailty(leadid)
#modelP1.L <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
#                               + civwar + txcivwar
#                               + lngdpcapL + growth
#                               + tropen2L + txtropen2L + growth
#                               + lnpop 
#                               + age0 + txage0 + entry1 + txentry1 + powtimes
#                               + initiator2 + defender2 + inherit
#                               + dwinsh + dlosesh + txdlosesh + ddrawsh
#                               + dwinwar + dlosewar + ddrawwar
#                               + frailty(leadid), na.action=na.exclude, data=LeaderP.data,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#print(modelP1.L)


detach(LeaderP.data)
attach(LeaderP.data)

## Get the data as matrix
P.L <- as.matrix(LeaderP.data[,c('t','t0','d',
                     'tmixed','tdemparl','tdempres','trans',
                     'civwar','lngdpcapL','growth','txgrowth',
                     'tropen2L','dopen2','lnpop','energy',
                     'age0','txage0','txentry1','entry1','powtimes',
                     'initiator2', 'defender2','inherit',
                     'dwin','dlose','txdlose','ddraw','dwinsh','dlosesh','txdlosesh', 'ddrawsh',
                     'dwinwar','dlosewar','ddrawwar')])

detach(LeaderP.data)


## missing value imputation
## prelim.norm does preliminary computations
## em.norm gives the EM estimates
## getparam gives the parameters back on original scale

s <- prelim.norm(P.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)


## bootstrap procedure to get EM estimates on a sample a quarter of the size of the whole sample
## this gives different starting values for the imputation, see Allison, 2002
set.seed(1510)
trk <- seq(1,nrow(P.L),1)
boot.1 <- sample(trk,1+abs(nrow(P.L)/4),replace=TRUE)  ## sample the obs

## missing value imputation
s.1 <- prelim.norm(P.L[boot.1,])  ## P.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)


## replace the mean mu and variances sigma computed on the entire dataset L
## with the mean mu and variances sigma computed on the smaller sample
## then, convert the values with the makeparam command
thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## P.L.1 is the first imputed data set
rngseed(4510)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
P.L.1 <- as.data.frame(imp.norm(s,theta.1,P.L))

P.L.1$ccode <- LeaderP.data$ccode
attach(P.L.1)


## model with imputed data set P.L.1 without correction for ph violation

model1.P.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.P.L1)
## proportional hazard tests
fit.model1.P.L1 <- cox.zph(model1.P.L1, transform='identity')
print(fit.model1.P.L1)
#ph violations: growth, age0, entry1 and dlosesh fail. 

## more models, now collapsing conflict into one category


model0.P.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
print(model0.P.L1)
fit.model0.P.L1 <- cox.zph(model0.P.L1, transform='identity')
print(fit.model0.P.L1)
plot(fit.model0.P.L1[18])
#ph violations: tdemparl (0.06), tdempres (.004), civwar (.08), growth (.012), age0 (.003), entry1(0), dlose(.041)


model2.P.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + txdlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.P.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m2.coef.L1 <- list(coef(model2.P.L1))
P.m2.se.L1 <- list(sqrt(diag(vcov(model2.P.L1))))


## get the baseline hazard function; used later for the estimation of substantive effects
P.Ht.L1 <- basehaz(model2.P.L1,centered=FALSE)

# model1.tx <- update(model1, .~. + txtmixed + txtdemparl + txtdempres + txcivwar + txlnencap + txlnpop + txage)

model3.P.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + txdlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.P.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m3.coef.L1 <- list(coef(model3.P.L1))
P.m3.se.L1 <- list(sqrt(diag(vcov(model3.P.L1))))

detach(P.L.1)

## the following sections repeat the same operations; extracting a new sample from the
## main data set to get new starting values for the multiple imputation procedure

## Creating the second imputed data set

s <- prelim.norm(P.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6796)
trk <- seq(1,nrow(P.L),1)
boot.1 <- sample(trk,1+abs(nrow(P.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(P.L[boot.1,])  ## P.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## P.L.2 is the second imputed data set
rngseed(4894)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
P.L.2 <- as.data.frame(imp.norm(s,theta.1,P.L))

P.L.2$ccode <- LeaderP.data$ccode
attach(P.L.2)


## model with imputed data set P.L.2 without correction for ph violation

model1.P.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.P.L2)
## proportional hazard tests
fit.model1.P.L2 <- cox.zph(model1.P.L2, transform='identity')
print(fit.model1.P.L2)


## more models, now collapsing conflict into one category

model0.P.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.P.L2 <- cox.zph(model0.P.L2, transform='identity')
print(fit.model0.P.L2)
print(model0.P.L2)

model2.P.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + txdlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.P.L2)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m2.coef.L2 <- list(coef(model2.P.L2))
P.m2.se.L2 <- list(sqrt(diag(vcov(model2.P.L2))))


## get the baseline hazard function; used later for the estimation of substantive effects
P.Ht.L2 <- basehaz(model2.P.L2,centered=FALSE)


model3.P.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + txdlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.P.L2)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m3.coef.L2 <- list(coef(model3.P.L2))
P.m3.se.L2 <- list(sqrt(diag(vcov(model3.P.L2))))

detach(P.L.2)

##Now creating the third imputed data set

s <- prelim.norm(P.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6975)
trk <- seq(1,nrow(P.L),1)
boot.1 <- sample(trk,1+abs(nrow(P.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(P.L[boot.1,])  ## P.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## P.L.3 is the third imputed data set
rngseed(9329)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
P.L.3 <- as.data.frame(imp.norm(s,theta.1,P.L))

P.L.3$ccode <- LeaderP.data$ccode
attach(P.L.3)


## model with imputed data set P.L.3 without correction for ph violation

model1.P.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.P.L3)
## proportional hazard tests
fit.model1.P.L3 <- cox.zph(model1.P.L3, transform='identity')
print(fit.model1.P.L3)


## more models, now collapsing conflict into one category

model0.P.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.P.L3 <- cox.zph(model0.P.L3, transform='identity')
print(fit.model0.P.L3)
print(model0.P.L3)

model2.P.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + txdlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.P.L3)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m2.coef.L3 <- list(coef(model2.P.L3))
P.m2.se.L3 <- list(sqrt(diag(vcov(model2.P.L3))))


## get the baseline hazard function; used later for the estimation of substantive effects
P.Ht.L3 <- basehaz(model2.P.L3,centered=FALSE)

model3.P.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + txdlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.P.L3)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m3.coef.L3 <- list(coef(model3.P.L3))
P.m3.se.L3 <- list(sqrt(diag(vcov(model3.P.L3))))

detach(P.L.3)

# Now creating the fourth imputed data set

s <- prelim.norm(P.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(3038)
trk <- seq(1,nrow(P.L),1)
boot.1 <- sample(trk,1+abs(nrow(P.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(P.L[boot.1,])  ## P.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## P.L.4 is the fourth imputed data set
rngseed(5152)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
P.L.4 <- as.data.frame(imp.norm(s,theta.1,P.L))

P.L.4$ccode <- LeaderP.data$ccode
attach(P.L.4)


## model with imputed data set P.L.4 without correction for ph violation

model1.P.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.P.L4)
## proportional hazard tests
fit.model1.P.L4 <- cox.zph(model1.P.L4, transform='identity')
print(fit.model1.P.L4)


## more models, now collapsing conflict into one category

model0.P.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.P.L4 <- cox.zph(model0.P.L4, transform='identity')
print(fit.model0.P.L4)
print(model0.P.L4)

model2.P.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + txdlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.P.L4)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m2.coef.L4 <- list(coef(model2.P.L4))
P.m2.se.L4 <- list(sqrt(diag(vcov(model2.P.L4))))


## get the baseline hazard function; used later for the estimation of substantive effects
P.Ht.L4 <- basehaz(model2.P.L4,centered=FALSE)


model3.P.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + txdlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.P.L4)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m3.coef.L4 <- list(coef(model3.P.L4))
P.m3.se.L4 <- list(sqrt(diag(vcov(model3.P.L4))))

detach(P.L.4)

# Now the fifth and final imputed data set

s <- prelim.norm(P.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(2632)
trk <- seq(1,nrow(P.L),1)
boot.1 <- sample(trk,1+abs(nrow(P.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(P.L[boot.1,])  ## P.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## P.L.5 is the fifth imputed data set
rngseed(1138)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
P.L.5 <- as.data.frame(imp.norm(s,theta.1,P.L))

P.L.5$ccode <- LeaderP.data$ccode
attach(P.L.5)


## model with imputed data set P.L.5 without correction for ph violation

model1.P.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.P.L5)
## proportional hazard tests
fit.model1.P.L5 <- cox.zph(model1.P.L5, transform='identity')
print(fit.model1.P.L5)


## more models, now collapsing conflict into one category

model0.P.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.P.L5 <- cox.zph(model0.P.L5, transform='identity')
print(fit.model0.P.L5)
print(model0.P.L5)

model2.P.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + txdlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=P.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
print(model2.P.L5)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
P.m2.coef.L5 <- list(coef(model2.P.L5))
P.m2.se.L5 <- list(sqrt(diag(vcov(model2.P.L5))))


## get the baseline hazard function; used later for the estimation of substantive effects
P.Ht.L5 <- basehaz(model2.P.L5,centered=FALSE)


model3.P.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth + txgrowth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + txdlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=P.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.P.L5)

## get coefficients and standard errors from the models; used later below
P.m3.coef.L5 <- list(coef(model3.P.L5))
P.m3.se.L5 <- list(sqrt(diag(vcov(model3.P.L5))))

detach(P.L.5)


##################################################################################################
##################################################################################################

# model 0 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m0.rho <- cbind(fit.model0.P.L1$table[,1],fit.model0.P.L2$table[,1],fit.model0.P.L3$table[,1],fit.model0.P.L4$table[,1],
                fit.model0.P.L5$table[,1])  ## get the rhos

m0.rho.chi <- cbind(fit.model0.P.L1$table[,2],fit.model0.P.L2$table[,2],fit.model0.P.L3$table[,2],fit.model0.P.L4$table[,2],
                fit.model0.P.L5$table[,2])  ## get the chi-squares

m0.rho.bar <- apply(m0.rho,1,mean)   ## take the means of the rhos

m0.d.bar <- apply(m0.rho.chi,1,mean)  ## take the means of the chi-squares

m0.s2.rho <- apply(sqrt(m0.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m0.D.tilde <- (m0.d.bar-(1-1/M)*m0.s2.rho)/(1+(1+1/M)*m0.s2.rho)  ## D-tilde expression on p.590 of Rubin-Shenker
                                                                  ## k is equal to 1

m0.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m0.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                  ## of p.590 of Rubin-Shenker

m0.rho.imp <- round(cbind('rho'=m0.rho.bar,'D.tilde'=m0.D.tilde,'p-value'=pf(m0.D.tilde,1,m0.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m0.rho.imp)

##################################################################################################
##################################################################################################

# model 1 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m1.rho <- cbind(fit.model1.P.L1$table[,1],fit.model1.P.L2$table[,1],fit.model1.P.L3$table[,1],fit.model1.P.L4$table[,1],
                fit.model1.P.L5$table[,1])  ## get the rhos

m1.rho.chi <- cbind(fit.model1.P.L1$table[,2],fit.model1.P.L2$table[,2],fit.model1.P.L3$table[,2],fit.model1.P.L4$table[,2],
                fit.model1.P.L5$table[,2])  ## get the chi-squares

m1.rho.bar <- apply(m1.rho,1,mean)   ## take the means of the rhos

m1.d.bar <- apply(m1.rho.chi,1,mean)  ## take the means of the chi-squares

m1.s2.rho <- apply(sqrt(m1.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m1.D.tilde <- (m1.d.bar-(1-1/M)*m1.s2.rho)/(1+(1+1/M)*m1.s2.rho)  ## D-tilde expression on p.590 of Rubin-Shenker
                                                                  ## k is equal to 1

m1.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m1.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                  ## of p.590 of Rubin-Shenker

m1.rho.imp <- round(cbind('rho'=m1.rho.bar,'D.tilde'=m1.D.tilde,'p-value'=pf(m1.D.tilde,1,m1.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m1.rho.imp)
##############################################################################################
##################################################################################################
# model 2 -- coefficients

m2.P.b <- c(P.m2.coef.L1,P.m2.coef.L2,P.m2.coef.L3,P.m2.coef.L4,P.m2.coef.L5)
m2.P.s <- c(P.m2.se.L1,P.m2.se.L2,P.m2.se.L3,P.m2.se.L4,P.m2.se.L5)

model2.P.imp <- mi.inference(m2.P.b,m2.P.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model2.P.imp$est,'std.err'=model2.P.imp$std.err,'p-value'=model2.P.imp$signif),3)

# model 2 -- log likelihood
m2.P.llk <- mean(c(model2.P.L1$loglik[2],model2.P.L2$loglik[2],model2.P.L3$loglik[2],model2.P.L4$loglik[2],
               model2.P.L5$loglik[2]))

# model 2 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.P <- nrow(vcov(model2.P.L1))

m2.P.U <- (vcov(model2.P.L1)+vcov(model2.P.L2)+vcov(model2.P.L3)+vcov(model2.P.L4)+vcov(model2.P.L5))/M
                ## mean of var-cov matrixes

m2.P.A <- diag(1,k.P,k.P)

m2.P.zz1 <- (model2.P.L1$coef - model2.P.imp$est)%*%t(model2.P.L1$coef - model2.P.imp$est) ## (Theta-0 - Theta-bar) squared
m2.P.zz2 <- (model2.P.L2$coef - model2.P.imp$est)%*%t(model2.P.L2$coef - model2.P.imp$est)
m2.P.zz3 <- (model2.P.L3$coef - model2.P.imp$est)%*%t(model2.P.L3$coef - model2.P.imp$est)
m2.P.zz4 <- (model2.P.L4$coef - model2.P.imp$est)%*%t(model2.P.L4$coef - model2.P.imp$est)
m2.P.zz5 <- (model2.P.L5$coef - model2.P.imp$est)%*%t(model2.P.L5$coef - model2.P.imp$est)

m2.P.B <- (m2.P.zz1+m2.P.zz2+m2.P.zz3+m2.P.zz4+m2.P.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m2.P.rm <- (1+1/M)*sum(diag(m2.P.B%*%solve(m2.P.U)))/k.P   ## see r at top of p.590 of Rubin-Shenker

#m2.P.V <- (1+m2.P.rm)*m2.P.U

m2.P.Dm <- t(m2.P.A%*%model2.P.imp$est)%*%solve(m2.P.A%*%m2.P.U%*%t(m2.P.A))%*%(m2.P.A%*%model2.P.imp$est)/((1+m2.P.rm)*k.P) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m2.P.Dm) # This is the Wald test statistic

m2.P.a <- 1-2/(k.P*(M-1))                   ## a p.590 of Rubin-Shenker
m2.P.v <- 4+(k.P*(M-1)-4)*(1+m2.P.a/m2.P.rm)^2  ## w p.590 of Rubin-Shenker

m2.P.pval.Wald <- pf(m2.P.Dm,k.P,m2.P.v,lower.tail=FALSE)  ## F-test
print(m2.P.pval.Wald)


##################################################################################################
##################################################################################################

# model 3 -- coefficients

m3.P.b <- c(P.m3.coef.L1,P.m3.coef.L2,P.m3.coef.L3,P.m3.coef.L4,P.m3.coef.L5)
m3.P.s <- c(P.m3.se.L1,P.m3.se.L2,P.m3.se.L3,P.m3.se.L4,P.m3.se.L5)

model3.P.imp <- mi.inference(m3.P.b,m3.P.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model3.P.imp$est,'std.err'=model3.P.imp$std.err,'p-value'=model3.P.imp$signif),3)

# model 3 -- log likelihood
m3.P.llk <- mean(c(model3.P.L1$loglik[2],model3.P.L2$loglik[2],model3.P.L3$loglik[2],model3.P.L4$loglik[2],
               model3.P.L5$loglik[2]))

# model 3 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.P <- nrow(vcov(model3.P.L1))

m3.P.U <- (vcov(model3.P.L1)+vcov(model3.P.L2)+vcov(model3.P.L3)+vcov(model3.P.L4)+vcov(model3.P.L5))/M
                ## mean of var-cov matrixes

m3.P.A <- diag(1,k.P,k.P)

m3.P.zz1 <- (model3.P.L1$coef - model3.P.imp$est)%*%t(model3.P.L1$coef - model3.P.imp$est) ## (Theta-0 - Theta-bar) squared
m3.P.zz2 <- (model3.P.L2$coef - model3.P.imp$est)%*%t(model3.P.L2$coef - model3.P.imp$est)
m3.P.zz3 <- (model3.P.L3$coef - model3.P.imp$est)%*%t(model3.P.L3$coef - model3.P.imp$est)
m3.P.zz4 <- (model3.P.L4$coef - model3.P.imp$est)%*%t(model3.P.L4$coef - model3.P.imp$est)
m3.P.zz5 <- (model3.P.L5$coef - model3.P.imp$est)%*%t(model3.P.L5$coef - model3.P.imp$est)

m3.P.B <- (m3.P.zz1+m3.P.zz2+m3.P.zz3+m3.P.zz4+m3.P.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m3.P.rm <- (1+1/M)*sum(diag(m3.P.B%*%solve(m3.P.U)))/k.P   ## see r at top of p.590 of Rubin-Shenker

#m3.P.V <- (1+m3.P.rm)*m3.P.U

m3.P.Dm <- t(m3.P.A%*%model3.P.imp$est)%*%solve(m3.P.A%*%m3.P.U%*%t(m3.P.A))%*%(m3.P.A%*%model3.P.imp$est)/((1+m3.P.rm)*k.P) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m3.P.Dm) # This is the Wald test statistic

m3.P.a <- 1-2/(k.P*(M-1))                   ## a p.590 of Rubin-Shenker
m3.P.v <- 4+(k.P*(M-1)-4)*(1+m3.P.a/m3.P.rm)^2  ## w p.590 of Rubin-Shenker

m3.P.pval.Wald <- pf(m3.P.Dm,k.P,m3.P.v,lower.tail=FALSE)  ## F-test
print(m3.P.pval.Wald)

##################################################################################################
##################################################################################################

# frailty terms: Model2

print(model2.P.L1)
print(model2.P.L2)
print(model2.P.L3)
print(model2.P.L4)
print(model2.P.L5)

m2.P.frailty <- mean(c(model2.P.L1$history$"frailty(ccode)"$history[9,1], # number of outer iterations
                     model2.P.L2$history$"frailty(ccode)"$history[9,1],
                     model2.P.L3$history$"frailty(ccode)"$history[9,1],
                     model2.P.L4$history$"frailty(ccode)"$history[9,1],
                     model2.P.L5$history$"frailty(ccode)"$history[9,1]))

print(m2.P.frailty)


round(pgamma(1,1/m2.P.frailty,1/m2.P.frailty),3)
round(qgamma(.025,1/m2.P.frailty,1/m2.P.frailty),3)
round(qgamma(.975,1/m2.P.frailty,1/m2.P.frailty),3)

m2.P.frail.terms <- exp((model2.P.L1$frail+model2.P.L2$frail+model2.P.L3$frail+model2.P.L4$frail+model2.P.L5$frail)/5)
print(m2.P.frail.terms)

quantile(m2.P.frail.terms,probs=seq(0,1,.01))

cbind(m2.P.frail.terms,rep(NA,164)) # number of countries: I dropped Switzerland

max(m2.P.frail.terms)
min(m2.P.frail.terms)


m2.P.k.theta <- 126 # see df from model2.P.L1 for example
m2.P.d.bar.theta <- mean(c(676.64,674.34,653.59,649.72,680.97))   # Chi-square of the models
m2.P.s2.theta <- var(c(676.64,674.34,653.59,649.72,680.97)^.5)    # Chi-square of the models. 

m2.P.D.tilde.theta <- (m2.P.d.bar.theta/m2.P.k.theta - (1-1/M)*m2.P.s2.theta)/(1+(1+1/M)*m2.P.s2.theta)


m2.P.b.theta <- (m2.P.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m2.P.s2.theta)^(-1))^2
print(m2.P.b.theta)

m2.P.frail.pval <- pf(m2.P.D.tilde.theta,m2.P.k.theta,m2.P.b.theta,lower.tail=FALSE)
print(m2.P.frail.pval)

#################################################################################################
##################################################################################################

# frailty terms: Model3

print(model3.P.L1)
print(model3.P.L2)
print(model3.P.L3)
print(model3.P.L4)
print(model3.P.L5)

m3.P.frailty <- mean(c(model3.P.L1$history$"frailty(ccode)"$history[9,1], # number of outer iterations
                     model3.P.L2$history$"frailty(ccode)"$history[9,1],
                     model3.P.L3$history$"frailty(ccode)"$history[9,1],
                     model3.P.L4$history$"frailty(ccode)"$history[9,1],
                     model3.P.L5$history$"frailty(ccode)"$history[9,1]))

print(m3.P.frailty)


round(pgamma(1,1/m3.P.frailty,1/m3.P.frailty),3)
round(qgamma(.025,1/m3.P.frailty,1/m3.P.frailty),3)
round(qgamma(.975,1/m3.P.frailty,1/m3.P.frailty),3)

m3.P.frail.terms <- exp((model3.P.L1$frail+model3.P.L2$frail+model3.P.L3$frail+model3.P.L4$frail+model3.P.L5$frail)/5)
print(m3.P.frail.terms)

quantile(m3.P.frail.terms,probs=seq(0,1,.01))

cbind(m3.P.frail.terms,rep(NA,164)) # number of countries: I dropped Switzerland

max(m3.P.frail.terms)
min(m3.P.frail.terms)

m3.P.k.theta <- 126 # see df from model3.P.L1 for example
m3.P.d.bar.theta <- mean(c(677.33,674.95,655.03,651.65,682.43))   # Chi-square of the models
m3.P.s2.theta <- var(c(677.33,674.95,655.03,651.65,682.43)^.5)    # Chi-square of the models. 

m3.P.D.tilde.theta <- (m3.P.d.bar.theta/m3.P.k.theta - (1-1/M)*m3.P.s2.theta)/(1+(1+1/M)*m3.P.s2.theta)


m3.P.b.theta <- (m3.P.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m3.P.s2.theta)^(-1))^2
print(m3.P.b.theta)

m3.P.frail.pval <- pf(m3.P.D.tilde.theta,m3.P.k.theta,m3.P.b.theta,lower.tail=FALSE)
print(m3.P.frail.pval)

#################################################################################################
##################################################################################################

m2.P.part1 <- round(cbind('b'=model2.P.imp$est,'std.err'=model2.P.imp$std.err,'p-value'=model2.P.imp$signif),3)[1:23,] # first 23 coefficients
m2.P.part1 <- rbind(m2.P.part1,
                  'No. of obs.'=c(as.integer(model2.P.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(1973,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m2.P.llk,NA,NA), # log-llk
                  'Wald-test'=c(m2.P.Dm,m2.P.pval.Wald,NA), # wald test
                  'Theta'=c(m2.P.frailty,m2.P.D.tilde.theta,m2.P.frail.pval)) # frailty

m2.P.part1 <- round((m2.P.part1),3)
print(m2.P.part1)



m3.P.part1 <- round(cbind('b'=model3.P.imp$est,'std.err'=model3.P.imp$std.err,'p-value'=model3.P.imp$signif),3)[1:26,] # first 26 coefficients
m3.P.part1 <- rbind(m3.P.part1,
                  'No. of obs.'=c(as.integer(model3.P.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(1973,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m3.P.llk,NA,NA), # log-llk
                  'Wald-test'=c(m3.P.Dm,m3.P.pval.Wald,NA), # wald test
                  'Theta'=c(m3.P.frailty,m3.P.D.tilde.theta,m3.P.frail.pval)) # frailty

m3.P.part1 <- round((m3.P.part1),3)
print(m3.P.part1)

############################################################################################
###########################################################################################

# time to zero effects

# Growth


exp(-model3.P.imp$est[7]/model3.P.imp$est[8])/365.25 # Result is the coefficient associated with growth = 0 after ? years

m3.P.Tm <- m3.P.U+(1+1/M)*m3.P.B


2*pt(abs(model3.P.imp$est[7]+model3.P.imp$est[8]*log(365.25*.09))/sqrt(m3.P.Tm[7,7]+(log(365.25*.09))^2*m3.P.Tm[8,8]
      +2*log(365.25*.09)*m3.P.Tm[8,7]),200,lower.tail=FALSE)
      
# That's roughly one month


2*pt(abs(model3.P.imp$est[7]+model3.P.imp$est[8]*log(365.25*(31/365)))/sqrt(m3.P.Tm[7,7]+(log(365.25*(31/365)))^2*m3.P.Tm[8,8]
      +2*log(365.25*(31/365))*m3.P.Tm[8,7]),200,lower.tail=FALSE)


# Age

exp(-model3.P.imp$est[12]/model3.P.imp$est[13])/365.25

2*pt(abs(model3.P.imp$est[12]+model3.P.imp$est[13]*log(365.25*2.25))/sqrt(m3.P.Tm[12,12]+(log(365.25*2.25))^2*m3.P.Tm[13,13]
      +2*log(365.25*2.25)*m3.P.Tm[13,12]),200,lower.tail=FALSE)
      
#After slightly less than two and a quarter years, effect dissipates.


2*pt(abs(model3.P.imp$est[12]+model3.P.imp$est[13]*log(365.25*2.85))/sqrt(m3.P.Tm[12,12]+(log(365.25*2.85))^2*m3.P.Tm[13,13]
      +2*log(365.25*2.85)*m3.P.Tm[13,12]),200,lower.tail=FALSE)
      
#After less than three and a quarter years in office, Age reduces the overall hazard


# Entry

exp(-model3.P.imp$est[14]/model3.P.imp$est[15])/365.25

2*pt(abs(model3.P.imp$est[14]+model3.P.imp$est[15]*log(365.25*2))/sqrt(m3.P.Tm[14,14]+(log(365.25*2))^2*m3.P.Tm[15,15]
      +2*log(365.25*2)*m3.P.Tm[15,14]),200,lower.tail=FALSE)

#After slightly more than two years, Entry no longoer significantly increases the hazard


2*pt(abs(model3.P.imp$est[14]+model3.P.imp$est[15]*log(365.25*3.3))/sqrt(m3.P.Tm[14,14]+(log(365.25*3.3))^2*m3.P.Tm[15,15]
      +2*log(365.25*3.3)*m3.P.Tm[15,14]),200,lower.tail=FALSE)

# After slightly more than three and a quarter years, irregular entry decreases the overall hazard.

#dlosesh

exp(-model3.P.imp$est[21]/model3.P.imp$est[22])/365.25 # Result is the coefficient associated with dlosesh = 0 after ? years

m3.P.Tm <- m3.P.U+(1+1/M)*m3.P.B

#dlosesh: To get the p-values, when significant/no longer signficant at .05 level

2*pt(abs(model3.P.imp$est[21]+model3.P.imp$est[22]*log(365.25*100))/sqrt(m3.P.Tm[21,21]+(log(365.25*100))^2*m3.P.Tm[22,22]
      +2*log(365.25*100)*m3.P.Tm[22,21]),200,lower.tail=FALSE)


2*pt(abs(model3.P.imp$est[21]+model3.P.imp$est[22]*log(365.25*5.5))/sqrt(m3.P.Tm[21,21]+(log(365.25*5.5))^2*m3.P.Tm[22,22]
      +2*log(365.25*5.5)*m3.P.Tm[22,21]),200,lower.tail=FALSE)


#After experimentation, after roughly 5.5 years, dlosesh is significant at the .172 level, two-tailed

2*pt(abs(model3.P.imp$est[21]+model3.P.imp$est[22]*log(365.25*.000005))/sqrt(m3.P.Tm[21,21]+(log(365.25*.000005))^2*m3.P.Tm[22,22]
      +2*log(365.25*.000005)*m3.P.Tm[22,21]),200,lower.tail=FALSE)


# p-value is maximized after 5.5 years in office

##################################################################################################
##################################################################################################


#
#
### estimated effects
#
#
### See Therneau and Grambsch -- p.268--272
#
### estimate model with frailty term
#
#model2.P.L5 <- coxph(Surv(t0, t, d) ~  tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres
#                               + civwar
#                               + lnmaddcap + txlnmaddcap + maddgrowth
#                               + lntropen1 + tropen1chg
#                               + lnpop + txlnpop
#                               + age + txage + entry + txentry + powtimes
#                               + initiator + target
#                               + dwin + dlose + ddraw
#                               + frailty(ccode), na.action=na.exclude, data=P.L.5,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#
### estimate same model with no frailty
#modelP.trk <- coxph(Surv(t0, t, d) ~  tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres
#                               + civwar
#                               + lnmaddcap + txlnmaddcap + maddgrowth
#                               + lntropen1 + tropen1chg
#                               + lnpop + txlnpop
#                               + age + txage + entry + txentry + powtimes
#                               + initiator + target
#                               + dwin + dlose + ddraw, 
#                               na.action=na.exclude, data=P.L.5,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#
### trick, assuming that the frailty==1
#
#modelP.trk$coefficients <- model2.P.L5$coefficients
#
#summary(P.L.5)
#
#
### create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly and wins
#scen1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
#                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
#                    d=c(0,0,0,0,0), ## failure indicator all to 0
#                    tmixed=c(1,1,1,1,1),
#                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
#                    tdemparl=c(0,0,0,0,0),
#                    txtdemparl=c(0,0,0,0,0),
#                    tdempres=c(0,0,0,0,0),
#                    txtdempres=c(0,0,0,0,0),
#                    civwar=c(0,0,0,0,0),
#                    lnmaddcap=c(7.828,7.846,7.864,7.882,7.900),
#                    txlnmaddcap=c(46.177,51.728,55.032,57.428,59.321),
#                    maddgrowth=c(1.82,1.82,1.82,1.82,1.82),
#                    lntropen1=c(1.93,1.93,1.93,1.93,1.93),
#                    tropen1chg=c(0.036,0.036,0.036,0.036,0.036),
#                    lnpop=c(8.923,8.923,8.923,8.923,8.923),
#                    txlnpop=c(52.636,58.829,62.443,65.012,67.002),
#                    age=c(51,51,51,51,51),
#                    txage=c(300.85,336.24,356.90,371.59,382.96),
#                    entry=c(0,0,0,0,0),
#                    txentry=c(0,0,0,0,0),
#                    powtimes=c(0,0,0,0,0),
#                    initiator=c(1,0,0,0,0),
#                    target=c(0,0,0,0,0),
#                    dwin=c(1,.5,.33,.25,.2),
#                    dlose=c(0,0,0,0,0),
#                    ddraw=c(0,0,0,0,0))
#
#fitPM4 <- survfit(modelP.trk,newdata=scen1,individual=TRUE)
#plot(fitPM4)
#summary(fitPM4)
#
### create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly and loses
#scen1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
#                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
#                    d=c(0,0,0,0,0), ## failure indicator all to 0
#                    tmixed=c(1,1,1,1,1),
#                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
#                    tdemparl=c(0,0,0,0,0),
#                    txtdemparl=c(0,0,0,0,0),
#                    tdempres=c(0,0,0,0,0),
#                    txtdempres=c(0,0,0,0,0),
#                    civwar=c(0,0,0,0,0),
#                    lnmaddcap=c(7.828,7.846,7.864,7.882,7.900),
#                    txlnmaddcap=c(46.177,51.728,55.032,57.428,59.321),
#                    maddgrowth=c(1.82,1.82,1.82,1.82,1.82),
#                    lntropen1=c(1.93,1.93,1.93,1.93,1.93),
#                    tropen1chg=c(0.036,0.036,0.036,0.036,0.036),
#                    lnpop=c(8.923,8.923,8.923,8.923,8.923),
#                    txlnpop=c(52.636,58.829,62.443,65.012,67.002),
#                    age=c(51,51,51,51,51),
#                    txage=c(300.85,336.24,356.90,371.59,382.96),
#                    entry=c(0,0,0,0,0),
#                    txentry=c(0,0,0,0,0),
#                    powtimes=c(0,0,0,0,0),
#                    initiator=c(1,0,0,0,0),
#                    target=c(0,0,0,0,0),
#                    dwin=c(0,0,0,0,0),
#                    dlose=c(1,.5,.33,.25,.2),
#                    ddraw=c(0,0,0,0,0))
#
#fitPM4 <- survfit(modelP.trk,newdata=scen1,individual=TRUE)
#plot(fitPM4)
#summary(fitPM4)
