library(foreign)
library(survival)
library(norm)


LeaderR.data <- read.dta("C:/Hgoemans/Leaders/Fate/CRISK/JCR/Rfail.dta", convert.dates=FALSE)

attach(LeaderR.data)

summary(LeaderR.data)
sum(is.na(tmixed))
sum(is.na(tdemparl))
sum(is.na(tdempres))
sum(is.na(trans))
sum(is.na(civwar))
sum(is.na(lngdpcapL))
sum(is.na(growth))
sum(is.na(tropen2L))
sum(is.na(dopen2))
sum(is.na(lnpop))
sum(is.na(age)) #age is age in this observation
sum(is.na(age0)) #age0 is age at entry
sum(is.na(entry1))
sum(is.na(powtimes))
sum(is.na(initiator))
sum(is.na(defender))
sum(is.na(dwinsh))
sum(is.na(dlosesh))
sum(is.na(ddrawsh))
sum(is.na(initiator2))
sum(is.na(defender2))
sum(is.na(dwinwar))
sum(is.na(dlosewar))
sum(is.na(ddrawwar))
sum(is.na(ccode))

#LeaderP.2.data <- subset(LeaderR.data, tmixed!="NA")
#detach(LeaderR.data)
#attach(LeaderP.2.data)
#sum(is.na(tmixed))

median(t)
median(t)/365.25
(median(t)/365.25-as.integer(median(t)/365.25))*12
median(t[tmixed==1])
median(t[tmixed==1])/365.25
median(t[tdemparl==1])
median(t[tdemparl==1])/365.25
median(t[tdempres==1])
median(t[tdempres==1])/365.25
median(t[autoc==1])
median(t[autoc==1])/365.25
median(t[trans==1])/365.25

#Leader.data$t <- round(t,6)
#Leader.data$t0 <- round(t0,6)

LeaderR.data$txtmixed <- log(t)*tmixed
LeaderR.data$txtdemparl <- log(t)*tdemparl
LeaderR.data$txtdempres <- log(t)*tdempres
LeaderR.data$txtrans <- log(t)*trans
LeaderR.data$txentry1 <- log(t)*entry1
LeaderR.data$txcivwar <- log(t)*civwar
LeaderR.data$txlngcapL <- log(t)*lngdpcapL
LeaderR.data$txgrowth <- log(t)*growth
LeaderR.data$txtropen2L <- log(t)*tropen2L
LeaderR.data$txdopen2 <- log(t)*dopen2
LeaderR.data$txlnpop <- log(t)*lnpop
LeaderR.data$txage0 <- log(t)*age0
LeaderR.data$txinitiator <- log(t)*initiator
LeaderR.data$txinitiator2 <- log(t)*initiator2
LeaderR.data$txdefender <- log(t)*defender
LeaderR.data$txdefender2 <- log(t)*defender2
LeaderR.data$txinherit <- log(t)*inherit
LeaderR.data$txdwinsh <- log(t)*dwinsh
LeaderR.data$txdwinwar <- log(t)*dwinwar
LeaderR.data$txdlosesh <- log(t)*dlosesh
LeaderR.data$txdlose <- log(t)*dlose
LeaderR.data$txdlosesh <- log(t)*dlosesh
LeaderR.data$txdwin <- log(t)*dwin


attach(LeaderR.data)
#
#
#modelR1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
#                               + civwar + txcivwar
#                               + lngdpcapL + growth
#                               + tropen2L + txtropen2L + dopen2
#                               + lnpop 
#                               + age0 + txage0 + entry1 + txentry1 + powtimes
#                               + initiator2 + defender2 + inherit + onsetlead
#                               + dwinsh + dlosesh + txdlosesh + ddrawsh
#                               + dwinwar + dlosewar + ddrawwar
#                               + frailty(ccode), na.action=na.exclude, data=LeaderR.data,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#print(modelR1)
#also ran with frailty(leadid)
#modelP1.L <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
#                               + civwar + txcivwar
#                               + lngdpcapL + growth
#                               + tropen2L + txtropen2L + growth
#                               + lnpop 
#                               + age0 + txage0 + entry1 + txentry1 + powtimes
#                               + initiator2 + defender2 + inherit + onsetlead
#                               + dwinsh + dlosesh + txdlosesh + ddrawsh
#                               + dwinwar + dlosewar + ddrawwar
#                               + frailty(leadid), na.action=na.exclude, data=LeaderR.data,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#print(modelR1.L)


detach(LeaderR.data)
attach(LeaderR.data)

## Get the data as matrix
R.L <- as.matrix(LeaderR.data[,c('t','t0','d',
                     'tmixed','txtmixed','tdemparl','txtdemparl','tdempres','txtdempres','trans','txtrans',
                     'civwar','lngdpcapL','txlngcapL','growth',
                     'tropen2L','dopen2','lnpop','energy',
                     'age0','txage0','entry1','txentry1','powtimes',
                     'initiator2','defender2','inherit','onsetlead',
                     'dwin','dlose','ddraw','dwinsh','dlosesh', 'ddrawsh',
                     'dwinwar','dlosewar','ddrawwar')])

detach(LeaderR.data)


## missing value imputation
## prelim.norm does preliminary computations
## em.norm gives the EM estimates
## getparam gives the parameters back on original scale

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)


## bootstrap procedure to get EM estimates on a sample a quarter of the size of the whole sample
## this gives different starting values for the imputation, see Allison, 2002
set.seed(1510)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

## missing value imputation
s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)


## replace the mean mu and variances sigma computed on the entire dataset L
## with the mean mu and variances sigma computed on the smaller sample
## then, convert the values with the makeparam command
thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.1 is the first imputed data set
rngseed(4510)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.1 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.1$ccode <- LeaderR.data$ccode
attach(R.L.1)


## model with imputed data set R.L.1 without correction for ph violation

model1.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.R.L1)
## proportional hazard tests
fit.model1.R.L1 <- cox.zph(model1.R.L1, transform='identity')
print(fit.model1.R.L1)
#ph violations: growth, age0, entry1 and dlosesh fail. 

## more models, now collapsing conflict into one category


model0.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
print(model0.R.L1)
fit.model0.R.L1 <- cox.zph(model0.R.L1, transform='identity')
print(fit.model0.R.L1)
plot(fit.model0.R.L1[18])
#ph violations: 


model2.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.R.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L1 <- list(coef(model2.R.L1))
R.m2.se.L1 <- list(sqrt(diag(vcov(model2.R.L1))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L1 <- basehaz(model2.R.L1,centered=FALSE)

# model1.tx <- update(model1, .~. + txtmixed + txtdemparl + txtdempres + txtrans)

model3.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m3.coef.L1 <- list(coef(model3.R.L1))
R.m3.se.L1 <- list(sqrt(diag(vcov(model3.R.L1))))

detach(R.L.1)

## the following sections repeat the same operations; extracting a new sample from the
## main data set to get new starting values for the multiple imputation procedure

## Creating the second imputed data set

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6796)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.2 is the second imputed data set
rngseed(4894)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.2 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.2$ccode <- LeaderR.data$ccode
attach(R.L.2)


## model with imputed data set R.L.2 without correction for ph violation

model1.R.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.R.L2)
## proportional hazard tests
fit.model1.R.L2 <- cox.zph(model1.R.L2, transform='identity')
print(fit.model1.R.L2)


## more models, now collapsing conflict into one category

model0.R.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.R.L2 <- cox.zph(model0.R.L2, transform='identity')
print(fit.model0.R.L2)
print(model0.R.L2)

model2.R.L2 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL +growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.R.L2)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L2 <- list(coef(model2.R.L2))
R.m2.se.L2 <- list(sqrt(diag(vcov(model2.R.L2))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L2 <- basehaz(model2.R.L2,centered=FALSE)


model3.R.L2 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L2)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m3.coef.L2 <- list(coef(model3.R.L2))
R.m3.se.L2 <- list(sqrt(diag(vcov(model3.R.L2))))

detach(R.L.2)

##Now creating the third imputed data set

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6975)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.3 is the third imputed data set
rngseed(9329)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.3 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.3$ccode <- LeaderR.data$ccode
attach(R.L.3)


## model with imputed data set R.L.3 without correction for ph violation

model1.R.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.R.L3)
## proportional hazard tests
fit.model1.R.L3 <- cox.zph(model1.R.L3, transform='identity')
print(fit.model1.R.L3)


## more models, now collapsing conflict into one category

model0.R.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.R.L3 <- cox.zph(model0.R.L3, transform='identity')
print(fit.model0.R.L3)
print(model0.R.L3)

model2.R.L3 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL +growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.R.L3)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L3 <- list(coef(model2.R.L3))
R.m2.se.L3 <- list(sqrt(diag(vcov(model2.R.L3))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L3 <- basehaz(model2.R.L3,centered=FALSE)

model3.R.L3 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L3)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m3.coef.L3 <- list(coef(model3.R.L3))
R.m3.se.L3 <- list(sqrt(diag(vcov(model3.R.L3))))

detach(R.L.3)

# Now creating the fourth imputed data set

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(3038)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.4 is the fourth imputed data set
rngseed(5152)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.4 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.4$ccode <- LeaderR.data$ccode
attach(R.L.4)


## model with imputed data set R.L.4 without correction for ph violation

model1.R.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.R.L4)
## proportional hazard tests
fit.model1.R.L4 <- cox.zph(model1.R.L4, transform='identity')
print(fit.model1.R.L4)


## more models, now collapsing conflict into one category

model0.R.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.R.L4 <- cox.zph(model0.R.L4, transform='identity')
print(fit.model0.R.L4)
print(model0.R.L4)

model2.R.L4 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL +growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.R.L4)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L4 <- list(coef(model2.R.L4))
R.m2.se.L4 <- list(sqrt(diag(vcov(model2.R.L4))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L4 <- basehaz(model2.R.L4,centered=FALSE)


model3.R.L4 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L4)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m3.coef.L4 <- list(coef(model3.R.L4))
R.m3.se.L4 <- list(sqrt(diag(vcov(model3.R.L4))))

detach(R.L.4)

# Now the fifth and final imputed data set

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(2632)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.5 is the fifth imputed data set
rngseed(1138)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.5 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.5$ccode <- LeaderR.data$ccode
attach(R.L.5)


## model with imputed data set R.L.5 without correction for ph violation

model1.R.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.R.L5)
## proportional hazard tests
fit.model1.R.L5 <- cox.zph(model1.R.L5, transform='identity')
print(fit.model1.R.L5)


## more models, now collapsing conflict into one category

model0.R.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.R.L5 <- cox.zph(model0.R.L5, transform='identity')
print(fit.model0.R.L5)
print(model0.R.L5)

model2.R.L5 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL +growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
print(model2.R.L5)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L5 <- list(coef(model2.R.L5))
R.m2.se.L5 <- list(sqrt(diag(vcov(model2.R.L5))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L5 <- basehaz(model2.R.L5,centered=FALSE)


model3.R.L5 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit + onsetlead
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L5)

## get coefficients and standard errors from the models; used later below
R.m3.coef.L5 <- list(coef(model3.R.L5))
R.m3.se.L5 <- list(sqrt(diag(vcov(model3.R.L5))))

detach(R.L.5)




##################################################################################################
##################################################################################################

# model 0 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m0.R.rho <- cbind(fit.model0.R.L1$table[,1],fit.model0.R.L2$table[,1],fit.model0.R.L3$table[,1],fit.model0.R.L4$table[,1],
                fit.model0.R.L5$table[,1])  ## get the rhos

m0.R.rho.chi <- cbind(fit.model0.R.L1$table[,2],fit.model0.R.L2$table[,2],fit.model0.R.L3$table[,2],fit.model0.R.L4$table[,2],
                fit.model0.R.L5$table[,2])  ## get the chi-squares

m0.R.rho.bar <- apply(m0.R.rho,1,mean)   ## take the means of the rhos

m0.R.d.bar <- apply(m0.R.rho.chi,1,mean)  ## take the means of the chi-squares

m0.R.s2.rho <- apply(sqrt(m0.R.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m0.R.D.tilde <- (m0.R.d.bar-(1-1/M)*m0.R.s2.rho)/(1+(1+1/M)*m0.R.s2.rho)    ## D-tilde expression on p.590 of Rubin-Shenker
                                                                            ## k is equal to 1

m0.R.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m0.R.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                      ## of p.590 of Rubin-Shenker

m0.R.rho.imp <- round(cbind('rho'=m0.R.rho.bar,'D.tilde'=m0.R.D.tilde,'p-value'=pf(m0.R.D.tilde,1,m0.R.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m0.R.rho.imp)


plot(fit.model0.R.L1[1])
plot(fit.model0.R.L2[2])
plot(fit.model0.R.L3[3])
plot(fit.model0.R.L4[4])
plot(fit.model0.R.L5[6])

##################################################################################################
##################################################################################################

# model 1 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m1.R.rho <- cbind(fit.model1.R.L1$table[,1],fit.model1.R.L2$table[,1],fit.model1.R.L3$table[,1],fit.model1.R.L4$table[,1],
                fit.model1.R.L5$table[,1])  ## get the rhos

m1.R.rho.chi <- cbind(fit.model1.R.L1$table[,2],fit.model1.R.L2$table[,2],fit.model1.R.L3$table[,2],fit.model1.R.L4$table[,2],
                fit.model1.R.L5$table[,2])  ## get the chi-squares

m1.R.rho.bar <- apply(m1.R.rho,1,mean)   ## take the means of the rhos

m1.R.d.bar <- apply(m1.R.rho.chi,1,mean)  ## take the means of the chi-squares

m1.R.s2.rho <- apply(sqrt(m1.R.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m1.R.D.tilde <- (m1.R.d.bar-(1-1/M)*m1.R.s2.rho)/(1+(1+1/M)*m1.R.s2.rho)    ## D-tilde expression on p.590 of Rubin-Shenker
                                                                            ## k is equal to 1

m1.R.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m1.R.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                      ## of p.590 of Rubin-Shenker

m1.R.rho.imp <- round(cbind('rho'=m1.R.rho.bar,'D.tilde'=m1.R.D.tilde,'p-value'=pf(m1.R.D.tilde,1,m1.R.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m1.R.rho.imp)


plot(fit.model1.R.L1[6])
plot(fit.model1.R.L2[6])
plot(fit.model1.R.L3[6])
plot(fit.model1.R.L4[6])
plot(fit.model1.R.L5[1])

##################################################################################################
##################################################################################################


# model 2 -- coefficients

m2.R.b <- c(R.m2.coef.L1,R.m2.coef.L2,R.m2.coef.L3,R.m2.coef.L4,R.m2.coef.L5)
m2.R.s <- c(R.m2.se.L1,R.m2.se.L2,R.m2.se.L3,R.m2.se.L4,R.m2.se.L5)

model2.R.imp <- mi.inference(m2.R.b,m2.R.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model2.R.imp$est,'std.err'=model2.R.imp$std.err,'p-value'=model2.R.imp$signif),3)

# model 2 -- log likelihood
m2.R.llk <- mean(c(model2.R.L1$loglik[2],model2.R.L2$loglik[2],model2.R.L3$loglik[2],model2.R.L4$loglik[2],
               model2.R.L5$loglik[2]))

# model 2 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.R <- nrow(vcov(model2.R.L1))

m2.R.U <- (vcov(model2.R.L1)+vcov(model2.R.L2)+vcov(model2.R.L3)+vcov(model2.R.L4)+vcov(model2.R.L5))/M
                ## mean of var-cov matrixes

m2.R.A <- diag(1,k.R,k.R)

m2.R.zz1 <- (model2.R.L1$coef - model2.R.imp$est)%*%t(model2.R.L1$coef - model2.R.imp$est) ## (Theta-0 - Theta-bar) squared
m2.R.zz2 <- (model2.R.L2$coef - model2.R.imp$est)%*%t(model2.R.L2$coef - model2.R.imp$est)
m2.R.zz3 <- (model2.R.L3$coef - model2.R.imp$est)%*%t(model2.R.L3$coef - model2.R.imp$est)
m2.R.zz4 <- (model2.R.L4$coef - model2.R.imp$est)%*%t(model2.R.L4$coef - model2.R.imp$est)
m2.R.zz5 <- (model2.R.L5$coef - model2.R.imp$est)%*%t(model2.R.L5$coef - model2.R.imp$est)

m2.R.B <- (m2.R.zz1+m2.R.zz2+m2.R.zz3+m2.R.zz4+m2.R.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m2.R.rm <- (1+1/M)*sum(diag(m2.R.B%*%solve(m2.R.U)))/k.R   ## see r at top of p.590 of Rubin-Shenker

#m2.R.V <- (1+m2.R.rm)*m2.R.U

m2.R.Dm <- t(m2.R.A%*%model2.R.imp$est)%*%solve(m2.R.A%*%m2.R.U%*%t(m2.R.A))%*%(m2.R.A%*%model2.R.imp$est)/((1+m2.R.rm)*k.R) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m2.R.Dm) # This is the Wald test statistic

m2.R.a <- 1-2/(k.R*(M-1))                   ## a p.590 of Rubin-Shenker
m2.R.v <- 4+(k.R*(M-1)-4)*(1+m2.R.a/m2.R.rm)^2  ## w p.590 of Rubin-Shenker

m2.R.pval.Wald <- pf(m2.R.Dm,k.R,m2.R.v,lower.tail=FALSE)  ## F-test
print(m2.R.pval.Wald)


##################################################################################################
##################################################################################################


# model 3 -- coefficients

m3.R.b <- c(R.m3.coef.L1,R.m3.coef.L2,R.m3.coef.L3,R.m3.coef.L4,R.m3.coef.L5)
m3.R.s <- c(R.m3.se.L1,R.m3.se.L2,R.m3.se.L3,R.m3.se.L4,R.m3.se.L5)

model3.R.imp <- mi.inference(m3.R.b,m3.R.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model3.R.imp$est,'std.err'=model3.R.imp$std.err,'p-value'=model3.R.imp$signif),3)

# model 3 -- log likelihood
m3.R.llk <- mean(c(model3.R.L1$loglik[2],model3.R.L2$loglik[2],model3.R.L3$loglik[2],model3.R.L4$loglik[2],
               model3.R.L5$loglik[2]))

# model 3 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.R <- nrow(vcov(model3.R.L1))

m3.R.U <- (vcov(model3.R.L1)+vcov(model3.R.L2)+vcov(model3.R.L3)+vcov(model3.R.L4)+vcov(model3.R.L5))/M
                ## mean of var-cov matrixes

m3.R.A <- diag(1,k.R,k.R)

m3.R.zz1 <- (model3.R.L1$coef - model3.R.imp$est)%*%t(model3.R.L1$coef - model3.R.imp$est) ## (Theta-0 - Theta-bar) squared
m3.R.zz2 <- (model3.R.L2$coef - model3.R.imp$est)%*%t(model3.R.L2$coef - model3.R.imp$est)
m3.R.zz3 <- (model3.R.L3$coef - model3.R.imp$est)%*%t(model3.R.L3$coef - model3.R.imp$est)
m3.R.zz4 <- (model3.R.L4$coef - model3.R.imp$est)%*%t(model3.R.L4$coef - model3.R.imp$est)
m3.R.zz5 <- (model3.R.L5$coef - model3.R.imp$est)%*%t(model3.R.L5$coef - model3.R.imp$est)

m3.R.B <- (m3.R.zz1+m3.R.zz2+m3.R.zz3+m3.R.zz4+m3.R.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m3.R.rm <- (1+1/M)*sum(diag(m3.R.B%*%solve(m3.R.U)))/k.R   ## see r at top of p.590 of Rubin-Shenker

#m3.R.V <- (1+m3.R.rm)*m3.R.U

m3.R.Dm <- t(m3.R.A%*%model3.R.imp$est)%*%solve(m3.R.A%*%m3.R.U%*%t(m3.R.A))%*%(m3.R.A%*%model3.R.imp$est)/((1+m3.R.rm)*k.R) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m3.R.Dm) # This is the Wald test statistic

m3.R.a <- 1-2/(k.R*(M-1))                   ## a p.590 of Rubin-Shenker
m3.R.v <- 4+(k.R*(M-1)-4)*(1+m3.R.a/m3.R.rm)^2  ## w p.590 of Rubin-Shenker

m3.R.pval.Wald <- pf(m3.R.Dm,k.R,m3.R.v,lower.tail=FALSE)  ## F-test
print(m3.R.pval.Wald)



##################################################################################################
##################################################################################################


# frailty terms: Model2

print(model2.R.L1)
print(model2.R.L2)
print(model2.R.L3)
print(model2.R.L4)
print(model2.R.L5)

m2.R.frailty <- mean(c(model2.R.L1$history$"frailty(ccode)"$history[8,1], # number of outer iterations
                     model2.R.L2$history$"frailty(ccode)"$history[8,1],
                     model2.R.L3$history$"frailty(ccode)"$history[8,1],
                     model2.R.L4$history$"frailty(ccode)"$history[8,1],
                     model2.R.L5$history$"frailty(ccode)"$history[8,1]))


round(pgamma(1,1/m2.R.frailty,1/m2.R.frailty),3)
round(qgamma(.025,1/m2.R.frailty,1/m2.R.frailty),3)
round(qgamma(.975,1/m2.R.frailty,1/m2.R.frailty),3)

m2.R.frail.terms <- exp((model2.R.L1$frail+model2.R.L2$frail+model2.R.L3$frail+model2.R.L4$frail+model2.R.L5$frail)/5)

quantile(m2.R.frail.terms,probs=seq(0,1,.005))

#table(ccode)

cbind(m2.R.frail.terms,rep(NA,164)) #164 is the number of countries.

summary(m2.R.frail.terms)

max(m2.R.frail.terms)
min(m2.R.frail.terms)

country <- LeaderR.data$ccode
country <- unique(country)
country.frailty <- cbind(m2.R.frail.terms,country)
print(country.frailty)

round(100*(1-0.7768),2)       # ccode 200, UK
round(100*(1-1.2418),2)       # ccode 1, USA
round(100*(1-0.0016),2)       # ccode 710, China
round(100*(1-0.0998),2)       # ccode 678, Yemen
round(100*(1-0.0570),2)       # ccode 420, Gambia
round(100*(1-0.0811),2)       # ccode 760, Bhutan
round(100*(1-0.7585),2)       # ccode 750, India


m2.R.k.theta <- 95 # see df from model2.R.L5 from the frailty term
m2.R.d.bar.theta <- mean(c(TO BE DONE)) # Chi-square of the models
m2.R.s2.theta <- var(c(TO BE DONE)^.5)  # Chi-square of the models

m2.R.D.tilde.theta <- (m2.R.d.bar.theta/m2.R.k.theta - (1-1/M)*m2.R.s2.theta)/(1+(1+1/M)*m2.R.s2.theta)

m2.R.b.theta <- (m2.R.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m2.R.s2.theta)^(-1))^2

m2.R.frail.pval <- pf(m2.R.D.tilde.theta,m2.R.k.theta,m2.R.b.theta,lower.tail=FALSE)
print(m2.R.frail.pval)

#################################################################################################
##################################################################################################

# frailty terms: Model3

print(model3.R.L1)
print(model3.R.L2)
print(model3.R.L3)
print(model3.R.L4)
print(model3.R.L5)

m3.R.frailty <- mean(c(model3.R.L1$history$"frailty(ccode)"$history[8,1], # number of outer iterations
                     model3.R.L2$history$"frailty(ccode)"$history[8,1],
                     model3.R.L3$history$"frailty(ccode)"$history[8,1],
                     model3.R.L4$history$"frailty(ccode)"$history[8,1],
                     model3.R.L5$history$"frailty(ccode)"$history[8,1]))


round(pgamma(1,1/m3.R.frailty,1/m3.R.frailty),3)
round(qgamma(.025,1/m3.R.frailty,1/m3.R.frailty),3)
round(qgamma(.975,1/m3.R.frailty,1/m3.R.frailty),3)

m3.R.frail.terms <- exp((model3.R.L1$frail+model3.R.L2$frail+model3.R.L3$frail+model3.R.L4$frail+model3.R.L5$frail)/5)

quantile(m3.R.frail.terms,probs=seq(0,1,.01))

#table(ccode)

cbind(m3.R.frail.terms,rep(NA,164)) #164 is the number of countries.

max(m3.R.frail.terms)
min(m3.R.frail.terms)

country.frail.3 <- cbind(m3.R.frail.terms,country)
print(country.frail.3)

m3.R.k.theta <- 95 # see df from model3.R.L4 from the frailty term
m3.R.d.bar.theta <- mean(c(TO BE DONE)) # Chi-square of the models
m3.R.s2.theta <- var(c(TO BE DONE)^.5)  # Chi-square of the models

m3.R.D.tilde.theta <- (m3.R.d.bar.theta/m3.R.k.theta - (1-1/M)*m3.R.s2.theta)/(1+(1+1/M)*m3.R.s2.theta)

m3.R.b.theta <- (m3.R.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m3.R.s2.theta)^(-1))^2

m3.R.frail.pval <- pf(m3.R.D.tilde.theta,m3.R.k.theta,m3.R.b.theta,lower.tail=FALSE)
print(m3.R.frail.pval)

#################################################################################################
##################################################################################################


m2.R.part1 <- round(cbind('b'=model2.R.imp$est,'std.err'=model2.R.imp$std.err,'p-value'=model2.R.imp$signif),3)[1:27,] # first 26 coefficients
m2.R.part1 <- rbind(m2.R.part1,
                  'No. of obs.'=c(as.integer(model2.R.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(1319,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m2.R.llk,NA,NA), # log-llk
                  'Wald-test'=c(m2.R.Dm,m2.R.pval.Wald,NA), # wald test
                  'Theta'=c(m2.R.frailty,m2.R.D.tilde.theta,m2.R.frail.pval)) # frailty

m2.R.part1 <- round((m2.R.part1),3)
print(m2.R.part1)



m3.R.part1 <- round(cbind('b'=model3.R.imp$est,'std.err'=model3.R.imp$std.err,'p-value'=model3.R.imp$signif),3)[1:30,] # first 29 coefficients
m3.R.part1 <- rbind(m3.R.part1,
                  'No. of obs.'=c(as.integer(model3.R.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(1319,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m3.R.llk,NA,NA), # log-llk
                  'Wald-test'=c(m3.R.Dm,m3.R.pval.Wald,NA), # wald test
                  'Theta'=c(m3.R.frailty,m3.R.D.tilde.theta,m3.R.frail.pval)) # frailty

m3.R.part1 <- round((m3.R.part1),3)
print(m3.R.part1)


#################################################################################################
#################################################################################################
