library(foreign)
library(survival)
library(norm)


LeaderI.data <- read.dta("C:/Hgoemans/Leaders/Fate/CRISK/JCR/Ifail.dta", convert.dates=FALSE)

attach(LeaderI.data)

summary(LeaderI.data)
sum(is.na(tmixed))
sum(is.na(tdemparl))
sum(is.na(tdempres))
sum(is.na(trans))
sum(is.na(civwar))
sum(is.na(lngdpcapL))
sum(is.na(growth))
sum(is.na(tropen2L))
sum(is.na(dopen2))
sum(is.na(lnpop))
sum(is.na(age)) #age is age in this observation
sum(is.na(age0)) #age0 is age at entry
sum(is.na(entry1))
sum(is.na(powtimes))
sum(is.na(initiator))
sum(is.na(defender))
sum(is.na(dwinsh))
sum(is.na(dlosesh))
sum(is.na(ddrawsh))
sum(is.na(initiator2))
sum(is.na(defender2))
sum(is.na(dwinwar))
sum(is.na(dlosewar))
sum(is.na(ddrawwar))
sum(is.na(ccode))

#LeaderP.2.data <- subset(LeaderI.data, tmixed!="NA")
#detach(LeaderI.data)
#attach(LeaderP.2.data)
#sum(is.na(tmixed))

median(t)
median(t)/365.25
(median(t)/365.25-as.integer(median(t)/365.25))*12
median(t[tmixed==1])
median(t[tmixed==1])/365.25
median(t[tdemparl==1])
median(t[tdemparl==1])/365.25
median(t[tdempres==1])
median(t[tdempres==1])/365.25
median(t[autoc==1])
median(t[autoc==1])/365.25
median(t[trans==1])/365.25

#Leader.data$t <- round(t,6)
#Leader.data$t0 <- round(t0,6)

LeaderI.data$txtmixed <- log(t)*tmixed
LeaderI.data$txtdemparl <- log(t)*tdemparl
LeaderI.data$txtdempres <- log(t)*tdempres
LeaderI.data$txtrans <- log(t)*trans
LeaderI.data$txentry1 <- log(t)*entry1
LeaderI.data$txcivwar <- log(t)*civwar
LeaderI.data$txlngcapL <- log(t)*lngdpcapL
LeaderI.data$txgrowth <- log(t)*growth
LeaderI.data$txtropen2L <- log(t)*tropen2L
LeaderI.data$txdopen2 <- log(t)*dopen2
LeaderI.data$txlnpop <- log(t)*lnpop
LeaderI.data$txage0 <- log(t)*age0
LeaderI.data$txinitiator <- log(t)*initiator
LeaderI.data$txinitiator2 <- log(t)*initiator2
LeaderI.data$txdefender <- log(t)*defender
LeaderI.data$txdefender2 <- log(t)*defender2
LeaderI.data$txinherit <- log(t)*inherit
LeaderI.data$txdwinsh <- log(t)*dwinsh
LeaderI.data$txdwinwar <- log(t)*dwinwar
LeaderI.data$txdlosesh <- log(t)*dlosesh
LeaderI.data$txdlose <- log(t)*dlose
LeaderI.data$txdlosesh <- log(t)*dlosesh
LeaderI.data$txdwin <- log(t)*dwin


attach(LeaderI.data)

#
#modelI1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
#                               + civwar + txcivwar
#                               + lngdpcapL + growth
#                               + tropen2L + txtropen2L + dopen2
#                               + lnpop 
#                               + age0 + txage0 + entry1 + txentry1 + powtimes
#                               + initiator2 + defender2 + inherit
#                               + dwinsh + dlosesh + txdlosesh + ddrawsh
#                               + dwinwar + dlosewar + ddrawwar
#                               + frailty(ccode), na.action=na.exclude, data=LeaderI.data,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#print(modelI1)
#also ran with frailty(leadid)
#modelP1.L <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
#                               + civwar + txcivwar
#                               + lngdpcapL + growth
#                               + tropen2L + txtropen2L + growth
#                               + lnpop 
#                               + age0 + txage0 + entry1 + txentry1 + powtimes
#                               + initiator2 + defender2 + inherit
#                               + dwinsh + dlosesh + txdlosesh + ddrawsh
#                               + dwinwar + dlosewar + ddrawwar
#                               + frailty(leadid), na.action=na.exclude, data=LeaderI.data,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#print(modelR1.L)


detach(LeaderI.data)
attach(LeaderI.data)

## Get the data as matrix
I.L <- as.matrix(LeaderI.data[,c('t','t0','d',
                     'tmixed','tdemparl','tdempres','trans',
                     'civwar','txcivwar','lngdpcapL','growth',
                     'tropen2L','dopen2','lnpop','energy',
                     'age0','entry1','txentry1','powtimes',
                     'initiator2', 'defender2','inherit',
                     'dwin','dlose','ddraw','dwinsh','dlosesh', 'ddrawsh',
                     'dwinwar','dlosewar','ddrawwar')])

detach(LeaderI.data)


## missing value imputation
## prelim.norm does preliminary computations
## em.norm gives the EM estimates
## getparam gives the parameters back on original scale

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)


## bootstrap procedure to get EM estimates on a sample a quarter of the size of the whole sample
## this gives different starting values for the imputation, see Allison, 2002
set.seed(1510)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

## missing value imputation
s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)


## replace the mean mu and variances sigma computed on the entire dataset L
## with the mean mu and variances sigma computed on the smaller sample
## then, convert the values with the makeparam command
thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.1 is the first imputed data set
rngseed(4510)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.1 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.1$ccode <- LeaderI.data$ccode
attach(I.L.1)


## model with imputed data set I.L.1 without correction for ph violation

model1.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.I.L1)
## proportional hazard tests
fit.model1.I.L1 <- cox.zph(model1.I.L1, transform='identity')
print(fit.model1.I.L1)
#ph violations: growth, age0, entry1 and dlosesh fail. 

## more models, now collapsing conflict into one category


model0.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
print(model0.I.L1)
fit.model0.I.L1 <- cox.zph(model0.I.L1, transform='identity')
print(fit.model0.I.L1)
plot(fit.model0.I.L1[18])
#ph violations: 


model2.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.I.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L1 <- list(coef(model2.I.L1))
I.m2.se.L1 <- list(sqrt(diag(vcov(model2.I.L1))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L1 <- basehaz(model2.I.L1,centered=FALSE)

# model1.tx <- update(model1, .~. + txtmixed + txtdemparl + txtdempres + txtrans)

model3.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m3.coef.L1 <- list(coef(model3.I.L1))
I.m3.se.L1 <- list(sqrt(diag(vcov(model3.I.L1))))

detach(I.L.1)

## the following sections repeat the same operations; extracting a new sample from the
## main data set to get new starting values for the multiple imputation procedure

## Creating the second imputed data set

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6796)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.2 is the second imputed data set

rngseed(4894)

theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.2 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.2$ccode <- LeaderI.data$ccode
attach(I.L.2)


## model with imputed data set I.L.2 without correction for ph violation

model1.I.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.I.L2)
## proportional hazard tests
fit.model1.I.L2 <- cox.zph(model1.I.L2, transform='identity')
print(fit.model1.I.L2)


## more models, now collapsing conflict into one category

model0.I.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.I.L2 <- cox.zph(model0.I.L2, transform='identity')
print(fit.model0.I.L2)
print(model0.I.L2)

model2.I.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.I.L2)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L2 <- list(coef(model2.I.L2))
I.m2.se.L2 <- list(sqrt(diag(vcov(model2.I.L2))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L2 <- basehaz(model2.I.L2,centered=FALSE)


model3.I.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L2)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m3.coef.L2 <- list(coef(model3.I.L2))
I.m3.se.L2 <- list(sqrt(diag(vcov(model3.I.L2))))

detach(I.L.2)

##Now creating the third imputed data set

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6975)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.3 is the third imputed data set
rngseed(9329)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.3 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.3$ccode <- LeaderI.data$ccode
attach(I.L.3)


## model with imputed data set I.L.3 without correction for ph violation

model1.I.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.I.L3)
## proportional hazard tests
fit.model1.I.L3 <- cox.zph(model1.I.L3, transform='identity')
print(fit.model1.I.L3)


## more models, now collapsing conflict into one category

model0.I.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.I.L3 <- cox.zph(model0.I.L3, transform='identity')
print(fit.model0.I.L3)
print(model0.I.L3)

model2.I.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.I.L3)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L3 <- list(coef(model2.I.L3))
I.m2.se.L3 <- list(sqrt(diag(vcov(model2.I.L3))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L3 <- basehaz(model2.I.L3,centered=FALSE)

model3.I.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L3)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m3.coef.L3 <- list(coef(model3.I.L3))
I.m3.se.L3 <- list(sqrt(diag(vcov(model3.I.L3))))

detach(I.L.3)

# Now creating the fourth imputed data set

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(3038)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.4 is the fourth imputed data set
rngseed(5152)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.4 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.4$ccode <- LeaderI.data$ccode
attach(I.L.4)


## model with imputed data set I.L.4 without correction for ph violation

model1.I.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.I.L4)
## proportional hazard tests
fit.model1.I.L4 <- cox.zph(model1.I.L4, transform='identity')
print(fit.model1.I.L4)


## more models, now collapsing conflict into one category

model0.I.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.I.L4 <- cox.zph(model0.I.L4, transform='identity')
print(fit.model0.I.L4)
print(model0.I.L4)

model2.I.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.I.L4)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L4 <- list(coef(model2.I.L4))
I.m2.se.L4 <- list(sqrt(diag(vcov(model2.I.L4))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L4 <- basehaz(model2.I.L4,centered=FALSE)


model3.I.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L4)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m3.coef.L4 <- list(coef(model3.I.L4))
I.m3.se.L4 <- list(sqrt(diag(vcov(model3.I.L4))))

detach(I.L.4)

# Now the fifth and final imputed data set

s <- prelim.norm(I.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(2632)
trk <- seq(1,nrow(I.L),1)
boot.1 <- sample(trk,1+abs(nrow(I.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(I.L[boot.1,])  ## I.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## I.L.5 is the fifth imputed data set
rngseed(1138)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
I.L.5 <- as.data.frame(imp.norm(s,theta.1,I.L))

I.L.5$ccode <- LeaderI.data$ccode
attach(I.L.5)


## model with imputed data set I.L.5 without correction for ph violation

model1.I.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.I.L5)
## proportional hazard tests
fit.model1.I.L5 <- cox.zph(model1.I.L5, transform='identity')
print(fit.model1.I.L5)


## more models, now collapsing conflict into one category

model0.I.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.I.L5 <- cox.zph(model0.I.L5, transform='identity')
print(fit.model0.I.L5)
print(model0.I.L5)

model2.I.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=I.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
print(model2.I.L5)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
I.m2.coef.L5 <- list(coef(model2.I.L5))
I.m2.se.L5 <- list(sqrt(diag(vcov(model2.I.L5))))


## get the baseline hazard function; used later for the estimation of substantive effects
I.Ht.L5 <- basehaz(model2.I.L5,centered=FALSE)


model3.I.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.I.L5)

## get coefficients and standard errors from the models; used later below
I.m3.coef.L5 <- list(coef(model3.I.L5))
I.m3.se.L5 <- list(sqrt(diag(vcov(model3.I.L5))))

detach(I.L.5)



##################################################################################################
##################################################################################################

# model 0 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m0.I.rho <- cbind(fit.model0.I.L1$table[,1],fit.model0.I.L2$table[,1],fit.model0.I.L3$table[,1],fit.model0.I.L4$table[,1],
                fit.model0.I.L5$table[,1])  ## get the rhos

m0.I.rho.chi <- cbind(fit.model0.I.L1$table[,2],fit.model0.I.L2$table[,2],fit.model0.I.L3$table[,2],fit.model0.I.L4$table[,2],
                fit.model0.I.L5$table[,2])  ## get the chi-squares

m0.I.rho.bar <- apply(m0.I.rho,1,mean)   ## take the means of the rhos

m0.I.d.bar <- apply(m0.I.rho.chi,1,mean)  ## take the means of the chi-squares

m0.I.s2.rho <- apply(sqrt(m0.I.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m0.I.D.tilde <- (m0.I.d.bar-(1-1/M)*m0.I.s2.rho)/(1+(1+1/M)*m0.I.s2.rho)  ## D-tilde expression on p.590 of Rubin-Shenker
                                                                  ## k is equal to 1

m0.I.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m0.I.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                  ## of p.590 of Rubin-Shenker

m0.I.rho.imp <- round(cbind('rho'=m0.I.rho.bar,'D.tilde'=m0.I.D.tilde,'p-value'=pf(m0.I.D.tilde,1,m0.I.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m0.I.rho.imp)


plot(fit.model0.I.L1[1])
plot(fit.model0.I.L2[2])
plot(fit.model0.I.L3[3])
plot(fit.model0.I.L4[4])
plot(fit.model0.I.L5[5])

##################################################################################################
##################################################################################################

# model 1 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m1.I.rho <- cbind(fit.model1.I.L1$table[,1],fit.model1.I.L2$table[,1],fit.model1.I.L3$table[,1],fit.model1.I.L4$table[,1],
                fit.model1.I.L5$table[,1])  ## get the rhos

m1.I.rho.chi <- cbind(fit.model1.I.L1$table[,2],fit.model1.I.L2$table[,2],fit.model1.I.L3$table[,2],fit.model1.I.L4$table[,2],
                fit.model1.I.L5$table[,2])  ## get the chi-squares

m1.I.rho.bar <- apply(m1.I.rho,1,mean)   ## take the means of the rhos

m1.I.d.bar <- apply(m1.I.rho.chi,1,mean)  ## take the means of the chi-squares

m1.I.s2.rho <- apply(sqrt(m1.I.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m1.I.D.tilde <- (m1.I.d.bar-(1-1/M)*m1.I.s2.rho)/(1+(1+1/M)*m1.I.s2.rho)  ## D-tilde expression on p.590 of Rubin-Shenker
                                                                  ## k is equal to 1

m1.I.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m1.I.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                  ## of p.590 of Rubin-Shenker

m1.I.rho.imp <- round(cbind('rho'=m1.I.rho.bar,'D.tilde'=m1.I.D.tilde,'p-value'=pf(m1.I.D.tilde,1,m1.I.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m1.I.rho.imp)

plot(fit.model1.I.L1[5])
plot(fit.model1.I.L2[11])
plot(fit.model1.I.L3[12])
plot(fit.model1.I.L4[11])
plot(fit.model1.I.L5[20]) #Two outliers drive the violation.


##################################################################################################
##################################################################################################

# model 2 -- coefficients

m2.I.b <- c(I.m2.coef.L1,I.m2.coef.L2,I.m2.coef.L3,I.m2.coef.L4,I.m2.coef.L5)
m2.I.s <- c(I.m2.se.L1,I.m2.se.L2,I.m2.se.L3,I.m2.se.L4,I.m2.se.L5)

model2.I.imp <- mi.inference(m2.I.b,m2.I.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model2.I.imp$est,'std.err'=model2.I.imp$std.err,'p-value'=model2.I.imp$signif),3)

# model 2 -- log likelihood
m2.I.llk <- mean(c(model2.I.L1$loglik[2],model2.I.L2$loglik[2],model2.I.L3$loglik[2],model2.I.L4$loglik[2],
               model2.I.L5$loglik[2]))

# model 2 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.I <- nrow(vcov(model2.I.L1))

m2.I.U <- (vcov(model2.I.L1)+vcov(model2.I.L2)+vcov(model2.I.L3)+vcov(model2.I.L4)+vcov(model2.I.L5))/M
                ## mean of var-cov matrixes

m2.I.A <- diag(1,k.I,k.I)

m2.I.zz1 <- (model2.I.L1$coef - model2.I.imp$est)%*%t(model2.I.L1$coef - model2.I.imp$est) ## (Theta-0 - Theta-bar) squared
m2.I.zz2 <- (model2.I.L2$coef - model2.I.imp$est)%*%t(model2.I.L2$coef - model2.I.imp$est)
m2.I.zz3 <- (model2.I.L3$coef - model2.I.imp$est)%*%t(model2.I.L3$coef - model2.I.imp$est)
m2.I.zz4 <- (model2.I.L4$coef - model2.I.imp$est)%*%t(model2.I.L4$coef - model2.I.imp$est)
m2.I.zz5 <- (model2.I.L5$coef - model2.I.imp$est)%*%t(model2.I.L5$coef - model2.I.imp$est)

m2.I.B <- (m2.I.zz1+m2.I.zz2+m2.I.zz3+m2.I.zz4+m2.I.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m2.I.rm <- (1+1/M)*sum(diag(m2.I.B%*%solve(m2.I.U)))/k.I   ## see r at top of p.590 of Rubin-Shenker

#m2.I.V <- (1+m2.I.rm)*m2.I.U

m2.I.Dm <- t(m2.I.A%*%model2.I.imp$est)%*%solve(m2.I.A%*%m2.I.U%*%t(m2.I.A))%*%(m2.I.A%*%model2.I.imp$est)/((1+m2.I.rm)*k.I) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m2.I.Dm) # This is the Wald test statistic

m2.I.a <- 1-2/(k.I*(M-1))                   ## a p.590 of Rubin-Shenker
m2.I.v <- 4+(k.I*(M-1)-4)*(1+m2.I.a/m2.I.rm)^2  ## w p.590 of Rubin-Shenker

m2.I.pval.Wald <- pf(m2.I.Dm,k.I,m2.I.v,lower.tail=FALSE)  ## F-test
print(m2.I.pval.Wald)

##################################################################################################
##################################################################################################


# model 3 -- coefficients

m3.I.b <- c(I.m3.coef.L1,I.m3.coef.L2,I.m3.coef.L3,I.m3.coef.L4,I.m3.coef.L5)
m3.I.s <- c(I.m3.se.L1,I.m3.se.L2,I.m3.se.L3,I.m3.se.L4,I.m3.se.L5)

model3.I.imp <- mi.inference(m3.I.b,m3.I.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model3.I.imp$est,'std.err'=model3.I.imp$std.err,'p-value'=model3.I.imp$signif),3)

# model 3 -- log likelihood
m3.I.llk <- mean(c(model3.I.L1$loglik[2],model3.I.L2$loglik[2],model3.I.L3$loglik[2],model3.I.L4$loglik[2],
               model3.I.L5$loglik[2]))

# model 3 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.I <- nrow(vcov(model3.I.L1))

m3.I.U <- (vcov(model3.I.L1)+vcov(model3.I.L2)+vcov(model3.I.L3)+vcov(model3.I.L4)+vcov(model3.I.L5))/M
                ## mean of var-cov matrixes

m3.I.A <- diag(1,k.I,k.I)

m3.I.zz1 <- (model3.I.L1$coef - model3.I.imp$est)%*%t(model3.I.L1$coef - model3.I.imp$est) ## (Theta-0 - Theta-bar) squared
m3.I.zz2 <- (model3.I.L2$coef - model3.I.imp$est)%*%t(model3.I.L2$coef - model3.I.imp$est)
m3.I.zz3 <- (model3.I.L3$coef - model3.I.imp$est)%*%t(model3.I.L3$coef - model3.I.imp$est)
m3.I.zz4 <- (model3.I.L4$coef - model3.I.imp$est)%*%t(model3.I.L4$coef - model3.I.imp$est)
m3.I.zz5 <- (model3.I.L5$coef - model3.I.imp$est)%*%t(model3.I.L5$coef - model3.I.imp$est)

m3.I.B <- (m3.I.zz1+m3.I.zz2+m3.I.zz3+m3.I.zz4+m3.I.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k.I   ## see r at top of p.590 of Rubin-Shenker

#m3.I.V <- (1+m3.I.rm)*m3.I.U

m3.I.Dm <- t(m3.I.A%*%model3.I.imp$est)%*%solve(m3.I.A%*%m3.I.U%*%t(m3.I.A))%*%(m3.I.A%*%model3.I.imp$est)/((1+m3.I.rm)*k.I) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m3.I.Dm) # This is the Wald test statistic

m3.I.a <- 1-2/(k.I*(M-1))                   ## a p.590 of Rubin-Shenker
m3.I.v <- 4+(k.I*(M-1)-4)*(1+m3.I.a/m3.I.rm)^2  ## w p.590 of Rubin-Shenker

m3.I.pval.Wald <- pf(m3.I.Dm,k.I,m3.I.v,lower.tail=FALSE)  ## F-test
print(m3.I.pval.Wald)

##################################################################################################
##################################################################################################

# frailty terms Model0

print(model2.I.L1)
print(model2.I.L2)
print(model2.I.L3)
print(model2.I.L4)
print(model2.I.L5)

m2.I.frailty <- mean(c(model2.I.L1$history$"frailty(ccode)"$history[5,1], #number of outer iterations
                     model2.I.L2$history$"frailty(ccode)"$history[5,1],
                     model2.I.L3$history$"frailty(ccode)"$history[5,1],
                     model2.I.L4$history$"frailty(ccode)"$history[5,1],
                     model2.I.L5$history$"frailty(ccode)"$history[5,1]))


round(pgamma(1,1/m2.I.frailty,1/m2.I.frailty),3)
round(qgamma(.025,1/m2.I.frailty,1/m2.I.frailty),3)
round(qgamma(.975,1/m2.I.frailty,1/m2.I.frailty),3)

m2.I.frail.terms <- exp((model2.I.L1$frail+model2.I.L2$frail+model2.I.L3$frail+model2.I.L4$frail+model2.I.L5$frail)/5)

quantile(m2.I.frail.terms,probs=seq(0,1,.005))

table(ccode)

cbind(m2.I.frail.terms,rep(NA,164)) #164 is the number of countries.

max(m2.I.frail.terms)
min(m2.I.frail.terms)

summary(m2.I.frail.terms)

country <- LeaderI.data$ccode
country <- unique(country)
country.frailty <- cbind(m2.I.frail.terms,country)
print(country.frailty)

round(100*(1-0.5498),2)     # ccode 760, Bhutan
round(100*(1-0.9705),2)     # ccode 2, USA
round(100*(1-0.8038),2)     # ccode 200, UK


m2.I.k.theta <- 59.5 # see df from model2.I.L1 from the frailty term
m2.I.d.bar.theta <- mean(c(115.45,121.72,117.12,119.93,115.26)) # Chi-square of the models
m2.I.s2.theta <- var(c(115.45,121.72,117.12,119.93,115.26)^.5)  # Chi-square of the models

m2.I.D.tilde.theta <- (m2.I.d.bar.theta/m2.I.k.theta - (1-1/M)*m2.I.s2.theta)/(1+(1+1/M)*m2.I.s2.theta)

m2.I.b.theta <- (m2.I.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m2.I.s2.theta)^(-1))^2

m2.I.frail.pval <- pf(m2.I.D.tilde.theta,m2.I.k.theta,m2.I.b.theta,lower.tail=FALSE)
print(m2.I.frail.pval)

##################################################################################################
##################################################################################################

# frailty terms Model 3

print(model3.I.L1)
print(model3.I.L2)
print(model3.I.L3)
print(model3.I.L4)
print(model3.I.L5)

m3.I.frailty <- mean(c(model3.I.L1$history$"frailty(ccode)"$history[5,1], #number of outer iterations
                     model3.I.L2$history$"frailty(ccode)"$history[5,1],
                     model3.I.L3$history$"frailty(ccode)"$history[5,1],
                     model3.I.L4$history$"frailty(ccode)"$history[5,1],
                     model3.I.L5$history$"frailty(ccode)"$history[5,1]))


round(pgamma(1,1/m3.I.frailty,1/m3.I.frailty),3)
round(qgamma(.025,1/m3.I.frailty,1/m3.I.frailty),3)
round(qgamma(.975,1/m3.I.frailty,1/m3.I.frailty),3)

m3.I.frail.terms <- exp((model3.I.L1$frail+model3.I.L2$frail+model3.I.L3$frail+model3.I.L4$frail+model3.I.L5$frail)/5)

quantile(m3.I.frail.terms,probs=seq(0,1,.01))

table(ccode)

cbind(m3.I.frail.terms,rep(NA,164)) #164 is the number of countries.

max(m3.I.frail.terms)
min(m3.I.frail.terms)
country.frailty <- cbind(m3.I.frail.terms,country)
print(country.frailty)

m3.I.k.theta <- 57.5 # see df from model3.I.L1 from the frailty term
m3.I.d.bar.theta <- mean(c(110.36,116.00,113.08,115.72,108.94)) # Chi-square of the models
m3.I.s2.theta <- var(c(110.36,116.00,113.08,115.72,108.94)^.5)  # Chi-square of the models

m3.I.D.tilde.theta <- (m3.I.d.bar.theta/m3.I.k.theta - (1-1/M)*m3.I.s2.theta)/(1+(1+1/M)*m3.I.s2.theta)

m3.I.b.theta <- (m3.I.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m3.I.s2.theta)^(-1))^2

m3.I.frail.pval <- pf(m3.I.D.tilde.theta,m3.I.k.theta,m3.I.b.theta,lower.tail=FALSE)
print(m3.I.frail.pval)

##################################################################################################
##################################################################################################

m2.I.part1 <- round(cbind('b'=model2.I.imp$est,'std.err'=model2.I.imp$std.err,'p-value'=model2.I.imp$signif),3)[1:21,] # first 21 coefficients
m2.I.part1 <- rbind(m2.I.part1,
                  'No. of obs.'=c(as.integer(model2.I.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(477,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m2.I.llk,NA,NA), # log-llk
                  'Wald-test'=c(m2.I.Dm,m2.I.pval.Wald,NA), # wald test
                  'Theta'=c(m2.I.frailty,m2.I.D.tilde.theta,m2.I.frail.pval)) # frailty

m2.I.part1 <- round((m2.I.part1),3)
print(m2.I.part1)


m3.I.part1 <- round(cbind('b'=model3.I.imp$est,'std.err'=model3.I.imp$std.err,'p-value'=model3.I.imp$signif),3)[1:24,] # first 24 coefficients
m3.I.part1 <- rbind(m3.I.part1,
                  'No. of obs.'=c(as.integer(model3.I.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(477,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m3.I.llk,NA,NA), # log-llk
                  'Wald-test'=c(m3.I.Dm,m3.I.pval.Wald,NA), # wald test
                  'Theta'=c(m3.I.frailty,m3.I.D.tilde.theta,m3.I.frail.pval)) # frailty

m3.I.part1 <- round((m3.I.part1),3)
print(m3.I.part1)


##################################################################################################
##################################################################################################


Iscurve.3.L5 <- survfit(model3.I.L5)
attributes(Iscurve.3.L5)


plot(Iscurve.3.L5[[2]], Iscurve.3.L5[[5]],xlab="Days in Office",ylab="Survival Probability",main="How Leaders Lose Office",type="l",lty=1)
lines(Iscurve.3.L5[[2]],Iscurve.3.L5[[8]])
lines(Iscurve.3.L5[[2]],Iscurve.3.L5[[9]])


##################################################################################################
##################################################################################################



# time to zero effects

# Civil War

exp(-model3.I.imp$est[5]/model3.I.imp$est[6])/365.25 # Result is the coefficient associated with civil war==0

m3.I.Tm <- m3.I.U+(1+1/M)*m3.I.B

#Civil War: To get the p-values, 


2*pt(abs(model3.I.imp$est[5]+model3.I.imp$est[6]*log(365.25*(14/365)))/sqrt(m3.I.Tm[5,5]+(log(365.25*(14/365)))^2*m3.I.Tm[6,6]
      +2*log(365.25*(14/365))*m3.I.Tm[6,5]),200,lower.tail=FALSE)


2*pt(abs(model3.I.imp$est[5]+model3.I.imp$est[6]*log(365.25*.16))/sqrt(m3.I.Tm[5,5]+(log(365.25*.16))^2*m3.I.Tm[6,6]
      +2*log(365.25*.16)*m3.I.Tm[6,5]),200,lower.tail=FALSE)


# After about 2months in office, significantly more likely


2*pt(abs(model3.I.imp$est[5]+model3.I.imp$est[6]*log(365.25*.5))/sqrt(m3.I.Tm[5,5]+(log(365.25*.5))^2*m3.I.Tm[6,6]
      +2*log(365.25*.5)*m3.I.Tm[6,5]),200,lower.tail=FALSE)



2*pt(abs(model3.I.imp$est[5]+model3.I.imp$est[6]*log(365.25*10))/sqrt(m3.I.Tm[5,5]+(log(365.25*10))^2*m3.I.Tm[6,6]
      +2*log(365.25*10)*m3.I.Tm[6,5]),200,lower.tail=FALSE)
      

2*pt(abs(model3.I.imp$est[5]+model3.I.imp$est[6]*log(365.25*1000))/sqrt(m3.I.Tm[5,5]+(log(365.25*1000))^2*m3.I.Tm[6,6]
      +2*log(365.25*1000)*m3.I.Tm[6,5]),200,lower.tail=FALSE)

# Entry

exp(-model3.I.imp$est[13]/model3.I.imp$est[14])/365.25 # Result is the coefficient associated with entry = 0 after 2.24 years


2*pt(abs(model3.I.imp$est[13]+model3.I.imp$est[14]*log(365.25*3))/sqrt(m3.I.Tm[13,13]+(log(365.25*3))^2*m3.I.Tm[14,14]
      +2*log(365.25*3)*m3.I.Tm[14,13]),200,lower.tail=FALSE)
      
# After slightly more than 3 years,no longer(5\%) significantly different from 0.
 
2*pt(abs(model3.I.imp$est[13]+model3.I.imp$est[14]*log(365.25*5.2))/sqrt(m3.I.Tm[13,13]+(log(365.25*5.2))^2*m3.I.Tm[14,14]
      +2*log(365.25*5.2)*m3.I.Tm[14,13]),200,lower.tail=FALSE)

# After slightly more than 5 years, irregular entry decreases the hazard of an irregular removal

      
      
##################################################################################################
##################################################################################################

# Wald test -- H0: tdemparl == tdempres

k <- 1

Q <- as.matrix(t(rep(0,24)))
Q[2] <- 1
Q[3] <- -1

m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k

W.I.dems <- t(Q%*%model3.I.imp$est)%*%solve(Q%*%m3.I.U%*%t(Q))%*%(Q%*%model3.I.imp$est)/((1+m3.I.rm)*k)

m3.I.v <- .5*k*(M-1)*(1+1/k)*(1+m3.I.rm^(-1))^2 # Meng and Rubin (1992, 105)
print(m3.I.v)

pval.W.I.dems <- pf(W.I.dems,k,m3.I.v,lower.tail=FALSE)
print(pval.W.I.dems)



# Wald test -- H0: tdempres == trans

k <- 1

Q <- as.matrix(t(rep(0,24)))
Q[3] <- 1
Q[4] <- -1

m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k


W.I.dpT  <- t(Q%*%model3.I.imp$est)%*%solve(Q%*%m3.I.U%*%t(Q))%*%(Q%*%model3.I.imp$est)/((1+m3.I.rm)*k)

m3.I.v <- .5*k*(M-1)*(1+1/k)*(1+m3.I.rm^(-1))^2 # Meng and Rubin (1992, 105)
print(m3.I.v)

pval.W.I.dpt <- pf(W.I.dpT,k,m3.I.v,lower.tail=FALSE)
print(pval.W.I.dpt)


###################################################################################################
#Check formula!
###################################################################################################
## Wald tests on Model 3: check whether crisis and war outcomes differ.
#
## crisis challenger versus war challenger
#
#k <- 1
#
#Q <- as.matrix(t(rep(0,25)))
#Q[16] <- 1
#Q[21] <- -1
#
#m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k
#
#W.I.init <- t(Q%*%model3.I.imp$est)%*%solve(Q%*%m3.I.U%*%t(Q))%*%(Q%*%model3.I.imp$est)/((1+m3.I.rm)*k)
#
#m3.I.v <- .5*k*(M-1)*(1+1/k)*(1+m3.I.rm^(-1))^2 # Meng and Rubin (1992, 105)
#print(m3.I.v)
#
#pval.W.I.init <- pf(W.I.init,k,m3.I.v,lower.tail=FALSE)
#print(pval.W.I.init)
#
## crisis target versus war target
#
#
#k <- 1
#
#Q <- as.matrix(t(rep(0,25)))
#Q[17] <- 1
#Q[22] <- -1
#
#m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k
#
#W.I.targ <- t(Q%*%model3.I.imp$est)%*%solve(Q%*%m3.I.U%*%t(Q))%*%(Q%*%model3.I.imp$est)/((1+m3.I.rm)*k)
#
#m3.I.v <- .5*k*(M-1)*(1+1/k)*(1+m3.I.rm^(-1))^2 # Meng and Rubin (1992, 105)
#print(m3.I.v)
#
#pval.W.I.targ <- pf(W.I.targ,k,m3.I.v,lower.tail=FALSE)
#print(pval.W.I.targ)
#
## crisis victory versus war victory 
#
#
#k <- 1
#
#Q <- as.matrix(t(rep(0,25)))
#Q[18] <- 1
#Q[23] <- -1
#
#m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k
#
#W.I.vict <- t(Q%*%model3.I.imp$est)%*%solve(Q%*%m3.I.U%*%t(Q))%*%(Q%*%model3.I.imp$est)/((1+m3.I.rm)*k)
#
#m3.I.v <- .5*k*(M-1)*(1+1/k)*(1+m3.I.rm^(-1))^2 # Meng and Rubin (1992, 105)
#print(m3.I.v)
#
#pval.W.I.vict <- pf(W.I.vict,k,m3.I.v,lower.tail=FALSE)
#print(pval.W.I.vict)
#
## crisis defeat versus war defeat
#
#
#k <- 1
#
#Q <- as.matrix(t(rep(0,25)))
#Q[19] <- 1
#Q[24] <- -1
#
#m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k
#
#W.I.def <- t(Q%*%model3.I.imp$est)%*%solve(Q%*%m3.I.U%*%t(Q))%*%(Q%*%model3.I.imp$est)/((1+m3.I.rm)*k)
#
#m3.I.v <- .5*k*(M-1)*(1+1/k)*(1+m3.I.rm^(-1))^2 # Meng and Rubin (1992, 105)
#print(m3.I.v)
#
#pval.W.I.def <- pf(W.I.def,k,m3.I.v,lower.tail=FALSE)
#print(pval.W.I.def)
#
## crisis draw versus war draw
#
#
#k <- 1
#
#Q <- as.matrix(t(rep(0,25)))
#Q[17] <- 1
#Q[22] <- -1
#
#m3.I.rm <- (1+1/M)*sum(diag(m3.I.B%*%solve(m3.I.U)))/k
#
#W.I.draw <- t(Q%*%model3.I.imp$est)%*%solve(Q%*%m3.I.U%*%t(Q))%*%(Q%*%model3.I.imp$est)/((1+m3.I.rm)*k)
#
#m3.I.v <- .5*k*(M-1)*(1+1/k)*(1+m3.I.rm^(-1))^2 # Meng and Rubin (1992, 105)
#print(m3.I.v)
#
#pval.W.I.draw <- pf(W.I.draw,k,m3.I.v,lower.tail=FALSE)
#print(pval.W.I.draw)
#

##################################################################################################
##################################################################################################

## estimated effects


## See Therneau and Grambsch -- p.268--272

## estimate model with frailty term

model3.I.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


## estimate same model with no frailty
model3.trk <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans 
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar, 
                               na.action=na.exclude, data=I.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


## trick, assuming that the frailty==1

model3.trk$coefficients <- model3.I.L1$coefficients

summary(I.L.1)

#########################################################################################################
##SUBSTANTIVE EFFECTS : REGULAR ENTRY: Regime type at peace
#########################################################################################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly
scene.I.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.M1 <- survfit(model3.trk,newdata=scene.I.1,individual=TRUE)
plot(fit.I.M1)
summary(fit.I.M1)

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly
scene.I.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A1 <- survfit(model3.trk,newdata=scene.I.2,individual=TRUE)
plot(fit.I.A1)
summary(fit.I.A1)


## create data set with hypothetical scenario: A Democratic Parliamentary regime with a leader who enters regularly
scene.I.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPa1 <- survfit(model3.trk,newdata=scene.I.3,individual=TRUE)
plot(fit.I.DPa1)
summary(fit.I.DPa1)


## create data set with hypothetical scenario: A Democratic Presidential regime with a leader who enters regularly
scene.I.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPr1 <- survfit(model3.trk,newdata=scene.I.4,individual=TRUE)
plot(fit.I.DPr1)
summary(fit.I.DPr1)


## create data set with hypothetical scenario: A Transitional regime with a leader who enters regularly
scene.I.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T1 <- survfit(model3.trk,newdata=scene.I.5,individual=TRUE)
plot(fit.I.T1)
summary(fit.I.T1)

#########################################################################################################
##SUBSTANTIVE EFFECTS : IRREGULAR ENTRY & peace
#########################################################################################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters IRRegularly
scene.I.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.M1 <- survfit(model3.trk,newdata=scene.I.1,individual=TRUE)
plot(fit.I.M1)
summary(fit.I.M1)

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters IRRegularly
scene.I.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A1 <- survfit(model3.trk,newdata=scene.I.2,individual=TRUE)
plot(fit.I.A1)
summary(fit.I.A1)


## create data set with hypothetical scenario: A Democratic Parliamentary regime with a leader who enters IRREgulary
scene.I.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPa1 <- survfit(model3.trk,newdata=scene.I.3,individual=TRUE)
plot(fit.I.DPa1)
summary(fit.I.DPa1)


## create data set with hypothetical scenario: A Democratic Presidential regime with a leader who enters IRRegularly
scene.I.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPr1 <- survfit(model3.trk,newdata=scene.I.4,individual=TRUE)
plot(fit.I.DPr1)
summary(fit.I.DPr1)


## create data set with hypothetical scenario: A Transitional regime with a leader who enters rIRRegularly
scene.I.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T1 <- survfit(model3.trk,newdata=scene.I.5,individual=TRUE)
plot(fit.I.T1)
summary(fit.I.T1)

#################################################################################################################################
#################################################################################################################################
#################################################################################################################################
######      SUBSTANTIVE EFFECTS : REGULAR ENTRY: CONFLICT : Initiation + Victory in a CRISIS      ###############################
#################################################################################################################################
#################################################################################################################################
#################################################################################################################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and Wins a Crisis
scene.I.1.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.M2 <- survfit(model3.trk,newdata=scene.I.1.1,individual=TRUE)
plot(fit.I.M2)
summary(fit.I.M2)

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and LOSES
scene.I.1.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
fit.I.M3 <- survfit(model3.trk,newdata=scene.I.1.2,individual=TRUE)
plot(fit.I.M3)
summary(fit.I.M3)


## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and DRAWS
scene.I.1.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
                    
fit.I.M4 <- survfit(model3.trk,newdata=scene.I.1.4,individual=TRUE)
plot(fit.I.M4)
summary(fit.I.M4)

#############################################
#### Now for Wars ###########################
#############################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and Wins a WAR


scene.I.1.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.M5 <- survfit(model3.trk,newdata=scene.I.1.5,individual=TRUE)
plot(fit.I.M5)
summary(fit.I.M5)

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and LOSES
scene.I.1.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))
                    
fit.I.M6 <- survfit(model3.trk,newdata=scene.I.1.6,individual=TRUE)
plot(fit.I.M6)
summary(fit.I.M6)


## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and DRAWS
scene.I.1.7 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))
                    
fit.I.M7 <- survfit(model3.trk,newdata=scene.I.1.7,individual=TRUE)
plot(fit.I.M7)
summary(fit.I.M7)


##############################################################################################################################
##############################################################################################################################
#############################################################################################################################

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and wins a CRISIS
scene.I.2.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A2 <- survfit(model3.trk,newdata=scene.I.2.1,individual=TRUE)
plot(fit.I.A2)
summary(fit.I.A2)


## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and loses
scene.I.2.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A3 <- survfit(model3.trk,newdata=scene.I.2.2,individual=TRUE)
plot(fit.I.A3)
summary(fit.I.A3)

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and DRAWS
scene.I.2.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A4 <- survfit(model3.trk,newdata=scene.I.2.3,individual=TRUE)
plot(fit.I.A4)
summary(fit.I.A4)

############################
### Now for WARS  ##########
############################

scene.I.2.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
                    
fit.I.A5 <- survfit(model3.trk,newdata=scene.I.2.4,individual=TRUE)
plot(fit.I.A5)
summary(fit.I.A5)


scene.I.2.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A6 <- survfit(model3.trk,newdata=scene.I.2.5,individual=TRUE)
plot(fit.I.A6)
summary(fit.I.A6)

                    
scene.I.2.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))

fit.I.A7 <- survfit(model3.trk,newdata=scene.I.2.6,individual=TRUE)
plot(fit.I.A7)
summary(fit.I.A7)


##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


## create data set with hypothetical scenario: A Parliamentary Democratic leader who enters regularly, initiates + wins CRISIS

scene.I.3.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPa2 <- survfit(model3.trk,newdata=scene.I.3.1,individual=TRUE)
plot(fit.I.DPa2)
summary(fit.I.DPa2)


## create data set with hypothetical scenario: A Parliamentary Democratic regime with a leader who enters regularly, initiates + loses

scene.I.3.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPa3 <- survfit(model3.trk,newdata=scene.I.3.2,individual=TRUE)
plot(fit.I.DPa3)
summary(fit.I.DPa3)


## create data set with hypothetical scenario: A Parliamentary Democratic regime with a leader who enters regularly, initiates + DRAW

scene.I.3.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPa4 <- survfit(model3.trk,newdata=scene.I.3.3,individual=TRUE)
plot(fit.I.DPa4)
summary(fit.I.DPa4)

#############################################
## Now for Wars  ############################
#############################################


scene.I.3.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPa5 <- survfit(model3.trk,newdata=scene.I.3.4,individual=TRUE)
plot(fit.I.DPa5)
summary(fit.I.DPa5)

scene.I.3.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPa6 <- survfit(model3.trk,newdata=scene.I.3.5,individual=TRUE)
plot(fit.I.DPa6)
summary(fit.I.DPa6)

scene.I.3.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))


fit.I.DPa7 <- survfit(model3.trk,newdata=scene.I.3.6,individual=TRUE)
plot(fit.I.DPa7)
summary(fit.I.DPa7)

##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


## create data set with hypothetical scenario: A Presidential Democratic leader who enters regularly initiates + wins a CRISIS



scene.I.4.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPr2 <- survfit(model3.trk,newdata=scene.I.4.1,individual=TRUE)
plot(fit.I.DPr2)
summary(fit.I.DPr2)


## create data set with hypothetical scenario: A Presidential Democratic regime with a leader who enters regularly initiates + LOSES

scene.I.4.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    age0=c(50,50,50,50,50),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPr3 <- survfit(model3.trk,newdata=scene.I.4.2,individual=TRUE)
plot(fit.I.DPr3)
summary(fit.I.DPr3)



## create data set with hypothetical scenario: A Presidential Democratic regime with a leader who enters regularly initiates + DRAWS

scene.I.4.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPr4 <- survfit(model3.trk,newdata=scene.I.4.3,individual=TRUE)
plot(fit.I.DPr4)
summary(fit.I.DPr4)


###################################
#### Now for WARS  ################
###################################


scene.I.4.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPr5 <- survfit(model3.trk,newdata=scene.I.4.4,individual=TRUE)
plot(fit.I.DPr5)
summary(fit.I.DPr5)


scene.I.4.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPr6 <- survfit(model3.trk,newdata=scene.I.4.5,individual=TRUE)
plot(fit.I.DPr6)
summary(fit.I.DPr6)

scene.I.4.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))


fit.I.DPr7 <- survfit(model3.trk,newdata=scene.I.4.4,individual=TRUE)
plot(fit.I.DPr7)
summary(fit.I.DPr7)

##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


# Now for leaders of Regimes in Transition. First CRISES.


scene.I.5.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T2 <- survfit(model3.trk,newdata=scene.I.5.1,individual=TRUE)
plot(fit.I.T2) 
summary(fit.I.T2)



scene.I.5.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T3 <- survfit(model3.trk,newdata=scene.I.5.2,individual=TRUE)
plot(fit.I.T3) 
summary(fit.I.T3)


scene.I.5.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T4 <- survfit(model3.trk,newdata=scene.I.5.3,individual=TRUE)
plot(fit.I.T4) 
summary(fit.I.T4)

#######################################
### Now for WARS ######################
#######################################


scene.I.5.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T5 <- survfit(model3.trk,newdata=scene.I.5.4,individual=TRUE)
plot(fit.I.T5) 
summary(fit.I.T5)


scene.I.5.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T6 <- survfit(model3.trk,newdata=scene.I.5.5,individual=TRUE)
plot(fit.I.T6) 
summary(fit.I.T6)


scene.I.5.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))

fit.I.T7 <- survfit(model3.trk,newdata=scene.I.5.6,individual=TRUE)
plot(fit.I.T7) 
summary(fit.I.T7)


###########################################################################################################################################
###########################################################################################################################################
###########################################################################################################################################
##################@@################################      IRREGULAR ENTRY  + OUTCOMES       #################################################
###########################################################################################################################################
###########################################################################################################################################
###########################################################################################################################################



## create data set with hypothetical scenario: A Mixed regime with a leader who enters Irregularly, Initiates and Wins a Crisis
scene.I.1.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.M2 <- survfit(model3.trk,newdata=scene.I.1.1,individual=TRUE)
plot(fit.I.M2)
summary(fit.I.M2)

## create data set with hypothetical scenario: A Mixed regime with a leader who enters Irregularly Initiates and LOSES
scene.I.1.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
fit.I.M3 <- survfit(model3.trk,newdata=scene.I.1.2,individual=TRUE)
plot(fit.I.M3)
summary(fit.I.M3)


## create data set with hypothetical scenario: A Mixed regime with a leader who enters irregularly Initiates and DRAWS
scene.I.1.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
                    
fit.I.M4 <- survfit(model3.trk,newdata=scene.I.1.4,individual=TRUE)
plot(fit.I.M4)
summary(fit.I.M4)

#############################################
#### Now for Wars ###########################
#############################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters irregularly Initiates and Wins a WAR


scene.I.1.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.M5 <- survfit(model3.trk,newdata=scene.I.1.5,individual=TRUE)
plot(fit.I.M5)
summary(fit.I.M5)

## create data set with hypothetical scenario: A Mixed regime with a leader who enters irregularly Initiates and LOSES
scene.I.1.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))
                    
fit.I.M6 <- survfit(model3.trk,newdata=scene.I.1.6,individual=TRUE)
plot(fit.I.M6)
summary(fit.I.M6)


## create data set with hypothetical scenario: A Mixed regime with a leader who enters irregularly Initiates and DRAWS
scene.I.1.7 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))
                    
fit.I.M7 <- survfit(model3.trk,newdata=scene.I.1.7,individual=TRUE)
plot(fit.I.M7)
summary(fit.I.M7)


##############################################################################################################################
##############################################################################################################################
#############################################################################################################################

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters irregularly, initiates and wins a CRISIS
scene.I.2.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A2 <- survfit(model3.trk,newdata=scene.I.2.1,individual=TRUE)
plot(fit.I.A2)
summary(fit.I.A2)


## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters irregularly, initiates and loses
scene.I.2.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A3 <- survfit(model3.trk,newdata=scene.I.2.2,individual=TRUE)
plot(fit.I.A3)
summary(fit.I.A3)

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters irregularly, initiates and DRAWS
scene.I.2.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A4 <- survfit(model3.trk,newdata=scene.I.2.3,individual=TRUE)
plot(fit.I.A4)
summary(fit.I.A4)

############################
### Now for WARS  ##########
############################

scene.I.2.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
                    
fit.I.A5 <- survfit(model3.trk,newdata=scene.I.2.4,individual=TRUE)
plot(fit.I.A5)
summary(fit.I.A5)


scene.I.2.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fit.I.A6 <- survfit(model3.trk,newdata=scene.I.2.5,individual=TRUE)
plot(fit.I.A6)
summary(fit.I.A6)

                    
scene.I.2.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))

fit.I.A7 <- survfit(model3.trk,newdata=scene.I.2.6,individual=TRUE)
plot(fit.I.A7)
summary(fit.I.A7)


##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


## create data set with hypothetical scenario: A Parliamentary Democratic leader who enters irregularly, initiates + wins CRISIS

scene.I.3.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPa2 <- survfit(model3.trk,newdata=scene.I.3.1,individual=TRUE)
plot(fit.I.DPa2)
summary(fit.I.DPa2)


## create data set with hypothetical scenario: A Parliamentary Democratic regime with a leader who enters irregularly, initiates + loses

scene.I.3.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPa3 <- survfit(model3.trk,newdata=scene.I.3.2,individual=TRUE)
plot(fit.I.DPa3)
summary(fit.I.DPa3)


## create data set with hypothetical scenario: A Parliamentary Democratic regime with a leader who enters irregularly, initiates + DRAW

scene.I.3.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPa4 <- survfit(model3.trk,newdata=scene.I.3.3,individual=TRUE)
plot(fit.I.DPa4)
summary(fit.I.DPa4)

#############################################
## Now for Wars  ############################
#############################################


scene.I.3.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPa5 <- survfit(model3.trk,newdata=scene.I.3.4,individual=TRUE)
plot(fit.I.DPa5)
summary(fit.I.DPa5)

scene.I.3.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPa6 <- survfit(model3.trk,newdata=scene.I.3.5,individual=TRUE)
plot(fit.I.DPa6)
summary(fit.I.DPa6)

scene.I.3.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    tdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))


fit.I.DPa7 <- survfit(model3.trk,newdata=scene.I.3.6,individual=TRUE)
plot(fit.I.DPa7)
summary(fit.I.DPa7)

##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


## create data set with hypothetical scenario: A Presidential Democratic leader who enters irregularly initiates + wins a CRISIS



scene.I.4.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPr2 <- survfit(model3.trk,newdata=scene.I.4.1,individual=TRUE)
plot(fit.I.DPr2)
summary(fit.I.DPr2)


## create data set with hypothetical scenario: A Presidential Democratic regime with a leader who enters irregularly initiates + LOSES

scene.I.4.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPr3 <- survfit(model3.trk,newdata=scene.I.4.2,individual=TRUE)
plot(fit.I.DPr3)
summary(fit.I.DPr3)



## create data set with hypothetical scenario: A Presidential Democratic regime with a leader who enters irregularly initiates + DRAWS

scene.I.4.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPr4 <- survfit(model3.trk,newdata=scene.I.4.3,individual=TRUE)
plot(fit.I.DPr4)
summary(fit.I.DPr4)


###################################
#### Now for WARS  ################
###################################


scene.I.4.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.DPr5 <- survfit(model3.trk,newdata=scene.I.4.4,individual=TRUE)
plot(fit.I.DPr5)
summary(fit.I.DPr5)


scene.I.4.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))


fit.I.DPr6 <- survfit(model3.trk,newdata=scene.I.4.5,individual=TRUE)
plot(fit.I.DPr6)
summary(fit.I.DPr6)

scene.I.4.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    trans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))


fit.I.DPr7 <- survfit(model3.trk,newdata=scene.I.4.4,individual=TRUE)
plot(fit.I.DPr7)
summary(fit.I.DPr7)

##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


# Now for leaders of Regimes in Transition. First CRISES.


scene.I.5.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T2 <- survfit(model3.trk,newdata=scene.I.5.1,individual=TRUE)
plot(fit.I.T2) 
summary(fit.I.T2)



scene.I.5.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T3 <- survfit(model3.trk,newdata=scene.I.5.2,individual=TRUE)
plot(fit.I.T3) 
summary(fit.I.T3)


scene.I.5.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T4 <- survfit(model3.trk,newdata=scene.I.5.3,individual=TRUE)
plot(fit.I.T4) 
summary(fit.I.T4)

#######################################
### Now for WARS ######################
#######################################


scene.I.5.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T5 <- survfit(model3.trk,newdata=scene.I.5.4,individual=TRUE)
plot(fit.I.T5) 
summary(fit.I.T5)


scene.I.5.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fit.I.T6 <- survfit(model3.trk,newdata=scene.I.5.5,individual=TRUE)
plot(fit.I.T6) 
summary(fit.I.T6)


scene.I.5.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    civwar=c(0,0,0,0,0),
                    txcivwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))

fit.I.T7 <- survfit(model3.trk,newdata=scene.I.5.6,individual=TRUE)
plot(fit.I.T7) 
summary(fit.I.T7)
