library(foreign)
library(survival)
library(norm)


LeaderR.data <- read.dta("C:/Hgoemans/Leaders/Fate/CRISK/JCR/Rfail.dta", convert.dates=FALSE)

attach(LeaderR.data)

summary(LeaderR.data)
sum(is.na(tmixed))
sum(is.na(tdemparl))
sum(is.na(tdempres))
sum(is.na(trans))
sum(is.na(civwar))
sum(is.na(lngdpcapL))
sum(is.na(growth))
sum(is.na(tropen2L))
sum(is.na(dopen2))
sum(is.na(lnpop))
sum(is.na(age)) #age is age in this observation
sum(is.na(age0)) #age0 is age at entry
sum(is.na(entry1))
sum(is.na(powtimes))
sum(is.na(initiator))
sum(is.na(defender))
sum(is.na(dwinsh))
sum(is.na(dlosesh))
sum(is.na(ddrawsh))
sum(is.na(initiator2))
sum(is.na(defender2))
sum(is.na(dwinwar))
sum(is.na(dlosewar))
sum(is.na(ddrawwar))
sum(is.na(ccode))

#LeaderP.2.data <- subset(LeaderR.data, tmixed!="NA")
#detach(LeaderR.data)
#attach(LeaderP.2.data)
#sum(is.na(tmixed))

median(t)
median(t)/365.25
(median(t)/365.25-as.integer(median(t)/365.25))*12
median(t[tmixed==1])
median(t[tmixed==1])/365.25
median(t[tdemparl==1])
median(t[tdemparl==1])/365.25
median(t[tdempres==1])
median(t[tdempres==1])/365.25
median(t[autoc==1])
median(t[autoc==1])/365.25
median(t[trans==1])/365.25

#Leader.data$t <- round(t,6)
#Leader.data$t0 <- round(t0,6)

LeaderR.data$txtmixed <- log(t)*tmixed
LeaderR.data$txtdemparl <- log(t)*tdemparl
LeaderR.data$txtdempres <- log(t)*tdempres
LeaderR.data$txtrans <- log(t)*trans
LeaderR.data$txentry1 <- log(t)*entry1
LeaderR.data$txcivwar <- log(t)*civwar
LeaderR.data$txlngcapL <- log(t)*lngdpcapL
LeaderR.data$txgrowth <- log(t)*growth
LeaderR.data$txtropen2L <- log(t)*tropen2L
LeaderR.data$txdopen2 <- log(t)*dopen2
LeaderR.data$txlnpop <- log(t)*lnpop
LeaderR.data$txage0 <- log(t)*age0
LeaderR.data$txinitiator <- log(t)*initiator
LeaderR.data$txinitiator2 <- log(t)*initiator2
LeaderR.data$txdefender <- log(t)*defender
LeaderR.data$txdefender2 <- log(t)*defender2
LeaderR.data$txinherit <- log(t)*inherit
LeaderR.data$txdwinsh <- log(t)*dwinsh
LeaderR.data$txdwinwar <- log(t)*dwinwar
LeaderR.data$txdlosesh <- log(t)*dlosesh
LeaderR.data$txdlose <- log(t)*dlose
LeaderR.data$txdlosesh <- log(t)*dlosesh
LeaderR.data$txdwin <- log(t)*dwin


attach(LeaderR.data)


modelR1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
                               + civwar + txcivwar
                               + lngdpcapL + growth
                               + tropen2L + txtropen2L + dopen2
                               + lnpop 
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + txdlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=LeaderR.data,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(modelR1)
#also ran with frailty(leadid)
#modelP1.L <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + trans
#                               + civwar + txcivwar
#                               + lngdpcapL + growth
#                               + tropen2L + txtropen2L + growth
#                               + lnpop 
#                               + age0 + txage0 + entry1 + txentry1 + powtimes
#                               + initiator2 + defender2 + inherit
#                               + dwinsh + dlosesh + txdlosesh + ddrawsh
#                               + dwinwar + dlosewar + ddrawwar
#                               + frailty(leadid), na.action=na.exclude, data=LeaderR.data,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
#
#print(modelR1.L)


detach(LeaderR.data)
attach(LeaderR.data)

## Get the data as matrix
R.L <- as.matrix(LeaderR.data[,c('t','t0','d',
                     'tmixed','txtmixed','tdemparl','txtdemparl','tdempres','txtdempres','trans','txtrans',
                     'civwar','lngdpcapL','txlngcapL','growth',
                     'tropen2L','dopen2','lnpop','energy',
                     'age0','txage0','entry1','txentry1','powtimes',
                     'initiator2','defender2','inherit',
                     'dwin','dlose','ddraw','dwinsh','dlosesh', 'ddrawsh',
                     'dwinwar','dlosewar','ddrawwar')])

detach(LeaderR.data)


## missing value imputation
## prelim.norm does preliminary computations
## em.norm gives the EM estimates
## getparam gives the parameters back on original scale

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)


## bootstrap procedure to get EM estimates on a sample a quarter of the size of the whole sample
## this gives different starting values for the imputation, see Allison, 2002
set.seed(1510)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

## missing value imputation
s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)


## replace the mean mu and variances sigma computed on the entire dataset L
## with the mean mu and variances sigma computed on the smaller sample
## then, convert the values with the makeparam command
thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.1 is the first imputed data set
rngseed(4510)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.1 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.1$ccode <- LeaderR.data$ccode
attach(R.L.1)


## model with imputed data set R.L.1 without correction for ph violation

model1.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.R.L1)
## proportional hazard tests
fit.model1.R.L1 <- cox.zph(model1.R.L1, transform='identity')
print(fit.model1.R.L1)
#ph violations: growth, age0, entry1 and dlosesh fail. 

## more models, now collapsing conflict into one category


model0.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
print(model0.R.L1)
fit.model0.R.L1 <- cox.zph(model0.R.L1, transform='identity')
print(fit.model0.R.L1)
plot(fit.model0.R.L1[18])
#ph violations: 


model2.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL + growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.R.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L1 <- list(coef(model2.R.L1))
R.m2.se.L1 <- list(sqrt(diag(vcov(model2.R.L1))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L1 <- basehaz(model2.R.L1,centered=FALSE)

# model1.tx <- update(model1, .~. + txtmixed + txtdemparl + txtdempres + txtrans)

model3.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L1)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m3.coef.L1 <- list(coef(model3.R.L1))
R.m3.se.L1 <- list(sqrt(diag(vcov(model3.R.L1))))

detach(R.L.1)

## the following sections repeat the same operations; extracting a new sample from the
## main data set to get new starting values for the multiple imputation procedure

## Creating the second imputed data set

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6796)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.2 is the second imputed data set
rngseed(4894)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.2 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.2$ccode <- LeaderR.data$ccode
attach(R.L.2)


## model with imputed data set R.L.2 without correction for ph violation

model1.R.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.R.L2)
## proportional hazard tests
fit.model1.R.L2 <- cox.zph(model1.R.L2, transform='identity')
print(fit.model1.R.L2)


## more models, now collapsing conflict into one category

model0.R.L2 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.R.L2 <- cox.zph(model0.R.L2, transform='identity')
print(fit.model0.R.L2)
print(model0.R.L2)

model2.R.L2 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL +growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.R.L2)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L2 <- list(coef(model2.R.L2))
R.m2.se.L2 <- list(sqrt(diag(vcov(model2.R.L2))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L2 <- basehaz(model2.R.L2,centered=FALSE)


model3.R.L2 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.2,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L2)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m3.coef.L2 <- list(coef(model3.R.L2))
R.m3.se.L2 <- list(sqrt(diag(vcov(model3.R.L2))))

detach(R.L.2)

##Now creating the third imputed data set

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(6975)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.3 is the third imputed data set
rngseed(9329)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.3 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.3$ccode <- LeaderR.data$ccode
attach(R.L.3)


## model with imputed data set R.L.3 without correction for ph violation

model1.R.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.R.L3)
## proportional hazard tests
fit.model1.R.L3 <- cox.zph(model1.R.L3, transform='identity')
print(fit.model1.R.L3)


## more models, now collapsing conflict into one category

model0.R.L3 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.R.L3 <- cox.zph(model0.R.L3, transform='identity')
print(fit.model0.R.L3)
print(model0.R.L3)

model2.R.L3 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL +growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.R.L3)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L3 <- list(coef(model2.R.L3))
R.m2.se.L3 <- list(sqrt(diag(vcov(model2.R.L3))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L3 <- basehaz(model2.R.L3,centered=FALSE)

model3.R.L3 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.3,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L3)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m3.coef.L3 <- list(coef(model3.R.L3))
R.m3.se.L3 <- list(sqrt(diag(vcov(model3.R.L3))))

detach(R.L.3)

# Now creating the fourth imputed data set

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(3038)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.4 is the fourth imputed data set
rngseed(5152)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.4 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.4$ccode <- LeaderR.data$ccode
attach(R.L.4)


## model with imputed data set R.L.4 without correction for ph violation

model1.R.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


print(model1.R.L4)
## proportional hazard tests
fit.model1.R.L4 <- cox.zph(model1.R.L4, transform='identity')
print(fit.model1.R.L4)


## more models, now collapsing conflict into one category

model0.R.L4 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.R.L4 <- cox.zph(model0.R.L4, transform='identity')
print(fit.model0.R.L4)
print(model0.R.L4)

model2.R.L4 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL +growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model2.R.L4)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L4 <- list(coef(model2.R.L4))
R.m2.se.L4 <- list(sqrt(diag(vcov(model2.R.L4))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L4 <- basehaz(model2.R.L4,centered=FALSE)


model3.R.L4 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.4,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L4)

## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m3.coef.L4 <- list(coef(model3.R.L4))
R.m3.se.L4 <- list(sqrt(diag(vcov(model3.R.L4))))

detach(R.L.4)

# Now the fifth and final imputed data set

s <- prelim.norm(R.L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(2632)
trk <- seq(1,nrow(R.L),1)
boot.1 <- sample(trk,1+abs(nrow(R.L)/4),replace=TRUE)  ## sample the obs

s.1 <- prelim.norm(R.L[boot.1,])  ## R.L[boot.1,] is the "smaller" sample
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

## imputation phase with 500 steps using the da.norm command
## R.L.5 is the fifth imputed data set
rngseed(1138)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
R.L.5 <- as.data.frame(imp.norm(s,theta.1,R.L))

R.L.5$ccode <- LeaderR.data$ccode
attach(R.L.5)


## model with imputed data set R.L.5 without correction for ph violation

model1.R.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

print(model1.R.L5)
## proportional hazard tests
fit.model1.R.L5 <- cox.zph(model1.R.L5, transform='identity')
print(fit.model1.R.L5)


## more models, now collapsing conflict into one category

model0.R.L5 <- coxph(Surv(t0, t, d) ~ tmixed + tdemparl + tdempres + trans
                               + civwar 
                               + lngdpcapL + growth 
                               + tropen2L + dopen2 
                               + lnpop 
                               + age0 + entry1 + powtimes
                               + initiator2 + defender2 + inherit 
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## proportional hazard tests
fit.model0.R.L5 <- cox.zph(model0.R.L5, transform='identity')
print(fit.model0.R.L5)
print(model0.R.L5)

model2.R.L5 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar
                               + lngdpcapL + txlngcapL +growth 
                               + tropen2L + dopen2
                               + lnpop  
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwin + dlose + ddraw
                               + frailty(ccode), na.action=na.exclude, data=R.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
print(model2.R.L5)


## get coefficients and standard errors from the models; used later in script file 06-models-sum.R
R.m2.coef.L5 <- list(coef(model2.R.L5))
R.m2.se.L5 <- list(sqrt(diag(vcov(model2.R.L5))))


## get the baseline hazard function; used later for the estimation of substantive effects
R.Ht.L5 <- basehaz(model2.R.L5,centered=FALSE)


model3.R.L5 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.5,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
                               
print(model3.R.L5)

## get coefficients and standard errors from the models; used later below
R.m3.coef.L5 <- list(coef(model3.R.L5))
R.m3.se.L5 <- list(sqrt(diag(vcov(model3.R.L5))))

detach(R.L.5)




##################################################################################################
##################################################################################################

# model 0 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m0.R.rho <- cbind(fit.model0.R.L1$table[,1],fit.model0.R.L2$table[,1],fit.model0.R.L3$table[,1],fit.model0.R.L4$table[,1],
                fit.model0.R.L5$table[,1])  ## get the rhos

m0.R.rho.chi <- cbind(fit.model0.R.L1$table[,2],fit.model0.R.L2$table[,2],fit.model0.R.L3$table[,2],fit.model0.R.L4$table[,2],
                fit.model0.R.L5$table[,2])  ## get the chi-squares

m0.R.rho.bar <- apply(m0.R.rho,1,mean)   ## take the means of the rhos

m0.R.d.bar <- apply(m0.R.rho.chi,1,mean)  ## take the means of the chi-squares

m0.R.s2.rho <- apply(sqrt(m0.R.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m0.R.D.tilde <- (m0.R.d.bar-(1-1/M)*m0.R.s2.rho)/(1+(1+1/M)*m0.R.s2.rho)    ## D-tilde expression on p.590 of Rubin-Shenker
                                                                            ## k is equal to 1

m0.R.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m0.R.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                      ## of p.590 of Rubin-Shenker

m0.R.rho.imp <- round(cbind('rho'=m0.R.rho.bar,'D.tilde'=m0.R.D.tilde,'p-value'=pf(m0.R.D.tilde,1,m0.R.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m0.R.rho.imp)


plot(fit.model0.R.L1[1])
plot(fit.model0.R.L2[2])
plot(fit.model0.R.L3[3])
plot(fit.model0.R.L4[4])
plot(fit.model0.R.L5[6])

##################################################################################################
##################################################################################################

# model 1 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5 ## number of imputed data sets

m1.R.rho <- cbind(fit.model1.R.L1$table[,1],fit.model1.R.L2$table[,1],fit.model1.R.L3$table[,1],fit.model1.R.L4$table[,1],
                fit.model1.R.L5$table[,1])  ## get the rhos

m1.R.rho.chi <- cbind(fit.model1.R.L1$table[,2],fit.model1.R.L2$table[,2],fit.model1.R.L3$table[,2],fit.model1.R.L4$table[,2],
                fit.model1.R.L5$table[,2])  ## get the chi-squares

m1.R.rho.bar <- apply(m1.R.rho,1,mean)   ## take the means of the rhos

m1.R.d.bar <- apply(m1.R.rho.chi,1,mean)  ## take the means of the chi-squares

m1.R.s2.rho <- apply(sqrt(m1.R.rho.chi),1,var)  ## compute the sample variance of the sqrt(chi-squares)
                                            ## see Rubin-Shenker p.590 at the bottom

m1.R.D.tilde <- (m1.R.d.bar-(1-1/M)*m1.R.s2.rho)/(1+(1+1/M)*m1.R.s2.rho)    ## D-tilde expression on p.590 of Rubin-Shenker
                                                                            ## k is equal to 1

m1.R.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m1.R.s2.rho)^(-1))^2      ## df of F distribution (b expression at the bottom
                                                                      ## of p.590 of Rubin-Shenker

m1.R.rho.imp <- round(cbind('rho'=m1.R.rho.bar,'D.tilde'=m1.R.D.tilde,'p-value'=pf(m1.R.D.tilde,1,m1.R.b.rho.df,lower.tail=FALSE)),3)
                        ## this is the F test
                        
print(m1.R.rho.imp)


plot(fit.model1.R.L1[6])
plot(fit.model1.R.L2[6])
plot(fit.model1.R.L3[6])
plot(fit.model1.R.L4[6])
plot(fit.model1.R.L5[1])

##################################################################################################
##################################################################################################


# model 2 -- coefficients

m2.R.b <- c(R.m2.coef.L1,R.m2.coef.L2,R.m2.coef.L3,R.m2.coef.L4,R.m2.coef.L5)
m2.R.s <- c(R.m2.se.L1,R.m2.se.L2,R.m2.se.L3,R.m2.se.L4,R.m2.se.L5)

model2.R.imp <- mi.inference(m2.R.b,m2.R.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model2.R.imp$est,'std.err'=model2.R.imp$std.err,'p-value'=model2.R.imp$signif),3)

# model 2 -- log likelihood
m2.R.llk <- mean(c(model2.R.L1$loglik[2],model2.R.L2$loglik[2],model2.R.L3$loglik[2],model2.R.L4$loglik[2],
               model2.R.L5$loglik[2]))

# model 2 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.R <- nrow(vcov(model2.R.L1))

m2.R.U <- (vcov(model2.R.L1)+vcov(model2.R.L2)+vcov(model2.R.L3)+vcov(model2.R.L4)+vcov(model2.R.L5))/M
                ## mean of var-cov matrixes

m2.R.A <- diag(1,k.R,k.R)

m2.R.zz1 <- (model2.R.L1$coef - model2.R.imp$est)%*%t(model2.R.L1$coef - model2.R.imp$est) ## (Theta-0 - Theta-bar) squared
m2.R.zz2 <- (model2.R.L2$coef - model2.R.imp$est)%*%t(model2.R.L2$coef - model2.R.imp$est)
m2.R.zz3 <- (model2.R.L3$coef - model2.R.imp$est)%*%t(model2.R.L3$coef - model2.R.imp$est)
m2.R.zz4 <- (model2.R.L4$coef - model2.R.imp$est)%*%t(model2.R.L4$coef - model2.R.imp$est)
m2.R.zz5 <- (model2.R.L5$coef - model2.R.imp$est)%*%t(model2.R.L5$coef - model2.R.imp$est)

m2.R.B <- (m2.R.zz1+m2.R.zz2+m2.R.zz3+m2.R.zz4+m2.R.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m2.R.rm <- (1+1/M)*sum(diag(m2.R.B%*%solve(m2.R.U)))/k.R   ## see r at top of p.590 of Rubin-Shenker

#m2.R.V <- (1+m2.R.rm)*m2.R.U

m2.R.Dm <- t(m2.R.A%*%model2.R.imp$est)%*%solve(m2.R.A%*%m2.R.U%*%t(m2.R.A))%*%(m2.R.A%*%model2.R.imp$est)/((1+m2.R.rm)*k.R) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m2.R.Dm) # This is the Wald test statistic

m2.R.a <- 1-2/(k.R*(M-1))                   ## a p.590 of Rubin-Shenker
m2.R.v <- 4+(k.R*(M-1)-4)*(1+m2.R.a/m2.R.rm)^2  ## w p.590 of Rubin-Shenker

m2.R.pval.Wald <- pf(m2.R.Dm,k.R,m2.R.v,lower.tail=FALSE)  ## F-test
print(m2.R.pval.Wald)


##################################################################################################
##################################################################################################


# model 3 -- coefficients

m3.R.b <- c(R.m3.coef.L1,R.m3.coef.L2,R.m3.coef.L3,R.m3.coef.L4,R.m3.coef.L5)
m3.R.s <- c(R.m3.se.L1,R.m3.se.L2,R.m3.se.L3,R.m3.se.L4,R.m3.se.L5)

model3.R.imp <- mi.inference(m3.R.b,m3.R.s) ## get the coefficients, std.errs, and p-values (this applies Rubin's formula)

round(cbind('b'=model3.R.imp$est,'std.err'=model3.R.imp$std.err,'p-value'=model3.R.imp$signif),3)

# model 3 -- log likelihood
m3.R.llk <- mean(c(model3.R.L1$loglik[2],model3.R.L2$loglik[2],model3.R.L3$loglik[2],model3.R.L4$loglik[2],
               model3.R.L5$loglik[2]))

# model 3 -- Wald tests

## Wald-test at the bottom of Table 1 in Chiozza and Goemans' AJPS paper
## see formula at the top of p.590 of Rubin-Shenker

k.R <- nrow(vcov(model3.R.L1))

m3.R.U <- (vcov(model3.R.L1)+vcov(model3.R.L2)+vcov(model3.R.L3)+vcov(model3.R.L4)+vcov(model3.R.L5))/M
                ## mean of var-cov matrixes

m3.R.A <- diag(1,k.R,k.R)

m3.R.zz1 <- (model3.R.L1$coef - model3.R.imp$est)%*%t(model3.R.L1$coef - model3.R.imp$est) ## (Theta-0 - Theta-bar) squared
m3.R.zz2 <- (model3.R.L2$coef - model3.R.imp$est)%*%t(model3.R.L2$coef - model3.R.imp$est)
m3.R.zz3 <- (model3.R.L3$coef - model3.R.imp$est)%*%t(model3.R.L3$coef - model3.R.imp$est)
m3.R.zz4 <- (model3.R.L4$coef - model3.R.imp$est)%*%t(model3.R.L4$coef - model3.R.imp$est)
m3.R.zz5 <- (model3.R.L5$coef - model3.R.imp$est)%*%t(model3.R.L5$coef - model3.R.imp$est)

m3.R.B <- (m3.R.zz1+m3.R.zz2+m3.R.zz3+m3.R.zz4+m3.R.zz5)/(M-1) ## see B p.589 of Rubin-Shenker

m3.R.rm <- (1+1/M)*sum(diag(m3.R.B%*%solve(m3.R.U)))/k.R   ## see r at top of p.590 of Rubin-Shenker

#m3.R.V <- (1+m3.R.rm)*m3.R.U

m3.R.Dm <- t(m3.R.A%*%model3.R.imp$est)%*%solve(m3.R.A%*%m3.R.U%*%t(m3.R.A))%*%(m3.R.A%*%model3.R.imp$est)/((1+m3.R.rm)*k.R) ## D expression
                                                                                                         ## at top of p.590
                                                                                                         ## of Rubin-Shenker

print(m3.R.Dm) # This is the Wald test statistic

m3.R.a <- 1-2/(k.R*(M-1))                   ## a p.590 of Rubin-Shenker
m3.R.v <- 4+(k.R*(M-1)-4)*(1+m3.R.a/m3.R.rm)^2  ## w p.590 of Rubin-Shenker

m3.R.pval.Wald <- pf(m3.R.Dm,k.R,m3.R.v,lower.tail=FALSE)  ## F-test
print(m3.R.pval.Wald)



##################################################################################################
##################################################################################################


# frailty terms: Model2

print(model2.R.L1)
print(model2.R.L2)
print(model2.R.L3)
print(model2.R.L4)
print(model2.R.L5)

m2.R.frailty <- mean(c(model2.R.L1$history$"frailty(ccode)"$history[8,1], # number of outer iterations
                     model2.R.L2$history$"frailty(ccode)"$history[8,1],
                     model2.R.L3$history$"frailty(ccode)"$history[8,1],
                     model2.R.L4$history$"frailty(ccode)"$history[8,1],
                     model2.R.L5$history$"frailty(ccode)"$history[8,1]))


round(pgamma(1,1/m2.R.frailty,1/m2.R.frailty),3)
round(qgamma(.025,1/m2.R.frailty,1/m2.R.frailty),3)
round(qgamma(.975,1/m2.R.frailty,1/m2.R.frailty),3)

m2.R.frail.terms <- exp((model2.R.L1$frail+model2.R.L2$frail+model2.R.L3$frail+model2.R.L4$frail+model2.R.L5$frail)/5)

quantile(m2.R.frail.terms,probs=seq(0,1,.005))

#table(ccode)

cbind(m2.R.frail.terms,rep(NA,164)) #164 is the number of countries.

summary(m2.R.frail.terms)

max(m2.R.frail.terms)
min(m2.R.frail.terms)

country <- LeaderR.data$ccode
country <- unique(country)
country.frailty <- cbind(m2.R.frail.terms,country)
print(country.frailty)

round(100*(1-0.7768),2)       # ccode 200, UK
round(100*(1-1.2418),2)       # ccode 1, USA
round(100*(1-0.0016),2)       # ccode 710, China
round(100*(1-0.0998),2)       # ccode 678, Yemen
round(100*(1-0.0570),2)       # ccode 420, Gambia
round(100*(1-0.0811),2)       # ccode 760, Bhutan
round(100*(1-0.7585),2)       # ccode 750, India


m2.R.k.theta <- 95 # see df from model2.R.L5 from the frailty term
m2.R.d.bar.theta <- mean(c(318.65,331.81,331.37,322.93,325.52)) # Chi-square of the models
m2.R.s2.theta <- var(c(318.65,331.81,331.37,322.93,325.52)^.5)  # Chi-square of the models

m2.R.D.tilde.theta <- (m2.R.d.bar.theta/m2.R.k.theta - (1-1/M)*m2.R.s2.theta)/(1+(1+1/M)*m2.R.s2.theta)

m2.R.b.theta <- (m2.R.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m2.R.s2.theta)^(-1))^2

m2.R.frail.pval <- pf(m2.R.D.tilde.theta,m2.R.k.theta,m2.R.b.theta,lower.tail=FALSE)
print(m2.R.frail.pval)

#################################################################################################
##################################################################################################

# frailty terms: Model3

print(model3.R.L1)
print(model3.R.L2)
print(model3.R.L3)
print(model3.R.L4)
print(model3.R.L5)

m3.R.frailty <- mean(c(model3.R.L1$history$"frailty(ccode)"$history[8,1], # number of outer iterations
                     model3.R.L2$history$"frailty(ccode)"$history[8,1],
                     model3.R.L3$history$"frailty(ccode)"$history[8,1],
                     model3.R.L4$history$"frailty(ccode)"$history[8,1],
                     model3.R.L5$history$"frailty(ccode)"$history[8,1]))


round(pgamma(1,1/m3.R.frailty,1/m3.R.frailty),3)
round(qgamma(.025,1/m3.R.frailty,1/m3.R.frailty),3)
round(qgamma(.975,1/m3.R.frailty,1/m3.R.frailty),3)

m3.R.frail.terms <- exp((model3.R.L1$frail+model3.R.L2$frail+model3.R.L3$frail+model3.R.L4$frail+model3.R.L5$frail)/5)

quantile(m3.R.frail.terms,probs=seq(0,1,.01))

#table(ccode)

cbind(m3.R.frail.terms,rep(NA,164)) #164 is the number of countries.

max(m3.R.frail.terms)
min(m3.R.frail.terms)

country.frail.3 <- cbind(m3.R.frail.terms,country)
print(country.frail.3)

m3.R.k.theta <- 95 # see df from model3.R.L4 from the frailty term
m3.R.d.bar.theta <- mean(c(317.66,330.88,320.20,321.44,324.59)) # Chi-square of the models
m3.R.s2.theta <- var(c(317.66,330.88,320.20,321.44,324.59)^.5)  # Chi-square of the models

m3.R.D.tilde.theta <- (m3.R.d.bar.theta/m3.R.k.theta - (1-1/M)*m3.R.s2.theta)/(1+(1+1/M)*m3.R.s2.theta)

m3.R.b.theta <- (m3.R.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m3.R.s2.theta)^(-1))^2

m3.R.frail.pval <- pf(m3.R.D.tilde.theta,m3.R.k.theta,m3.R.b.theta,lower.tail=FALSE)
print(m3.R.frail.pval)

#################################################################################################
##################################################################################################


m2.R.part1 <- round(cbind('b'=model2.R.imp$est,'std.err'=model2.R.imp$std.err,'p-value'=model2.R.imp$signif),3)[1:26,] # first 26 coefficients
m2.R.part1 <- rbind(m2.R.part1,
                  'No. of obs.'=c(as.integer(model2.R.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(1319,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m2.R.llk,NA,NA), # log-llk
                  'Wald-test'=c(m2.R.Dm,m2.R.pval.Wald,NA), # wald test
                  'Theta'=c(m2.R.frailty,m2.R.D.tilde.theta,m2.R.frail.pval)) # frailty

m2.R.part1 <- round((m2.R.part1),3)
print(m2.R.part1)



m3.R.part1 <- round(cbind('b'=model3.R.imp$est,'std.err'=model3.R.imp$std.err,'p-value'=model3.R.imp$signif),3)[1:29,] # first 29 coefficients
m3.R.part1 <- rbind(m3.R.part1,
                  'No. of obs.'=c(as.integer(model3.R.L1$n),NA,NA),
                  'No. of subjects'=c(2130,NA,NA), # no. of leaders from stata stset
                  'No. of failures'=c(1319,NA,NA), # no. failures #table(d)
                  'Log-likelihood'=c(m3.R.llk,NA,NA), # log-llk
                  'Wald-test'=c(m3.R.Dm,m3.R.pval.Wald,NA), # wald test
                  'Theta'=c(m3.R.frailty,m3.R.D.tilde.theta,m3.R.frail.pval)) # frailty

m3.R.part1 <- round((m3.R.part1),3)
print(m3.R.part1)


#################################################################################################
#################################################################################################





Rscurve.3.L5 <- survfit(model3.R.L5)
attributes(Rscurve.3.L5)


plot(Rscurve.3.L5[[2]], Rscurve.3.L5[[5]],xlab="Days in Office",ylab="Survival Probability",main="How Leaders Lose Office",type="l",lty=1)
lines(Rscurve.3.L5[[2]],Rscurve.3.L5[[8]])
lines(Rscurve.3.L5[[2]],Rscurve.3.L5[[9]])







##################################################################################################
##################################################################################################

#
#
#
### time to zero effects Model 2
#
#exp(-model2.R.imp$est[1]/model2.R.imp$est[2])/365.25 # Result is the coefficient associated with tmixed = 0 after ?? years
#exp(-model2.R.imp$est[3]/model2.R.imp$est[4])/365.25 # Result is the coefficient associated with tdemparl = 0 after ?? years
#exp(-model2.R.imp$est[5]/model2.R.imp$est[6])/365.25 # Result is the coefficient associated with tdempres = 0 after ?? years
#exp(-model2.R.imp$est[7]/model2.R.imp$est[8])/365.25 # Result is the coefficient associated with trans = 0 after ?? years
#
#exp(-model2.R.imp$est[10]/model2.R.imp$est[11])/365.25 # The coefficient associated with GDP per cap dissipates after ?? years
#exp(-model2.R.imp$est[16]/model2.R.imp$est[17])/365.25 #The coefficient associated with age dissipates after ?? years. NB Interact is not sig
#exp(-model2.R.imp$est[18]/model2.R.imp$est[19])/365.25 #The coefficient associated with entry1 dissipates after ?? years
#
#m2.R.Tm <- m2.R.U+(1+1/M)*m2.R.B
#
##tmixed: To get the p-values, when no longer signficant at .05 level
#
#2*pt(abs(model2.R.imp$est[1]+model2.R.imp$est[2]*log(365.25*9.5))/sqrt(m2.R.Tm[1,1]+(log(365.25*9.5))^2*m2.R.Tm[2,2]
#      +2*log(365.25*9.5)*m2.R.Tm[2,1]),200,lower.tail=FALSE)
#      
##After experimentation, after (slightly less than 9.5 years, the difference between tmixed and auth is no longer signficant at the .05 level
#
#
#2*pt(abs(model2.R.imp$est[1]+model2.R.imp$est[2]*log(365.25*11.8))/sqrt(m2.R.Tm[1,1]+(log(365.25*11.8))^2*m2.R.Tm[2,2]
#      +2*log(365.25*11.8)*m2.R.Tm[2,1]),200,lower.tail=FALSE)
#
##After experimentation, after (slightly more than)11.8 years, the difference between tmixed is signficantly less likely at the .05 level
#
#
#
##tdemparl
#
#2*pt(abs(model2.R.imp$est[3]+model2.R.imp$est[4]*log(365.25*11.6))/sqrt(m2.R.Tm[3,3]+(log(365.25*11.6))^2*m2.R.Tm[4,4]
#      +2*log(365.25*11.6)*m2.R.Tm[4,3]),200,lower.tail=FALSE)
#      
##After experimentation, after 11.6 years, the difference between tdemparl and auth is no longer signficant at the .05 level
#
#
#2*pt(abs(model2.R.imp$est[3]+model2.R.imp$est[4]*log(365.25*15.5))/sqrt(m2.R.Tm[3,3]+(log(365.25*15.5))^2*m2.R.Tm[4,4]
#      +2*log(365.25*15.5)*m2.R.Tm[4,3]),200,lower.tail=FALSE)
#
#     
##After experimentation, after 15.5 years, tdemparl are significantly less likely than auth at the .05 level
#
##tdempres
#
#2*pt(abs(model2.R.imp$est[5]+model2.R.imp$est[6]*log(365.25*11.1))/sqrt(m2.R.Tm[5,5]+(log(365.25*11.1))^2*m2.R.Tm[6,6]
#      +2*log(365.25*11.1)*m2.R.Tm[6,5]),200,lower.tail=FALSE)
#
##After experimentation, after slightly more than 11 years, the difference between tdempres and auth is no longer signficant at the .05 level
#
#
#2*pt(abs(model2.R.imp$est[5]+model2.R.imp$est[6]*log(365.25*15.25))/sqrt(m2.R.Tm[5,5]+(log(365.25*15.25))^2*m2.R.Tm[6,6]
#      +2*log(365.25*15.25)*m2.R.Tm[6,5]),200,lower.tail=FALSE)
#      
#      
##After experimentation, after 15.25 years, the tdempres are significantly less likely at the .05 level
#
#
##trans
#
#
#2*pt(abs(model2.R.imp$est[7]+model2.R.imp$est[8]*log(365.25*11))/sqrt(m2.R.Tm[7,7]+(log(365.25*11))^2*m2.R.Tm[8,8]
#      +2*log(365.25*11)*m2.R.Tm[8,7]),200,lower.tail=FALSE)
#
#
##After experimentation, after slightly less than 11 years, trans are no longer significantly different at the .05 level
#
#
#2*pt(abs(model2.R.imp$est[7]+model2.R.imp$est[8]*log(365.25*15))/sqrt(m2.R.Tm[7,7]+(log(365.25*15))^2*m2.R.Tm[8,8]
#      +2*log(365.25*15)*m2.R.Tm[8,7]),200,lower.tail=FALSE)
#
##After experimentation, after slightly more than 15 years, trans are significantly less likely at the .05 level
#
#
##GDP per capita
#
#2*pt(abs(model2.R.imp$est[10]+model2.R.imp$est[11]*log(365.25*1.4))/sqrt(m2.R.Tm[10,10]+(log(365.25*1.4))^2*m2.R.Tm[11,11]
#      +2*log(365.25*1.4)*m2.R.Tm[11,10]),200,lower.tail=FALSE)
#
##After experimentation, after slightly more than 1.4 years no longer sig
#
#2*pt(abs(model2.R.imp$est[10]+model2.R.imp$est[11]*log(365.25*2.7))/sqrt(m2.R.Tm[10,10]+(log(365.25*2.7))^2*m2.R.Tm[11,11]
#      +2*log(365.25*2.7)*m2.R.Tm[11,10]),200,lower.tail=FALSE)
#
##After experimentation, after slightly less than 2.7 years GDP per capita has a positive and significant effect!
#
#
## age0
#
#2*pt(abs(model2.R.imp$est[16]+model2.R.imp$est[17]*log(365.25*2.3))/sqrt(m2.R.Tm[16,16]+(log(365.25*2.3))^2*m2.R.Tm[17,17]
#      +2*log(365.25*2.3)*m2.R.Tm[17,16]),200,lower.tail=FALSE)
#
##After experimentation, after slightly less than 2.3 years no longer sig.
#
#
#2*pt(abs(model2.R.imp$est[16]+model2.R.imp$est[17]*log(365.25*5.3))/sqrt(m2.R.Tm[16,16]+(log(365.25*5.3))^2*m2.R.Tm[17,17]
#      +2*log(365.25*5.3)*m2.R.Tm[17,16]),200,lower.tail=FALSE)
#
##After experimentation, after slightly less than 5.3 years age at entry decreases hazard
#
#
#
### Entry1
#
#2*pt(abs(model2.R.imp$est[18]+model2.R.imp$est[19]*log(365.25*.85))/sqrt(m2.R.Tm[18,18]+(log(365.25*.85))^2*m2.R.Tm[19,19]
#      +2*log(365.25*.85)*m2.R.Tm[19,18]),200,lower.tail=FALSE)
#      
##After experimentation, after slightly less less than .85 year effect is no longer significant
#
#
#2*pt(abs(model2.R.imp$est[18]+model2.R.imp$est[19]*log(365.25*2.7))/sqrt(m2.R.Tm[18,18]+(log(365.25*2.7))^2*m2.R.Tm[19,19]
#      +2*log(365.25*2.7)*m2.R.Tm[19,18]),200,lower.tail=FALSE)
#
## After slightly less than 2.7 years, the effect is negative and significant

#####################################################################################################################################
#####################################################################################################################################



## time to zero effects Model 3

exp(-model3.R.imp$est[1]/model3.R.imp$est[2])/365.25 # Result is the coefficient associated with tmixed = 0 after ?? years
exp(-model3.R.imp$est[3]/model3.R.imp$est[4])/365.25 # Result is the coefficient associated with tdemparl = 0 after ?? years
exp(-model3.R.imp$est[5]/model3.R.imp$est[6])/365.25 # Result is the coefficient associated with tdempres = 0 after ?? years
exp(-model3.R.imp$est[7]/model3.R.imp$est[8])/365.25 # Result is the coefficient associated with trans = 0 after ?? years

exp(-model3.R.imp$est[10]/model3.R.imp$est[11])/365.25 # The coefficient associated with GDP per cap dissipates after ?? years
exp(-model3.R.imp$est[16]/model3.R.imp$est[17])/365.25 #The coefficient associated with age dissipates after ?? years. NB Interact is not sig
exp(-model3.R.imp$est[18]/model3.R.imp$est[19])/365.25 #The coefficient associated with entry1 dissipates after ?? years

m3.R.Tm <- m3.R.U+(1+1/M)*m3.R.B

#tmixed: To get the p-values, when no longer signficant at .05 level

2*pt(abs(model3.R.imp$est[1]+model3.R.imp$est[2]*log(365.25*9.5))/sqrt(m3.R.Tm[1,1]+(log(365.25*9.5))^2*m3.R.Tm[2,2]
      +2*log(365.25*9.5)*m3.R.Tm[2,1]),200,lower.tail=FALSE)

#After experimentation, after slightly less than 9.5 years, the difference between tmixed and auth is no longer signficant at the .05 level


2*pt(abs(model3.R.imp$est[1]+model3.R.imp$est[2]*log(365.25*11.8))/sqrt(m3.R.Tm[1,1]+(log(365.25*11.8))^2*m3.R.Tm[2,2]
      +2*log(365.25*11.8)*m3.R.Tm[2,1]),200,lower.tail=FALSE)
      
      
#After experimentation, after slightly more than 11.8 years, the difference between tmixed and auth is signficant at the .05 level


#tdemparl

2*pt(abs(model3.R.imp$est[3]+model3.R.imp$est[4]*log(365.25*11.65))/sqrt(m3.R.Tm[3,3]+(log(365.25*11.65))^2*m3.R.Tm[4,4]
      +2*log(365.25*11.65)*m3.R.Tm[4,3]),200,lower.tail=FALSE)
      
#After experimentation, after 11.65 years, the difference between tdemparl and auth is no longer signficant at the .05 level


2*pt(abs(model3.R.imp$est[3]+model3.R.imp$est[4]*log(365.25*15.5))/sqrt(m3.R.Tm[3,3]+(log(365.25*15.5))^2*m3.R.Tm[4,4]
      +2*log(365.25*15.5)*m3.R.Tm[4,3]),200,lower.tail=FALSE)

  
#After experimentation, after 155 years, the difference between tdemparl and auth is again signficant at the .05 level


#tdempres

2*pt(abs(model3.R.imp$est[5]+model3.R.imp$est[6]*log(365.25*11))/sqrt(m3.R.Tm[5,5]+(log(365.25*11))^2*m3.R.Tm[6,6]
      +2*log(365.25*11)*m3.R.Tm[6,5]),200,lower.tail=FALSE)

#After experimentation, after  slightly less than 11 years, the difference between tdempres and aut is no longer signficant at the .05 level



2*pt(abs(model3.R.imp$est[5]+model3.R.imp$est[6]*log(365.25*15.3))/sqrt(m3.R.Tm[5,5]+(log(365.25*15.3))^2*m3.R.Tm[6,6]
      +2*log(365.25*15.3)*m3.R.Tm[6,5]),200,lower.tail=FALSE)

#trans

2*pt(abs(model3.R.imp$est[7]+model3.R.imp$est[8]*log(365.25*10.9))/sqrt(m3.R.Tm[7,7]+(log(365.25*10.9))^2*m3.R.Tm[8,8]
      +2*log(365.25*10.9)*m3.R.Tm[8,7]),200,lower.tail=FALSE)

#After experimentation, after slightly more than) 10.9 years, the difference between trans and auth is  signficant at the .05 level


2*pt(abs(model3.R.imp$est[7]+model3.R.imp$est[8]*log(365.25*15))/sqrt(m3.R.Tm[7,7]+(log(365.25*15))^2*m3.R.Tm[8,8]
      +2*log(365.25*15)*m3.R.Tm[8,7]),200,lower.tail=FALSE)

# After 15 years in power, Significantly less likely than autocrats


exp(-model3.R.imp$est[10]/model3.R.imp$est[11])/365.25 # The coefficient associated with GDP per cap dissipates after ?? years
exp(-model3.R.imp$est[16]/model3.R.imp$est[17])/365.25 #The coefficient associated with age dissipates after ?? years. NB Interact is not sig
exp(-model3.R.imp$est[18]/model3.R.imp$est[19])/365.25 #The coefficient associated with entry1 dissipates after ?? years


#GDP per capita

2*pt(abs(model3.R.imp$est[10]+model3.R.imp$est[11]*log(365.25*1.5))/sqrt(m3.R.Tm[10,10]+(log(365.25*1.5))^2*m3.R.Tm[11,11]
      +2*log(365.25*1.5)*m3.R.Tm[11,10]),200,lower.tail=FALSE)
      
      
2*pt(abs(model3.R.imp$est[10]+model3.R.imp$est[11]*log(365.25*1.7))/sqrt(m3.R.Tm[10,10]+(log(365.25*1.7))^2*m3.R.Tm[11,11]
      +2*log(365.25*1.7)*m3.R.Tm[11,10]),200,lower.tail=FALSE)

#After experimentation, after slightly less than 1.77 significant at 10\% level

2*pt(abs(model3.R.imp$est[10]+model3.R.imp$est[11]*log(365.25*2.8))/sqrt(m3.R.Tm[10,10]+(log(365.25*2.8))^2*m3.R.Tm[11,11]
      +2*log(365.25*2.8)*m3.R.Tm[11,10]),200,lower.tail=FALSE)

#After experimentation, after 2.8 years GDP per capita still a positive and  effect at .106


2*pt(abs(model3.R.imp$est[10]+model3.R.imp$est[11]*log(365.25*.9))/sqrt(m3.R.Tm[10,10]+(log(365.25*.9))^2*m3.R.Tm[11,11]
      +2*log(365.25*.9)*m3.R.Tm[11,10]),200,lower.tail=FALSE)


2*pt(abs(model3.R.imp$est[10]+model3.R.imp$est[11]*log(365.25*5))/sqrt(m3.R.Tm[10,10]+(log(365.25*5))^2*m3.R.Tm[11,11]
      +2*log(365.25*5)*m3.R.Tm[11,10]),200,lower.tail=FALSE)


# age0

2*pt(abs(model3.R.imp$est[16]+model3.R.imp$est[17]*log(365.25*2.1))/sqrt(m3.R.Tm[16,16]+(log(365.25*2.1))^2*m3.R.Tm[17,17]
      +2*log(365.25*2.1)*m3.R.Tm[17,16]),200,lower.tail=FALSE)

#After experimentation, after slightly less than 2.1 years no longer sig.

2*pt(abs(model3.R.imp$est[16]+model3.R.imp$est[17]*log(365.25*3.4))/sqrt(m3.R.Tm[16,16]+(log(365.25*3.4))^2*m3.R.Tm[17,17]
      +2*log(365.25*3.4)*m3.R.Tm[17,16]),200,lower.tail=FALSE)

#After experimentation, after slightly more than 3.4 years age at entry decreases hazard


## Entry1

2*pt(abs(model3.R.imp$est[18]+model3.R.imp$est[19]*log(365.25*1))/sqrt(m3.R.Tm[18,18]+(log(365.25*1))^2*m3.R.Tm[19,19]
      +2*log(365.25*1)*m3.R.Tm[19,18]),200,lower.tail=FALSE)
      
#After experimentation, after slightly more than 1 year effect is no longer significantly more likely


2*pt(abs(model3.R.imp$est[18]+model3.R.imp$est[19]*log(365.25*3.2))/sqrt(m3.R.Tm[18,18]+(log(365.25*3.2))^2*m3.R.Tm[19,19]
      +2*log(365.25*3.2)*m3.R.Tm[19,18]),200,lower.tail=FALSE)

# After slightly more than 3.2 years, the effect is negative and significant

#####################################################################################################################################
#####################################################################################################################################
#
## Wald test -- H0: tdemparl == tdempres
#
#k <- 1
#
#Q <- as.matrix(t(rep(0,26)))
#Q[3] <- 1
#Q[5] <- -1
#
#m2.R.rm <- (1+1/M)*sum(diag(m2.R.B%*%solve(m2.R.U)))/k
#
#W.R.dems <- t(Q%*%model2.R.imp$est)%*%solve(Q%*%m2.R.U%*%t(Q))%*%(Q%*%model2.R.imp$est)/((1+m2.R.rm)*k)
#
#m2.R.v <- .5*k*(M-1)*(1+1/k)*(1+m2.R.rm^(-1))^2 # Meng and Rubin (1992, 105)
#print(m2.R.v)
#
#pval.W.R.dems <- pf(W.R.dems,k,m2.R.v,lower.tail=FALSE)
#print(pval.W.R.dems)

#######################################################

k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[3] <- 1
Q[5] <- -1

m3.R.rm <- (1+1/M)*sum(diag(m3.R.B%*%solve(m3.R.U)))/k

W.R.dems <- t(Q%*%model3.R.imp$est)%*%solve(Q%*%m3.R.U%*%t(Q))%*%(Q%*%model3.R.imp$est)/((1+m3.R.rm)*k)

m3.R.v <- .5*k*(M-1)*(1+1/k)*(1+m3.R.rm^(-1))^2 # Meng and Rubin (1992, 105)
print(m3.R.v)

pval.W.R.dems <- pf(W.R.dems,k,m3.R.v,lower.tail=FALSE)
print(pval.W.R.dems)



#########################################################################################################
##SUBSTANTIVE EFFECTS 
#########################################################################################################


## estimated effects


## See Therneau and Grambsch -- p.268--272

## estimate model with frailty term

model3.R.L1 <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

## estimate same model with no frailty
model3.trk <- coxph(Surv(t0, t, d) ~ tmixed + txtmixed + tdemparl + txtdemparl + tdempres + txtdempres + trans + txtrans
                               + civwar 
                               + lngdpcapL + txlngcapL + growth
                               + tropen2L + dopen2
                               + lnpop
                               + age0 + txage0 + entry1 + txentry1 + powtimes
                               + initiator2 + defender2 + inherit
                               + dwinsh + dlosesh + ddrawsh
                               + dwinwar + dlosewar + ddrawwar,
                               na.action=na.exclude, data=R.L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


## trick, assuming that the frailty==1

model3.trk$coefficients <- model3.R.L1$coefficients

summary(R.L.1)

#########################################################################################################
##SUBSTANTIVE EFFECTS : REGULAR ENTRY: Regime type at peace
#########################################################################################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly
scen1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitM1 <- survfit(model3.trk,newdata=scen1,individual=TRUE)
plot(fitM1)
summary(fitM1)

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly
scen2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitA1 <- survfit(model3.trk,newdata=scen2,individual=TRUE)
plot(fitA1)
summary(fitA1)


## create data set with hypothetical scenario: A Democratic Parliamentary regime with a leader who enters regularly
scen3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitDPa1 <- survfit(model3.trk,newdata=scen3,individual=TRUE)
plot(fitDPa1)
summary(fitDPa1)


## create data set with hypothetical scenario: A Democratic Presidential regime with a leader who enters regularly
scen4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitDPr1 <- survfit(model3.trk,newdata=scen4,individual=TRUE)
plot(fitDPr1)
summary(fitDPr1)


## create data set with hypothetical scenario: A Transitional regime with a leader who enters regularly
scen5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT1 <- survfit(model3.trk,newdata=scen5,individual=TRUE)
plot(fitT1)
summary(fitT1)

#########################################################################################################
##SUBSTANTIVE EFFECTS : IRREGULAR ENTRY & peace
#########################################################################################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly
scen1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitM1 <- survfit(model3.trk,newdata=scen1,individual=TRUE)
plot(fitM1)
summary(fitM1)

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly
scen2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitA1 <- survfit(model3.trk,newdata=scen2,individual=TRUE)
plot(fitA1)
summary(fitA1)


## create data set with hypothetical scenario: A Democratic Parliamentary regime with a leader who enters regularly
scen3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitDPa1 <- survfit(model3.trk,newdata=scen3,individual=TRUE)
plot(fitDPa1)
summary(fitDPa1)


## create data set with hypothetical scenario: A Democratic Presidential regime with a leader who enters regularly
scen4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitDPr1 <- survfit(model3.trk,newdata=scen4,individual=TRUE)
plot(fitDPr1)
summary(fitDPr1)


## create data set with hypothetical scenario: A Transitional regime with a leader who enters regularly
scen5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(0,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT1 <- survfit(model3.trk,newdata=scen5,individual=TRUE)
plot(fitT1)
summary(fitT1)

#########################################################################################################
##SUBSTANTIVE EFFECTS : REGULAR ENTRY: CONFLICT : Initiation + Victory in a CRISIS
#########################################################################################################


## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and Wins a Crisis
scen1.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitM2 <- survfit(model3.trk,newdata=scen1.1,individual=TRUE)
plot(fitM2)
summary(fitM2)

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and LOSES
scen1.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
fitM3 <- survfit(model3.trk,newdata=scen1.2,individual=TRUE)
plot(fitM3)
summary(fitM3)


## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and DRAWS
scen1.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
                    
fitM4 <- survfit(model3.trk,newdata=scen1.4,individual=TRUE)
plot(fitM4)
summary(fitM4)

#############################################
#### Now for Wars ###########################
#############################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and Wins a WAR


scen1.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitM5 <- survfit(model3.trk,newdata=scen1.5,individual=TRUE)
plot(fitM5)
summary(fitM5)

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and LOSES
scen1.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))
                    
fitM6 <- survfit(model3.trk,newdata=scen1.6,individual=TRUE)
plot(fitM6)
summary(fitM6)


## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and DRAWS
scen1.7 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))
                    
fitM7 <- survfit(model3.trk,newdata=scen1.7,individual=TRUE)
plot(fitM7)
summary(fitM7)


##############################################################################################################################
##############################################################################################################################
#############################################################################################################################


## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and wins a CRISIS
scen2.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitA2 <- survfit(model3.trk,newdata=scen2.1,individual=TRUE)
plot(fitA2)
summary(fitA2)


## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and loses
scen2.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitA3 <- survfit(model3.trk,newdata=scen2.2,individual=TRUE)
plot(fitA3)
summary(fitA3)

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and DRAWS
scen2.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitA4 <- survfit(model3.trk,newdata=scen2.3,individual=TRUE)
plot(fitA4)
summary(fitA4)

############################
### Now for WARS  ##########
############################

scen2.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
                    
fitA5 <- survfit(model3.trk,newdata=scen2.4,individual=TRUE)
plot(fitA5)
summary(fitA5)


scen2.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fitA6 <- survfit(model3.trk,newdata=scen2.5,individual=TRUE)
plot(fitA6)
summary(fitA6)

                    
scen2.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))

fitA7 <- survfit(model3.trk,newdata=scen2.6,individual=TRUE)
plot(fitA7)
summary(fitA7)


##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


## create data set with hypothetical scenario: A Parliamentary Democratic leader who enters regularly, initiates + wins CRISIS

scen3.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPa2 <- survfit(model3.trk,newdata=scen3.1,individual=TRUE)
plot(fitDPa2)
summary(fitDPa2)


## create data set with hypothetical scenario: A Parliamentary Democratic regime with a leader who enters regularly, initiates + loses

scen3.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPa3 <- survfit(model3.trk,newdata=scen3.2,individual=TRUE)
plot(fitDPa3)
summary(fitDPa3)


## create data set with hypothetical scenario: A Parliamentary Democratic regime with a leader who enters regularly, initiates + DRAW

scen3.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPa4 <- survfit(model3.trk,newdata=scen3.3,individual=TRUE)
plot(fitDPa4)
summary(fitDPa4)

#############################################
## Now for Wars  ############################
#############################################


scen3.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitDPa5 <- survfit(model3.trk,newdata=scen3.4,individual=TRUE)
plot(fitDPa5)
summary(fitDPa5)

scen3.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fitDPa6 <- survfit(model3.trk,newdata=scen3.5,individual=TRUE)
plot(fitDPa6)
summary(fitDPa6)

scen3.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))


fitDPa7 <- survfit(model3.trk,newdata=scen3.6,individual=TRUE)
plot(fitDPa7)
summary(fitDPa7)

##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


## create data set with hypothetical scenario: A Presidential Democratic leader who enters regularly initiates + wins a CRISIS



scen4.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPr2 <- survfit(model3.trk,newdata=scen4.1,individual=TRUE)
plot(fitDPr2)
summary(fitDPr2)


## create data set with hypothetical scenario: A Presidential Democratic regime with a leader who enters regularly initiates + LOSES

scen4.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPr3 <- survfit(model3.trk,newdata=scen4.2,individual=TRUE)
plot(fitDPr3)
summary(fitDPr3)



## create data set with hypothetical scenario: A Presidential Democratic regime with a leader who enters regularly initiates + DRAWS

scen4.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPr4 <- survfit(model3.trk,newdata=scen4.3,individual=TRUE)
plot(fitDPr4)
summary(fitDPr4)


###################################
#### Now for WARS  ################
###################################


scen4.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitDPr5 <- survfit(model3.trk,newdata=scen4.4,individual=TRUE)
plot(fitDPr5)
summary(fitDPr5)


scen4.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))


fitDPr6 <- survfit(model3.trk,newdata=scen4.5,individual=TRUE)
plot(fitDPr6)
summary(fitDPr6)

scen4.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))


fitDPr7 <- survfit(model3.trk,newdata=scen4.4,individual=TRUE)
plot(fitDPr7)
summary(fitDPr7)

##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


# Now for leaders of Regimes in Transition. First CRISES.


scen5.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT2 <- survfit(model3.trk,newdata=scen5.1,individual=TRUE)
plot(fitT2) 
summary(fitT2)



scen5.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT3 <- survfit(model3.trk,newdata=scen5.2,individual=TRUE)
plot(fitT3) 
summary(fitT3)


scen5.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT4 <- survfit(model3.trk,newdata=scen5.3,individual=TRUE)
plot(fitT4) 
summary(fitT4)

#######################################
### Now for WARS ######################
#######################################


scen5.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT5 <- survfit(model3.trk,newdata=scen5.4,individual=TRUE)
plot(fitT5) 
summary(fitT5)


scen5.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fitT6 <- survfit(model3.trk,newdata=scen5.5,individual=TRUE)
plot(fitT6) 
summary(fitT6)


scen5.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(0,0,0,0,0),
                    txentry1=c(0,0,0,0,0),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))

fitT7 <- survfit(model3.trk,newdata=scen5.6,individual=TRUE)
plot(fitT7) 
summary(fitT7)

#########################################################################################################################################################
#########################################################################################################################################################
################################## Now for Irregular Entries.
#########################################################################################################################################################
#########################################################################################################################################################




## create data set with hypothetical scenario: A Mixed regime with a leader who enters Irregularly Initiates and Wins a Crisis
scen1.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitM2 <- survfit(model3.trk,newdata=scen1.1,individual=TRUE)
plot(fitM2)
summary(fitM2)

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and LOSES
scen1.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
fitM3 <- survfit(model3.trk,newdata=scen1.2,individual=TRUE)
plot(fitM3)
summary(fitM3)


## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and DRAWS
scen1.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
                    
fitM4 <- survfit(model3.trk,newdata=scen1.4,individual=TRUE)
plot(fitM4)
summary(fitM4)

#############################################
#### Now for Wars ###########################
#############################################

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and Wins a WAR


scen1.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitM5 <- survfit(model3.trk,newdata=scen1.5,individual=TRUE)
plot(fitM5)
summary(fitM5)

## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and LOSES
scen1.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))
                    
fitM6 <- survfit(model3.trk,newdata=scen1.6,individual=TRUE)
plot(fitM6)
summary(fitM6)


## create data set with hypothetical scenario: A Mixed regime with a leader who enters regularly Initiates and DRAWS
scen1.7 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(1,1,1,1,1),
                    txtmixed=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.687,.687,.687,.687,.687),
                    txlngcapL=c(4.56,4.56,4.56,4.56,4.56),
                    growth=c(0.011,0.011,0.011,0.011,0.011),
                    tropen2L=c(0.15,0.15,0.15,0.15,0.15),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(2.05,2.05,2.05,2.05,2.05),
                    age0=c(50,50,50,50,50),
                    txage0=c(375.6,375.6,375.6,375.6,375.6),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))
                    
fitM7 <- survfit(model3.trk,newdata=scen1.7,individual=TRUE)
plot(fitM7)
summary(fitM7)


##############################################################################################################################
##############################################################################################################################
#############################################################################################################################

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and wins a CRISIS
scen2.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitA2 <- survfit(model3.trk,newdata=scen2.1,individual=TRUE)
plot(fitA2)
summary(fitA2)


## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and loses
scen2.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitA3 <- survfit(model3.trk,newdata=scen2.2,individual=TRUE)
plot(fitA3)
summary(fitA3)

## create data set with hypothetical scenario: A Authoritarian regime with a leader who enters regularly, initiates and DRAWS
scen2.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitA4 <- survfit(model3.trk,newdata=scen2.3,individual=TRUE)
plot(fitA4)
summary(fitA4)

############################
### Now for WARS  ##########
############################

scen2.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))
                    
fitA5 <- survfit(model3.trk,newdata=scen2.4,individual=TRUE)
plot(fitA5)
summary(fitA5)


scen2.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fitA6 <- survfit(model3.trk,newdata=scen2.5,individual=TRUE)
plot(fitA6)
summary(fitA6)

                    
scen2.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.64,.64,.64,.64,.64),
                    txlngcapL=c(5.03,5.03,5.03,5.03,5.03),
                    growth=c(0.012,0.012,0.012,0.012,0.012),
                    tropen2L=c(0.18,0.18,0.18,0.18,0.18),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.02,2.02,2.02,2.02,2.02),
                    age0=c(45,45,45,45,45),
                    txage0=c(428.3,428.3,428.3,428.3,428.3),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))

fitA7 <- survfit(model3.trk,newdata=scen2.6,individual=TRUE)
plot(fitA7)
summary(fitA7)


##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


## create data set with hypothetical scenario: A Parliamentary Democratic leader who enters regularly, initiates + wins CRISIS

scen3.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPa2 <- survfit(model3.trk,newdata=scen3.1,individual=TRUE)
plot(fitDPa2)
summary(fitDPa2)


## create data set with hypothetical scenario: A Parliamentary Democratic regime with a leader who enters regularly, initiates + loses

scen3.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPa3 <- survfit(model3.trk,newdata=scen3.2,individual=TRUE)
plot(fitDPa3)
summary(fitDPa3)


## create data set with hypothetical scenario: A Parliamentary Democratic regime with a leader who enters regularly, initiates + DRAW

scen3.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPa4 <- survfit(model3.trk,newdata=scen3.3,individual=TRUE)
plot(fitDPa4)
summary(fitDPa4)

#############################################
## Now for Wars  ############################
#############################################


scen3.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitDPa5 <- survfit(model3.trk,newdata=scen3.4,individual=TRUE)
plot(fitDPa5)
summary(fitDPa5)

scen3.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fitDPa6 <- survfit(model3.trk,newdata=scen3.5,individual=TRUE)
plot(fitDPa6)
summary(fitDPa6)

scen3.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(1,1,1,1,1),
                    txtdemparl=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.85,1.85,1.85,1.85,1.85),
                    txlngcapL=c(11.9,11.9,11.9,11.9,11.9),
                    growth=c(0.023,0.023,0.023,0.023,0.023),
                    tropen2L=c(0.22,0.22,0.22,0.22,0.22),
                    dopen2=c(0.04,0.04,0.04,0.04,0.04),
                    lnpop=c(2.49,2.49,2.49,2.49,2.49),
                    age0=c(55,55,55,55,55),
                    txage0=c(371,371,371,371,371),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))


fitDPa7 <- survfit(model3.trk,newdata=scen3.6,individual=TRUE)
plot(fitDPa7)
summary(fitDPa7)

##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


## create data set with hypothetical scenario: A Presidential Democratic leader who enters regularly initiates + wins a CRISIS



scen4.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPr2 <- survfit(model3.trk,newdata=scen4.1,individual=TRUE)
plot(fitDPr2)
summary(fitDPr2)


## create data set with hypothetical scenario: A Presidential Democratic regime with a leader who enters regularly initiates + LOSES

scen4.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPr3 <- survfit(model3.trk,newdata=scen4.2,individual=TRUE)
plot(fitDPr3)
summary(fitDPr3)



## create data set with hypothetical scenario: A Presidential Democratic regime with a leader who enters regularly initiates + DRAWS

scen4.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))


fitDPr4 <- survfit(model3.trk,newdata=scen4.3,individual=TRUE)
plot(fitDPr4)
summary(fitDPr4)


###################################
#### Now for WARS  ################
###################################


scen4.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitDPr5 <- survfit(model3.trk,newdata=scen4.4,individual=TRUE)
plot(fitDPr5)
summary(fitDPr5)


scen4.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))


fitDPr6 <- survfit(model3.trk,newdata=scen4.5,individual=TRUE)
plot(fitDPr6)
summary(fitDPr6)

scen4.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(1,1,1,1,1),
                    txtdempres=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    trans=c(0,0,0,0,0),
                    txtrans=c(0,0,0,0,0),
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(1.42,1.42,1.42,1.42,1.42),
                    txlngcapL=c(9.7,9.7,9.7,9.7,9.7),
                    growth=c(0.01,0.01,0.01,0.01,0.01),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.05,0.05,0.05,0.05,0.05),
                    lnpop=c(2.22,2.22,2.22,2.22,2.22),
                    age0=c(55,55,55,55,55),
                    txage0=c(396,396,396,396,396),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))


fitDPr7 <- survfit(model3.trk,newdata=scen4.4,individual=TRUE)
plot(fitDPr7)
summary(fitDPr7)

##############################################################################################################################
##############################################################################################################################
##############################################################################################################################


# Now for leaders of Regimes in Transition. First CRISES.


scen5.1 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(1,.5,.33,.25,.2),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT2 <- survfit(model3.trk,newdata=scen5.1,individual=TRUE)
plot(fitT2) 
summary(fitT2)



scen5.2 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(1,.5,.33,.25,.2),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT3 <- survfit(model3.trk,newdata=scen5.2,individual=TRUE)
plot(fitT3) 
summary(fitT3)


scen5.3 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(1,.5,.33,.25,.2),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT4 <- survfit(model3.trk,newdata=scen5.3,individual=TRUE)
plot(fitT4) 
summary(fitT4)

#######################################
### Now for WARS ######################
#######################################


scen5.4 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(1,.5,.33,.25,.2),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(0,0,0,0,0))

fitT5 <- survfit(model3.trk,newdata=scen5.4,individual=TRUE)
plot(fitT5) 
summary(fitT5)


scen5.5 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(1,.5,.33,.25,.2),
                    ddrawwar=c(0,0,0,0,0))

fitT6 <- survfit(model3.trk,newdata=scen5.5,individual=TRUE)
plot(fitT6) 
summary(fitT6)


scen5.6 <- data.frame(t0=c(0,365,730,1095,1460),  ## time0
                    t=c(365,730,1095,1460,1825),  ## time (t-t0 is the time interval)
                    d=c(0,0,0,0,0), ## failure indicator all to 0
                    tmixed=c(0,0,0,0,0),
                    txtmixed=c(0,0,0,0,0),
                    tdemparl=c(0,0,0,0,0),
                    txtdemparl=c(0,0,0,0,0),
                    tdempres=c(0,0,0,0,0),
                    txtdempres=c(0,0,0,0,0),
                    trans=c(1,1,1,1,1),
                    txtrans=c(5.899,6.593,6.998,7.286,7.509),  #log(365)=5.899, log(730)=6.593, log(1095)=6.998, log(1460)=7.286
                    civwar=c(0,0,0,0,0),
                    lngdpcapL=c(.38,.38,.38,.38,.38),
                    txlngcapL=c(2.07,2.07,2.07,2.07,2.07),
                    growth=c(-0.013,-0.013,-0.013,-0.013,-0.013),
                    tropen2L=c(0.19,0.19,0.19,0.19,0.19),
                    dopen2=c(0.03,0.03,0.03,0.03,0.03),
                    lnpop=c(1.92,1.92,1.92,1.92,1.92),
                    age0=c(49,49,49,49,49),
                    txage0=c(315,215,315,315,315),
                    entry1=c(1,1,1,1,1),
                    txentry1=c(5.899,6.593,6.998,7.286,7.509),
                    powtimes=c(0,0,0,0,0),
                    initiator2=c(1,0,0,0,0),
                    defender2=c(0,0,0,0,0),
                    inherit=c(0,0,0,0,0),
                    dwinsh=c(0,0,0,0,0),
                    dlosesh=c(0,0,0,0,0),
                    ddrawsh=c(0,0,0,0,0),
                    dwinwar=c(0,0,0,0,0),
                    dlosewar=c(0,0,0,0,0),
                    ddrawwar=c(1,.5,.33,.25,.2))

fitT7 <- survfit(model3.trk,newdata=scen5.6,individual=TRUE)
plot(fitT7) 
summary(fitT7)
